<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:nc="http://niem.gov/niem/niem-core/2.0"
                xmlns:lexs="http://usdoj.gov/leisp/lexs/3.1"
                xmlns:lexsdigest="http://usdoj.gov/leisp/lexs/digest/3.1"
                xmlns:ndexia="http://fbi.gov/cjis/N-DEx/IncidentArrest/2.1"
                xmlns:lexslib="http://usdoj.gov/leisp/lexs/library/3.1"
                xmlns:s="http://niem.gov/niem/structures/2.0"
                xmlns:fn="http://www.w3.org/2005/xpath-functions"
                xmlns:lexspd="http://usdoj.gov/leisp/lexs/publishdiscover/3.1"
                xmlns:j="http://niem.gov/niem/domains/jxdm/4.0"
                xmlns:mspRoot="http://www.michigan.gov/msp/IncidentReporting/exchange/1.0"
                xmlns:msp="http://www.michigan.gov/msp/IncidentReporting/extensions/1.0"
                xmlns:mspfx="http://www.michigan.gov/msp/IncidentReporting"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->
<xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-message"
                 as="xs:string">
        <xsl:param name="errorNumberIN" as="xs:string"/>
        
        <xsl:sequence select="concat(concat($micr_edits_lookup//ROW/COLUMN[@NAME = 'ERROR_NUMBER' and text() = $errorNumberIN]/../COLUMN[@NAME = 'EDIT_NUMBER']/text(),': '),$micr_edits_lookup//ROW/COLUMN[@NAME = 'ERROR_NUMBER' and text() = $errorNumberIN]/../COLUMN[@NAME = 'MESSAGE_DESCRIPTION']/text())"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-prefixed-message"
                 as="xs:string">
        <xsl:param name="errorNumberIN" as="xs:string"/>
        <xsl:param name="prefixIN" as="xs:string*"/>
        <xsl:param name="prefixNumberIN" as="xs:string*"/>
        
        <xsl:sequence select="concat(concat($prefixIN,concat(' ',concat($prefixNumberIN,' '))),mspfx:error-message($errorNumberIN))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-315"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean(mspfx:no-offender-number-exists() and not($isZeroRec))"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-731"
                 as="xs:boolean">
        <xsl:param name="arrestNumberIN" as="xs:string"/>
        <xsl:param name="offenderNumberIN" as="xs:string"/>
        
        <xsl:sequence select="not($arrestNumberIN = $offenderNumberIN)"/>
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:error-1031"
                 as="xs:boolean">
        <xsl:param name="activityCategoryText" as="xs:string"/>
        
        <xsl:sequence select="boolean($activityCategoryText=('Offense','Incident','Arrest'))"/>
        
    </xsl:function>
   <xsl:function xmlns="http://purl.oclc.org/dsdl/schematron"
                 name="mspfx:no-offender-number-exists"
                 as="xs:boolean">
        
        <xsl:sequence select="boolean(count(distinct-values($offenderNumbers)) = 0)"/>
    </xsl:function>

   <!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl" title="" schemaVersion="">
         <xsl:attribute name="phase">full-integrity</xsl:attribute>
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://purl.oclc.org/dsdl/schematron" prefix="iso"/>
         <svrl:ns-prefix-in-attribute-values uri="http://niem.gov/niem/niem-core/2.0" prefix="nc"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/1999/XSL/Transform" prefix="xsl"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xsd"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/3.1" prefix="lexs"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xs"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/digest/3.1" prefix="lexsdigest"/>
         <svrl:ns-prefix-in-attribute-values uri="http://fbi.gov/cjis/N-DEx/IncidentArrest/2.1" prefix="ndexia"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/library/3.1" prefix="lexslib"/>
         <svrl:ns-prefix-in-attribute-values uri="http://niem.gov/niem/structures/2.0" prefix="s"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2005/xpath-functions" prefix="fn"/>
         <svrl:ns-prefix-in-attribute-values uri="http://usdoj.gov/leisp/lexs/publishdiscover/3.1" prefix="lexspd"/>
         <svrl:ns-prefix-in-attribute-values uri="http://niem.gov/niem/domains/jxdm/4.0" prefix="j"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.michigan.gov/msp/IncidentReporting/exchange/1.0"
                                             prefix="mspRoot"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.michigan.gov/msp/IncidentReporting/extensions/1.0"
                                             prefix="msp"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.michigan.gov/msp/IncidentReporting" prefix="mspfx"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">incident-details</xsl:attribute>
            <xsl:attribute name="name">incident-details</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M82"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">admin-data-constraints</xsl:attribute>
            <xsl:attribute name="name">admin-data-constraints</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M84"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">offense-data-constraints</xsl:attribute>
            <xsl:attribute name="name">offense-data-constraints</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M85"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">offender-data-constraints</xsl:attribute>
            <xsl:attribute name="name">offender-data-constraints</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M86"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">victim-data-constraints</xsl:attribute>
            <xsl:attribute name="name">victim-data-constraints</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M87"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">arrest-data-constraints</xsl:attribute>
            <xsl:attribute name="name">arrest-data-constraints</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M88"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">property-data-constraints</xsl:attribute>
            <xsl:attribute name="name">property-data-constraints</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M89"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">admin-micr-edits</xsl:attribute>
            <xsl:attribute name="name">admin-micr-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M90"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">offense-micr-edits</xsl:attribute>
            <xsl:attribute name="name">offense-micr-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M91"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">offender-micr-edits</xsl:attribute>
            <xsl:attribute name="name">offender-micr-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M92"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">victim-micr-edits</xsl:attribute>
            <xsl:attribute name="name">victim-micr-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M93"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">arrest-micr-edits</xsl:attribute>
            <xsl:attribute name="name">arrest-micr-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M94"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">property_global_micr_edits</xsl:attribute>
            <xsl:attribute name="name">property_global_micr_edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M95"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">property-drug-micr-edits</xsl:attribute>
            <xsl:attribute name="name">property-drug-micr-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M96"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">property-tangible-micr-edits</xsl:attribute>
            <xsl:attribute name="name">property-tangible-micr-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M97"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">property-drug-extended-micr-edits</xsl:attribute>
            <xsl:attribute name="name">property-drug-extended-micr-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M98"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">property-tangible-extended-micr-edits</xsl:attribute>
            <xsl:attribute name="name">property-tangible-extended-micr-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M99"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">micr-final-edits</xsl:attribute>
            <xsl:attribute name="name">micr-final-edits</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M100"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->
<xsl:param name="fbi_codes" select="document('./schema/xsd/niem/fbi/2.0/fbi.xsd')"/>
   <xsl:param name="msp_codes" select="document('./schema/xsd/msp/MSP_Codes.xsd')"/>
   <xsl:param name="ori_codes"
              select="document('./schema/xsd/msp/MICR_ORI_Codes.xsd')"/>
   <xsl:param name="ndexia_codes"
              select="document('./schema/xsd/ndexia/ndexia-codes/2.1/ndexia-codes.xsd')"/>
   <xsl:param name="ctxrf_lookup" select="document('./tables/CTXRF.xml')"/>
   <xsl:param name="orict_lookup" select="document('./tables/ORICT.xml')"/>
   <xsl:param name="filec_lookup" select="document('./tables/FILEC.xml')"/>
   <xsl:param name="val_lookup"
              select="document('./tables/SCHEMATRON_VALIDATION_LOOKUP.xml')"/>
   <xsl:param name="arrcd_lookup" select="document('./tables/ARRCD.xml')"/>
   <xsl:param name="ethinicity_lookup" select="document('./tables/ETHNICITY.xml')"/>
   <xsl:param name="residence_lookup" select="document('./tables/RESIDENCE.xml')"/>
   <xsl:param name="weapon_lookup" select="document('./tables/WEAPON.xml')"/>
   <xsl:param name="offenseactivity_lookup"
              select="document('./tables/OFFENSEACTIVITY.xml')"/>
   <xsl:param name="bias_lookup" select="document('./tables/BIAS.xml')"/>
   <xsl:param name="location_lookup" select="document('./tables/LOCATION.xml')"/>
   <xsl:param name="propertyloss_lookup"
              select="document('./tables/PROPERTYLOSS.xml')"/>
   <xsl:param name="propertyclass_lookup"
              select="document('./tables/PROPERTYCLASS.xml')"/>
   <xsl:param name="drug_lookup" select="document('./tables/DRUG.xml')"/>
   <xsl:param name="vor_lookup" select="document('./tables/VOR.xml')"/>
   <xsl:param name="injury_lookup" select="document('./tables/INJURY.xml')"/>
   <xsl:param name="micr_edits_lookup"
              select="document('./tables/MICR_EDITS_LKP.xml')"/>
   <xsl:param name="action"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ActionCode"/>
   <xsl:param name="arrestExists"
              select="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject/nc:RoleOfPersonReference)"/>
   <xsl:param name="assistOriId"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/nc:Organization[@s:id = //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:AssistingOrganization/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
   <xsl:param name="incidentDate"
              select="substring(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/*[text()] | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/*[text()])] ,1,10)"/>
   <xsl:param name="incidentDateTime"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text() | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime[text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text())]"/>
   <xsl:param name="isActionOR" select="$action = 'O' or $action = 'R'"/>
   <xsl:param name="isExClear"
              select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceCode/text())"/>
   <xsl:param name="occurDate"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate[nc:DateTime | nc:Date]/text()"/>
   <xsl:param name="offenderExists"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference"/>
   <xsl:param name="offenderExist"
              select="boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference)"/>
   <xsl:param name="offenseExists"
              select="exists(//lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText = 'Offense'])"/>
   <xsl:param name="offenseCount"
              select="count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Offense'])"/>
   <xsl:param name="ori"
              select="//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI"/>
   <xsl:param name="victcomimCount"
              select="count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Victim)"/>
   <xsl:param name="victimExist"
              select="boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Victim)"/>
   <xsl:param name="victimExists"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim/nc:RoleOfPersonReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Victim/nc:RoleOfOrganizationReference"/>
   <xsl:param name="propertyClass"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyCategoryCode"/>
   <xsl:param name="propertyExist"
              select="boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug)"/>
   <xsl:param name="propertyExists"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/nc:RoleOfItemReference or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Property/nc:RoleOfItemReference"/>
   <xsl:param name="propertyLoss"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyLossCode"/>
   <xsl:param name="offenderCount"
              select="count((//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference, //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference))"/>
   <xsl:param name="offenders"
              select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference"/>
   <xsl:param name="arrestClearanceTrueCount"
              select="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation[ndexia:ArresteeClearanceIndicator=true()])"/>
   <xsl:param name="offenseFileClasses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"/>
   <xsl:param name="propertyCount"
              select="count((//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property, //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug))"/>
   <xsl:param name="offenses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"/>
   <xsl:param name="completeOffenses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = true()]]"/>
   <xsl:param name="attemptOffenses"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = false()]]"/>
   <xsl:param name="completeReqProp"
              select="$completeOffenses = ($filec_lookup//ROW[COLUMN/@NAME = 'PROP_REQUIRED' and COLUMN/text() = 'Y']/COLUMN[@NAME = 'FILEC_OFFENSE_CO']/text())"/>
   <xsl:param name="attemptReqProp"
              select="$attemptOffenses = ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 162]/COLUMN[@NAME = 'CODE']/text(), 39000 to 39009)"/>
   <xsl:param name="lossTypeList"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyLossCode/text()"/>
   <xsl:param name="duplicateOffender"
              select="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText) != count(distinct-values(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText))"/>
   <xsl:param name="incidentNumber"
              select="//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID/text()"/>
   <xsl:param name="isZeroRec"
              select="$incidentNumber castable as xs:integer and number($incidentNumber) = 0"/>
   <xsl:param name="incidentComplete"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator"/>
   <xsl:param name="offenderNumbers"
              select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText/number(text())"/>

   <!--PATTERN incident-details-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage" priority="1000" mode="M82">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage"/>
      <xsl:variable name="incidentNumber"
                    select="./lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityIdentification/nc:IdentificationID"/>

		    <!--REPORT info-->
<xsl:if test="$ori">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$ori">
            <xsl:attribute name="id">ori</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="$ori"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT info-->
<xsl:if test="exists($incidentNumber/text()) and $incidentNumber/text() castable as xs:integer">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($incidentNumber/text()) and $incidentNumber/text() castable as xs:integer">
            <xsl:attribute name="id">incident-number</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="format-number($incidentNumber,'0000000000')"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT info-->
<xsl:if test="$action">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$action">
            <xsl:attribute name="id">action</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="$action"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT info-->
<xsl:if test="$incidentDate">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$incidentDate">
            <xsl:attribute name="id">orig-year</xsl:attribute>
            <xsl:attribute name="role">info</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="format-date(xs:date($incidentDate),'[Y0001]')"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M82"/>
   <xsl:template match="@*|node()" priority="-2" mode="M82">
      <xsl:apply-templates select="*" mode="M82"/>
   </xsl:template>

   <!--PATTERN admin-data-constraints-->


	<!--RULE -->
<xsl:template match="//msp:ActionCode" priority="1008" mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl" context="//msp:ActionCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$msp_codes//xsd:simpleType[@name='ActionCodeSimpleType']//xsd:enumeration/@value = ."/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$msp_codes//xsd:simpleType[@name='ActionCodeSimpleType']//xsd:enumeration/@value = .">
               <xsl:attribute name="id">175</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>175: ACTION MUST BE O/R/D</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="$isZeroRec and not(text() = 'O') and $isActionOR">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isZeroRec and not(text() = 'O') and $isActionOR">
            <xsl:attribute name="id">117</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>117: ACTION MUST BE O</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI"
                 priority="1007"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI"/>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID"
                 priority="1006"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="text() castable as xs:integer and number(text()) &gt;= 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="text() castable as xs:integer and number(text()) &gt;= 0">
               <xsl:attribute name="id">177_1</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>177: INCIDENT NUMBER MUST BE NUMERIC</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(text()) &lt;= 10"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string-length(text()) &lt;= 10">
               <xsl:attribute name="id">177_2</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>177: INCIDENT NUMBER MUST 10 CHARACTER OR LESS</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(.) = 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(.) = 1">
               <xsl:attribute name="id">177_3</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>177: SUBMISSION SHOULD ONLY CONTAIN ONE INCIDENT NUMBER</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(text())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists(text())">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>111: INCIDENT NUMBER REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//msp:LocationCountyCode" priority="1005" mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:LocationCountyCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not($isActionOR) or empty(.) or distinct-values($ctxrf_lookup//ROW/COLUMN[@NAME = 'CTXRF_COUNTY']/text()) = number(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($isActionOR) or empty(.) or distinct-values($ctxrf_lookup//ROW/COLUMN[@NAME = 'CTXRF_COUNTY']/text()) = number(.)">
               <xsl:attribute name="id">110</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>110: INVALID COUNTY NUMBER</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']"
                 priority="1004"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty($incidentDateTime) or number(substring($incidentDateTime,12,2)) = (0 to 23,99)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($incidentDateTime) or number(substring($incidentDateTime,12,2)) = (0 to 23,99)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>138: HOUR-OCC MUST BE 00 TO 23 OR 99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$incidentDate castable as xs:date"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$incidentDate castable as xs:date">
               <xsl:attribute name="id">113</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>113: INCIDENT DATE IS NOT VALID</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 and $isZeroRec and $isActionOR">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/nc:DateTime/text()) &gt; 0 and $isZeroRec and $isActionOR">
            <xsl:attribute name="id">121</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>121: REPORT DATE INDICATOR MUST BE R WITH ZERO RECORD ENTRY</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$isActionOR and $isZeroRec and $incidentDate castable as xs:date and not(day-from-date(xs:date($incidentDate)) = 1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isActionOR and $isZeroRec and $incidentDate castable as xs:date and not(day-from-date(xs:date($incidentDate)) = 1)">
            <xsl:attribute name="id">120</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>120: DAY IN INCIDENT MUST BE 01</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text() | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate[nc:DateTime | nc:Date]/*[1][text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text())])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text() | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate[nc:DateTime | nc:Date]/*[1][text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate[nc:DateTime | nc:Date]/*[1]/text())])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>134: INCIDENT DATE IS REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//j:IncidentExceptionalClearanceCode"
                 priority="1003"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//j:IncidentExceptionalClearanceCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not($isActionOR) or empty(text()) or $fbi_codes//xsd:simpleType[@name='IncidentExceptionalClearanceCodeSimpleType']//xsd:enumeration/@value = ."/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not($isActionOR) or empty(text()) or $fbi_codes//xsd:simpleType[@name='IncidentExceptionalClearanceCodeSimpleType']//xsd:enumeration/@value = .">
               <xsl:attribute name="id">114</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>114: EXCEPTIONAL CLEARANCE MUST BE 10/11/12/13/14</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1002"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--REPORT error-->
<xsl:if test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID) and not(some $x in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode satisfies ($x = 'L'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID) and not(some $x in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode satisfies ($x = 'L'))">
            <xsl:attribute name="id">112</xsl:attribute>
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>112: ASSIST ORI IS NOT A VALID FIELD</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1001"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime | nc:Date or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime | nc:Date) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime | nc:Date or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime | nc:Date)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, DATE OF OCCURRENCE/REPORT IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists(//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists(//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, ORI IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists(//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists(//nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityIdentification/nc:IdentificationID/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, INCIDENT NUMBER IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/*[text()]) or exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()]))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/*[text()]) or exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()]))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, CANNOT DETERMINE ORIGINAL YEAR FROM ROPORT DATE OR ACTIVITY DATE</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCountyCode/text())) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCountyCode/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, COUNTY CODE IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCityTownshipCode/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(not($isActionOR) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress/msp:LocationCityTownshipCode/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, CITY/TOWNSHIP CODE IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, INCIDENT COMPLETE INDICATOR MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident'])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident'])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, INCIDENT ENTITY ACTIVITY MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, NDEXIA:INCIDENT MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime  or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Incident']/nc:ActivityDate/nc:DateTime or //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/nc:DateTime))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, MISSING HOUR OCCURRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText"
                 priority="1000"
                 mode="M84">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="mspfx:error-1031(./text())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="mspfx:error-1031(./text())">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                  <xsl:text/>
                  <xsl:value-of select="mspfx:error-message('1031')"/>
                  <xsl:text/>
		             </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M84"/>
   <xsl:template match="@*|node()" priority="-2" mode="M84">
      <xsl:apply-templates select="*" mode="M84"/>
   </xsl:template>

   <!--PATTERN offense-data-constraints-->


	<!--RULE -->
<xsl:template match="//msp:OffenseCategoryCode" priority="1005" mode="M85">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:OffenseCategoryCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="distinct-values($filec_lookup//ROW/COLUMN[@NAME='FILEC_OFFENSE_CO']/text()) = number(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="distinct-values($filec_lookup//ROW/COLUMN[@NAME='FILEC_OFFENSE_CO']/text()) = number(.)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>178: INVALID FILE CLASS</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//msp:CriminalActivityCategoryCode"
                 priority="1004"
                 mode="M85">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:CriminalActivityCategoryCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="distinct-values($offenseactivity_lookup//ROW/COLUMN[@NAME='CODE']/text()) = ."/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="distinct-values($offenseactivity_lookup//ROW/COLUMN[@NAME='CODE']/text()) = .">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>585: INVALID ACTIVITY TYPE</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//msp:OffenseBiasMotivationCode" priority="1003" mode="M85">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:OffenseBiasMotivationCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="distinct-values($bias_lookup//ROW/COLUMN[@NAME='BIAS_CODE']/text()) = number(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="distinct-values($bias_lookup//ROW/COLUMN[@NAME='BIAS_CODE']/text()) = number(.)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>165: INVALID BIAS IN OFFENSE</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//msp:LocationCategoryCode" priority="1002" mode="M85">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:LocationCategoryCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="distinct-values($location_lookup//ROW/COLUMN[@NAME='LOCATION_CODE']/text()) =number(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="distinct-values($location_lookup//ROW/COLUMN[@NAME='LOCATION_CODE']/text()) =number(.)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>201: SITE MUST BE 01 to 21/23/24/31 to 41/44 to 46/48 to 50/54 to 57/58/88/99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense"
                 priority="1001"
                 mode="M85">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense"/>

		    <!--REPORT error-->
<xsl:if test="not(string(./ndexia:OffenseCompletedIndicator) castable as xs:boolean) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '160']/../COLUMN[@NAME = 'CODE' and text() = $action]) and not(exists($assistOriId))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(string(./ndexia:OffenseCompletedIndicator) castable as xs:boolean) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '160']/../COLUMN[@NAME = 'CODE' and text() = $action]) and not(exists($assistOriId))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>160: ATTEMPT FOR OFFENSE MUST BE TRUE(C) OR FALSE(A)</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty(./ndexia:OffenseCompletedIndicator/text()) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '202']/../COLUMN[@NAME = 'CODE' and text() = $action]) and not(exists($assistOriId))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty(./ndexia:OffenseCompletedIndicator/text()) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '202']/../COLUMN[@NAME = 'CODE' and text() = $action]) and not(exists($assistOriId))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>202: ATTEMPT IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty(./j:IncidentFactor/j:IncidentFactorCode) or $fbi_codes//xsd:simpleType[@name='IncidentFactorCodeSimpleType']//xsd:enumeration/@value = ./j:IncidentFactor/j:IncidentFactorCode/text()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(./j:IncidentFactor/j:IncidentFactorCode) or $fbi_codes//xsd:simpleType[@name='IncidentFactorCodeSimpleType']//xsd:enumeration/@value = ./j:IncidentFactor/j:IncidentFactorCode/text()">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>163: USED FOR OFFENSE MUST BE A/C/D/N</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty(./j:IncidentForce/j:ForceCategoryCode) or $fbi_codes//xsd:simpleType[@name='ForceCategoryCodeSimpleType']//xsd:enumeration/@value = ./j:IncidentForce/j:ForceCategoryCode/text()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(./j:IncidentForce/j:ForceCategoryCode) or $fbi_codes//xsd:simpleType[@name='ForceCategoryCodeSimpleType']//xsd:enumeration/@value = ./j:IncidentForce/j:ForceCategoryCode/text()">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>166: INVALID WEAPON</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty(./j:IncidentStructuresEnteredQuantity) or string(./j:IncidentStructuresEnteredQuantity) castable as xs:decimal"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(./j:IncidentStructuresEnteredQuantity) or string(./j:IncidentStructuresEnteredQuantity) castable as xs:decimal">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>209: PREMISE MUST BE 00 to 99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty(./j:IncidentStructuresEnteredQuantity) or number(./j:IncidentStructuresEnteredQuantity) &gt;= 0 and number(./j:IncidentStructuresEnteredQuantity) &lt; 100"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(./j:IncidentStructuresEnteredQuantity) or number(./j:IncidentStructuresEnteredQuantity) &gt;= 0 and number(./j:IncidentStructuresEnteredQuantity) &lt; 100">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>209: PREMISE MUST BE 00 to 99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1000"
                 mode="M85">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--REPORT error-->
<xsl:if test="not($isZeroRec) and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense)) and not(exists(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense)) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($isZeroRec) and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense)) and not(exists(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, msp:Offense Missing</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense) = count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense) = count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, count of msp:Offense and count of ndexia:Offense does not match</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M85"/>
   <xsl:template match="@*|node()" priority="-2" mode="M85">
      <xsl:apply-templates select="*" mode="M85"/>
   </xsl:template>

   <!--PATTERN offender-data-constraints-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText"
                 priority="1005"
                 mode="M86">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="number(text()) = number(text()) and number(text()) &lt;= 99 and number(text()) &gt;= 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="number(text()) = number(text()) and number(text()) &lt;= 99 and number(text()) &gt;= 0">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>305: OFFENDER MUST BE  0 to 99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport"
                 priority="1004"
                 mode="M86">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport"/>

		    <!--REPORT error-->
<xsl:if test="$duplicateOffender">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$duplicateOffender">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>311: OFFENDER CANNOT BE DUPLICATED</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonAgeMeasure[nc:MeasurePointValue and nc:TimeUnitCode and ../@s:id = ../../j:Subject/nc:RoleOfPersonReference/@s:ref]"
                 priority="1003"
                 mode="M86">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonAgeMeasure[nc:MeasurePointValue and nc:TimeUnitCode and ../@s:id = ../../j:Subject/nc:RoleOfPersonReference/@s:ref]"/>
      <xsl:variable name="offenderAge" select="nc:MeasurePointValue/text()"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="number($offenderAge) = number($offenderAge) and number($offenderAge) &lt;= 99 and number($offenderAge) &gt;=0 and nc:TimeUnitCode = 'ANN'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="number($offenderAge) = number($offenderAge) and number($offenderAge) &lt;= 99 and number($offenderAge) &gt;=0 and nc:TimeUnitCode = 'ANN'">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>305: OFFENDER MUST BE 0/1 TO 98/99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/ndexia:PersonRaceCode[../lexslib:SameAsDigestReference/@lexslib:ref  = ../../../../../lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference/@s:ref]"
                 priority="1002"
                 mode="M86">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/ndexia:PersonRaceCode[../lexslib:SameAsDigestReference/@lexslib:ref  = ../../../../../lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference/@s:ref]"/>

		    <!--REPORT error-->
<xsl:if test="exists(text()) and (not($ndexia_codes//xsd:simpleType[@name='RACCodeSimpleType']//xsd:enumeration/@value = text()))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(text()) and (not($ndexia_codes//xsd:simpleType[@name='RACCodeSimpleType']//xsd:enumeration/@value = text()))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>303: OFFENDER RACE MUST BE A/B/I/P/U/W</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref]/nc:PersonSexCode"
                 priority="1001"
                 mode="M86">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref]/nc:PersonSexCode"/>

		    <!--REPORT error-->
<xsl:if test="exists(text()) and not($fbi_codes//xsd:simpleType[@name = 'SEXCodeSimpleType']//xsd:enumeration/@value = text())">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(text()) and not($fbi_codes//xsd:simpleType[@name = 'SEXCodeSimpleType']//xsd:enumeration/@value = text())">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>304: OFFENDER SEX MUST BE M/F/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1000"
                 mode="M86">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--REPORT error-->
<xsl:if test="((exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceCode) and exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceDate/nc:Date)) or ($offenses = (09004,11001,11002,36001,36002))) and not($offenderExist) and ($action = 'O' or $action = 'R')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceCode) and exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceDate/nc:Date)) or ($offenses = (09004,11001,11002,36001,36002))) and not($offenderExist) and ($action = 'O' or $action = 'R')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, OFFENDER IS MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(some $x in (//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText) satisfies $x = '00') and not(count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference) = count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject) and count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject) = count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference) and count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject) = count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(some $x in (//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText) satisfies $x = '00') and not(count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference) = count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject) and count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject) = count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference) and count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject) = count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, OFFENDER SECTION MISMATCH</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M86"/>
   <xsl:template match="@*|node()" priority="-2" mode="M86">
      <xsl:apply-templates select="*" mode="M86"/>
   </xsl:template>

   <!--PATTERN victim-data-constraints-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText"
                 priority="1009"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText"/>

		    <!--REPORT error-->
<xsl:if test="(((number(.) &lt; 1 or number(.) &gt; 99))) or translate(., '0123456789','') != ''">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(((number(.) &lt; 1 or number(.) &gt; 99))) or translate(., '0123456789','') != ''">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>593: VICTIM NUMBER MUST BE 01 TO 99</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode"
                 priority="1008"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="string-length(.) &lt; 2"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="string-length(.) &lt; 2">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>598: VICTIM TYPE MUST BE LESS THAN 2 CHARACTERS</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="string-length(.) = 1 and not (. = $fbi_codes//xsd:simpleType[@name='VictimCategoryCodeSimpleType']//xsd:enumeration/@value)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(.) = 1 and not (. = $fbi_codes//xsd:simpleType[@name='VictimCategoryCodeSimpleType']//xsd:enumeration/@value)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>513: VICTIM TYPE MUST BE I/P/B/F/G/R/S/O/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial/j:EnforcementOfficialAssignmentCategoryCode"
                 priority="1007"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial/j:EnforcementOfficialAssignmentCategoryCode"/>

		    <!--REPORT error-->
<xsl:if test="string-length(.) = 1 and not(. = $fbi_codes//xsd:simpleType[@name='LEOKAOfficerAssignmentCategoryCodeSimpleType']//xsd:enumeration/@value)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(.) = 1 and not(. = $fbi_codes//xsd:simpleType[@name='LEOKAOfficerAssignmentCategoryCodeSimpleType']//xsd:enumeration/@value)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>586: INVALID ASSIGNMENT TYPE</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonAgeMeasure[../@s:id = ../../j:Victim/nc:RoleOfPersonReference/@s:ref]"
                 priority="1006"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonAgeMeasure[../@s:id = ../../j:Victim/nc:RoleOfPersonReference/@s:ref]"/>
      <xsl:variable name="measurePointValue" select="./nc:MeasurePointValue"/>
      <xsl:variable name="timeUnitCode" select="./nc:TimeUnitCode"/>

		    <!--REPORT error-->
<xsl:if test="not($timeUnitCode) or (string-length(xs:string(./nc:MeasurePointValue)) &lt; 4 and string-length(xs:string(./nc:MeasurePointValue)) &gt; 0 and string-length(xs:string(./nc:TimeUnitCode)) = 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($timeUnitCode) or (string-length(xs:string(./nc:MeasurePointValue)) &lt; 4 and string-length(xs:string(./nc:MeasurePointValue)) &gt; 0 and string-length(xs:string(./nc:TimeUnitCode)) = 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>598: VICTIM AGE TIME UNIT CODE IS INVALID</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Victim/nc:RoleOfPersonReference/@s:ref]/nc:PersonSexCode"
                 priority="1005"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Victim/nc:RoleOfPersonReference/@s:ref]/nc:PersonSexCode"/>

		    <!--REPORT error-->
<xsl:if test="string-length(.) = 1 and not(. = $fbi_codes//xsd:simpleType[@name='SEXCodeSimpleType']/xsd:restriction/xsd:enumeration/@value)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(.) = 1 and not(. = $fbi_codes//xsd:simpleType[@name='SEXCodeSimpleType']/xsd:restriction/xsd:enumeration/@value)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>528: VICTIM SEX MUST BE M/F/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim/j:VictimAggravatedAssaultHomicideFactorCode"
                 priority="1004"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim/j:VictimAggravatedAssaultHomicideFactorCode"/>

		    <!--REPORT error-->
<xsl:if test="string-length(.) &gt; 0 and string-length(.) &lt; 3 and not(. = $fbi_codes//xsd:simpleType[@name='AggravatedAssaultHomicideFactorsCodeSimpleType']/xsd:restriction/xsd:enumeration/@value)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(.) &gt; 0 and string-length(.) &lt; 3 and not(. = $fbi_codes//xsd:simpleType[@name='AggravatedAssaultHomicideFactorsCodeSimpleType']/xsd:restriction/xsd:enumeration/@value)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>542: CIRCUMSTANCE MUST BE 01 TO 10,20,21,30 TO 34</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimJustifiableHomicideFactorCode"
                 priority="1003"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimJustifiableHomicideFactorCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=".=$val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='JUSTIFIABLE_HOMICIDE_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='578']]/COLUMN[@NAME='CODE']"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=".=$val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='JUSTIFIABLE_HOMICIDE_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='578']]/COLUMN[@NAME='CODE']">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>578: INVALID JUSTIFY</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:VictimToSubjectRelationshipCode"
                 priority="1002"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:VictimToSubjectRelationshipCode"/>

		    <!--REPORT error-->
<xsl:if test="string-length(.) &gt; 0 and not(number(.) = distinct-values($vor_lookup//ROW/COLUMN[@NAME='VOR_CODE']/text()))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(.) &gt; 0 and not(number(.) = distinct-values($vor_lookup//ROW/COLUMN[@NAME='VOR_CODE']/text()))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>557: VOR MUST EQUAL 01 - 13, 20 - 25, 27 - 34, 98, OR 99 </svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1001"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--REPORT error-->
<xsl:if test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/lexslib:SameAsDigestReference) and not(exists(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/lexslib:SameAsDigestReference) and not(exists(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, ENTITY PERSON INFORMATION MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim) and not(exists(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim) and not(exists(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, ENTITY PERSON INFORMATION MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID/text())) and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID/text())) and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, VICTIM NUMBER IS MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID/text())) and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID/text())) and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, VICTIM CONNECTED OFFENSE FILE CLASS IS MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, NDEXIA:VICTIM IS MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim]))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim]))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, J:VICTIM IS MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode)) and not(count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode) = count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($isZeroRec) and $isActionOR and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode)) and not(count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/j:VictimCategoryCode) = count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, VICTIM TYPE IS MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim) = count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim) = count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, NDEXIA:VICTIM AND J:VICTIM NEED TO MATCH</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(//lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:VictimToSubjectRelationshipCode)= count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(//lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:VictimToSubjectRelationshipCode)= count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, SUBJECTVICTIMASSOCIATION/VICTIMTOSUBJECTRELATIONSHIPCODE COUNT MISSMATCH</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim]"
                 priority="1000"
                 mode="M87">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim]"/>
      <xsl:variable name="victim"
                    select="./lexsdigest:Person[@s:id = ../j:Victim/nc:RoleOfPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="victimRole"
                    select="./j:Victim[nc:RoleOfPersonReference/@s:ref = current()/lexsdigest:Person/@s:id]/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>
      <xsl:variable name="victimOffenseCodes"
                    select="for $I in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = (for $J in //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$victim] return $J)]/msp:OffenseCategoryCode   return $I"/>

		    <!--REPORT error-->
<xsl:if test="(($victimType='I' or $victimType = 'L'     or exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation))    and (some $x in $victimOffenseCodes satisfies $x = (09001, 09002, 09003, 09004, 09005, 09006, 10001, 10002, 11001, 11002, 11003, 11004, 11005, 11006, 11007, 11008, 12000, 13001, 13002, 21000, 40003, 64001, 64002)))    and (not(exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim/msp:Augmentation[lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]))) and ($victimType='I' or $victimType = 'L')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(($victimType='I' or $victimType = 'L' or exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation)) and (some $x in $victimOffenseCodes satisfies $x = (09001, 09002, 09003, 09004, 09005, 09006, 10001, 10002, 11001, 11002, 11003, 11004, 11005, 11006, 11007, 11008, 12000, 13001, 13002, 21000, 40003, 64001, 64002))) and (not(exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim/msp:Augmentation[lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]))) and ($victimType='I' or $victimType = 'L')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, MSP:VICTIM MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($victimType = 'L')    and (some $x in $victimOffenseCodes satisfies $x = (09001, 13001, 13002, 13003))    and (not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:EnforcementOfficial/j:EnforcementOfficialActivityCategoryCode)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($victimType = 'L') and (some $x in $victimOffenseCodes satisfies $x = (09001, 13001, 13002, 13003)) and (not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:EnforcementOfficial/j:EnforcementOfficialActivityCategoryCode)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, ACTIVITY TYPE IS MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($victimType = 'L')    and (some $x in $victimOffenseCodes satisfies $x = (09001, 13001, 13002, 13003))    and (not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial/j:EnforcementOfficialAssignmentCategoryCode)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($victimType = 'L') and (some $x in $victimOffenseCodes satisfies $x = (09001, 13001, 13002, 13003)) and (not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial/j:EnforcementOfficialAssignmentCategoryCode)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, ASSIGNMENT TYPE IS MISSING</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="every $x in (//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim]/lexsdigest:Person/@s:id ) satisfies //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $x"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="every $x in (//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim]/lexsdigest:Person/@s:id ) satisfies //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $x">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, NDEXIA:PERSON IS MISSING</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M87"/>
   <xsl:template match="@*|node()" priority="-2" mode="M87">
      <xsl:apply-templates select="*" mode="M87"/>
   </xsl:template>

   <!--PATTERN arrest-data-constraints-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/nc:PersonAgeMeasure"
                 priority="1004"
                 mode="M88">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/nc:PersonAgeMeasure"/>

		    <!--REPORT error-->
<xsl:if test="string-length(xs:string(./nc:MeasurePointValue)) &gt; 0 and number(./nc:MeasurePointValue) &gt; 99">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(xs:string(./nc:MeasurePointValue)) &gt; 0 and number(./nc:MeasurePointValue) &gt; 99">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>728: ARREST AGE MUST BE LESS THAN 3 CHARACTERS (<xsl:text/>
               <xsl:value-of select="./nc:MeasurePointValue"/>
               <xsl:text/>)</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="string-length(xs:string(./nc:MeasurePointValue)) &gt; 0 and translate(xs:string(./nc:MeasurePointValue), '0123456789','') != ''">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(xs:string(./nc:MeasurePointValue)) &gt; 0 and translate(xs:string(./nc:MeasurePointValue), '0123456789','') != ''">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>724: ARREST AGE  MUST BE NUMERIC</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(./nc:TimeUnitCode) or (string-length(./nc:TimeUnitCode) &gt; 0 and not(./nc:TimeUnitCode = 'ANN'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(./nc:TimeUnitCode) or (string-length(./nc:TimeUnitCode) &gt; 0 and not(./nc:TimeUnitCode = 'ANN'))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>729: ARREST AGE TIME UNIT MUST BE 'ANN'</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID"
                 priority="1003"
                 mode="M88">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID"/>

		    <!--REPORT error-->
<xsl:if test="string-length(.) &gt; 0 and translate(., '0123456789','') != ''">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(.) &gt; 0 and translate(., '0123456789','') != ''">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>722: ARREST NUMBER MUST BE NUMERIC</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="string-length(.) &gt; 0 and (number(.) &lt; 1 or number(.) &gt; 99)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(.) &gt; 0 and (number(.) &lt; 1 or number(.) &gt; 99)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>723: ARREST NUMBER MUST BE 01 to 99</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest/msp:ArrestChargeCode"
                 priority="1002"
                 mode="M88">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest/msp:ArrestChargeCode"/>

		    <!--REPORT error-->
<xsl:if test="string-length(.) &gt; 0 and translate(., '0123456789','') != ''">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(.) &gt; 0 and translate(., '0123456789','') != ''">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>725: ARREST CHARGE MUST BE NUMERIC</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity"
                 priority="1001"
                 mode="M88">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity"/>

		    <!--REPORT error-->
<xsl:if test="boolean(./nc:Activity[nc:ActivityCategoryText='Arrest']/nc:ActivityDate/nc:Date) and  not(./nc:Activity[nc:ActivityCategoryText='Arrest']/nc:ActivityDate/nc:Date/text() castable as xs:date)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean(./nc:Activity[nc:ActivityCategoryText='Arrest']/nc:ActivityDate/nc:Date) and not(./nc:Activity[nc:ActivityCategoryText='Arrest']/nc:ActivityDate/nc:Date/text() castable as xs:date)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>717: INVALID ARREST DATE</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1000"
                 mode="M88">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--REPORT error-->
<xsl:if test="(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText = 'Arrest') and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText = 'Arrest') and not(exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, msp:Arrest Missing</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest) = count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation) and count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID) = count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest) and count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID) = count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation) and count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText[text() = 'Arrest']) =  count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest) and count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText[text() = 'Arrest']) =  count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID) and count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText[text() = 'Arrest']) =  count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest) = count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation) and count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID) = count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest) and count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID) = count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation) and count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText[text() = 'Arrest']) = count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest) and count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText[text() = 'Arrest']) = count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID) and count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity/nc:ActivityCategoryText[text() = 'Arrest']) = count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, ARREST SEGMENTS DO NOT MATCH</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M88"/>
   <xsl:template match="@*|node()" priority="-2" mode="M88">
      <xsl:apply-templates select="*" mode="M88"/>
   </xsl:template>

   <!--PATTERN property-data-constraints-->


	<!--RULE -->
<xsl:template match="//msp:PropertySequenceNumberText" priority="1014" mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:PropertySequenceNumberText"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="number(text()) = number(text()) and text() &lt;= 999 and text() &gt;= 0"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="number(text()) = number(text()) and text() &lt;= 999 and text() &gt;= 0">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>213: PROPERTY ITEM NUMBER MUST BE BETWEEN 0 AND 999</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//msp:PropertyLossCode" priority="1013" mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:PropertyLossCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="distinct-values($propertyloss_lookup//ROW/COLUMN[@NAME='PROPERTYLOSS_CODE']/text()) = number(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="distinct-values($propertyloss_lookup//ROW/COLUMN[@NAME='PROPERTYLOSS_CODE']/text()) = number(.)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>962: PROPERTY TYPE MUST BE 0 to 7 OR 9</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//msp:Property" priority="1012" mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl" context="//msp:Property"/>
      <xsl:variable name="propertyItemNumber" select="./msp:PropertySequenceNumberText"/>
      <xsl:variable name="propertyCategoryCode" select="./msp:PropertyCategoryCode"/>
      <xsl:variable name="propertyLossCode" select="./msp:PropertyLossCode"/>

		    <!--REPORT error-->
<xsl:if test="(distinct-values($propertyclass_lookup//ROW/COLUMN[@NAME='PROPERTYCLASS_CODE']/text()) = number(.) or not(exists($propertyCategoryCode)))            and (exists($propertyItemNumber) and not ($propertyItemNumber = (000,00,0)))           and (exists($propertyLossCode) and not ($propertyLossCode = (0,9)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(distinct-values($propertyclass_lookup//ROW/COLUMN[@NAME='PROPERTYCLASS_CODE']/text()) = number(.) or not(exists($propertyCategoryCode))) and (exists($propertyItemNumber) and not ($propertyItemNumber = (000,00,0))) and (exists($propertyLossCode) and not ($propertyLossCode = (0,9)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>926: PROPERTY CLASS MUST BE 01-39/41-49/59/64-80/88(TWO DIGIT FIELD)</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem/ndexia:TangibleItemAugmentation/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount"
                 priority="1011"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem/ndexia:TangibleItemAugmentation/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=".&gt;=0 and number(text()) = number(text())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test=".&gt;=0 and number(text()) = number(text())">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>964: PROPERTY VALUE MUST BE NUMERIC</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(number(text()) mod 1 = 0) and not(contains(text(),'.'))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(number(text()) mod 1 = 0) and not(contains(text(),'.'))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>964: PROPERTY VALUE MUST BE A WHOLE DOLLAR AMOUNT</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem/ndexia:TangibleItemAugmentation/ndexia:ItemQuantityStatusValue/ndexia:ItemStatus/nc:StatusDate/nc:Date | //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation/ndexia:ItemQuantityStatusValue/ndexia:ItemStatus/nc:StatusDate/nc:Date"
                 priority="1010"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem/ndexia:TangibleItemAugmentation/ndexia:ItemQuantityStatusValue/ndexia:ItemStatus/nc:StatusDate/nc:Date | //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation/ndexia:ItemQuantityStatusValue/ndexia:ItemStatus/nc:StatusDate/nc:Date"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="text() castable as xs:date"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="text() castable as xs:date">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>965: PROPERTY RECOVERY DATE IS INVALID</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:StolenVehicleQuantityMeasure/nc:MeasurePointValue"
                 priority="1009"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:StolenVehicleQuantityMeasure/nc:MeasurePointValue"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=".&gt;= 0 and .&lt;=99"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test=".&gt;= 0 and .&lt;=99">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>966: STOLEN RECOVERED VEHICLES VALID RANGE IS 01 TO 99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//msp:SuspectedDrugCategoryCode" priority="1008" mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//msp:SuspectedDrugCategoryCode"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="distinct-values($drug_lookup//ROW/COLUMN[@NAME='SUSPECTED_DRUG_TYPE']/text()) =number(.) "/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="distinct-values($drug_lookup//ROW/COLUMN[@NAME='SUSPECTED_DRUG_TYPE']/text()) =number(.)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>948: DRUG TYPE MUST BE 1 to 18, 77, OR 99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode"
                 priority="1007"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode"
                       role="error"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty(text()) or $fbi_codes//xsd:simpleType[@name='DrugMeasurementCodeSimpleType']//xsd:enumeration/@value = ."/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(text()) or $fbi_codes//xsd:simpleType[@name='DrugMeasurementCodeSimpleType']//xsd:enumeration/@value = .">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>956: MEASURE MUST BE GM/KG/OZ/LB/ML/LT/FO/GL/DU/NP/XX</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1006"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--REPORT error-->
<xsl:if test="not(count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem) = count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem) = count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, NDEXIA:TANGIBLEITEM LEXSDIGEST:ENTITYTANGIBLEITEM COUNT MISMATCH</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug) = count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug) = count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, NDEXIA:DRUG LEXSDIGEST:ENTITYDRUG COUNT MISMATCH</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem) + count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug) = count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) and count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem) + count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug) = count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) and count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug) = count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem) + count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug) = count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) and count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem) + count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug) = count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) and count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug) = count(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>XML NOT FORMATTED CORRECTLY, DRUG OR PROPERTY ELEMENT COUNT MISMATCH</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem"
                 priority="1005"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:TangibleItem/@s:id)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:TangibleItem/@s:id)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, NC:TANGIBLEITEM S:ID Missing</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/@s:id)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/@s:id)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, NC:PROPERTY S:ID Missing</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/nc:RoleOfItemReference/@s:ref)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/nc:RoleOfItemReference/@s:ref)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, NC:ROLEOFITEMREFERENCE S:REF Missing</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug"
                 priority="1004"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug/@s:id)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug/@s:id)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, NC:DRUG S:ID Missing</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem"
                 priority="1003"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem/ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem/ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, LEXISDIGEST:TANGIBLEITEM REFERENCE Missing</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug"
                 priority="1002"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, LEXISDIGEST:ENTITYDRUG REFERENCE Missing</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property"
                 priority="1001"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, MSP:PROPERTY AUGMENTATION REFERENCE Missing</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug"
                 priority="1000"
                 mode="M89">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>XML NOT FORMATTED CORRECTLY, MSP:DRUG AUGMENTATION REFERENCE Missing</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M89"/>
   <xsl:template match="@*|node()" priority="-2" mode="M89">
      <xsl:apply-templates select="*" mode="M89"/>
   </xsl:template>

   <!--PATTERN admin-micr-edits-->
<xsl:variable name="biasList"
                 select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseBiasMotivationCode/text()"/>
   <xsl:variable name="weaponList"
                 select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/j:IncidentForce/j:ForceCategoryCode/text()"/>
   <xsl:variable name="siteList"
                 select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:LocationCategoryCode/text()"/>
   <xsl:variable name="isOffenseFCOnly"
                 select="empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Location/msp:LocationCategoryCode/text())             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:OffenseCompletedIndicator/text())             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/j:IncidentFactor/j:IncidentFactorCode/text())             and (empty($biasList) or (every $bias in $biasList satisfies (number($bias) = 0)))             and (empty($weaponList) or (every $weapon in $weaponList satisfies (number($weapon) = 0)))             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:CriminalActivityCategoryCode/text())             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/j:IncidentStructuresEnteredQuantity/text())             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:OffenseCargoTheftIndicator/text())             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:OffenseDomesticViolenceIndicator/text())"/>
   <xsl:variable name="isOffenseFCOnly111W"
                 select="empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:LocationCategoryCode/text())             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:OffenseCompletedIndicator/text())             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/j:IncidentFactor/j:IncidentFactorCode/text())             and (empty($biasList) or (every $bias in $biasList satisfies (number($bias) = 0)))             and (empty($weaponList) or (every $weapon in $weaponList satisfies (number($weapon) = 0)))             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:CriminalActivityCategoryCode/text())             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/j:IncidentStructuresEnteredQuantity/text())             and empty(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:OffenseDomesticViolenceIndicator/text())"/>
   <xsl:variable name="isOffenseFCOnlyForAssist"
                 select="empty($siteList) and empty($biasList)"/>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier"
                 priority="1005"
                 mode="M90">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="./lexs:ORI/text()"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="./lexs:ORI/text()">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>101: ORI REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress"
                 priority="1004"
                 mode="M90">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:StructuredAddress"/>
      <xsl:variable name="county" select="./msp:LocationCountyCode/text()"/>
      <xsl:variable name="cityTwp" select="./msp:LocationCityTownshipCode/text()"/>
      <xsl:variable name="orict_type"
                    select="$orict_lookup//ROW/COLUMN[@NAME = 'ORICT_COUNTY' and text() = $county]/../COLUMN[@NAME = 'ORICT_CITY_TWP' and text() = $cityTwp]/../COLUMN[@NAME = 'ORICT_TYPE']/text()"/>
      <xsl:variable name="isAdminORI"
                    select="(matches($ori,'MI\d{1,7}') and (substring($ori,5,1) = '0' or substring($ori,5,3) = '975')) or matches($ori,'MI\d{1,6}E') or (number(substring($ori,5,3)) &gt;= 100 and number(substring($ori,5,3)) &lt;= 183 and number(substring($ori,3,2)) = number($county))"/>
      <xsl:variable name="location_site"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Location/msp:LocationCategoryCode/text()"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(exists($county) and string-length($county) = 2 and $orict_lookup//ROW/COLUMN[@NAME = 'ORICT_COUNTY']/text() = $county ) or not($isActionOR)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(exists($county) and string-length($county) = 2 and $orict_lookup//ROW/COLUMN[@NAME = 'ORICT_COUNTY']/text() = $county ) or not($isActionOR)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>107: COUNTY MUST RANGE FROM 01 TO 83</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="./msp:LocationCityTownshipCode/text() or not($isActionOR)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="./msp:LocationCityTownshipCode/text() or not($isActionOR)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>108: CITY/TOWNSHIP IS REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty(./msp:LocationCityTownshipCode/text()) or exists($orict_lookup//ROW[COLUMN[@NAME = 'ORICT_COUNTY' and text() = $county] and COLUMN[@NAME = 'ORICT_CITY_TWP' and text() = $cityTwp]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(./msp:LocationCityTownshipCode/text()) or exists($orict_lookup//ROW[COLUMN[@NAME = 'ORICT_COUNTY' and text() = $county] and COLUMN[@NAME = 'ORICT_CITY_TWP' and text() = $cityTwp]])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>109: COUNTY/CITY TWP IS NOT VALID</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$isAdminORI or empty(./msp:LocationCountyCode/text()) or exists($ctxrf_lookup//ROW[COLUMN[@NAME = 'CTXRF_ORI' and text() = $ori] and COLUMN[@NAME = 'CTXRF_COUNTY' and text() = $county] and COLUMN[@NAME =  'CTXRF_CITY_TWP' and text() = $cityTwp]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$isAdminORI or empty(./msp:LocationCountyCode/text()) or exists($ctxrf_lookup//ROW[COLUMN[@NAME = 'CTXRF_ORI' and text() = $ori] and COLUMN[@NAME = 'CTXRF_COUNTY' and text() = $county] and COLUMN[@NAME = 'CTXRF_CITY_TWP' and text() = $cityTwp]])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>110: INVALID COUNTY NUMBER - ORI NOT VALID FOR COUNTY/CITY TWP</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="$orict_type = 'P' and $location_site != '15'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$orict_type = 'P' and $location_site != '15'">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>123: CITY/TWP IS PRISON, OFFENSE SITE MUST BE 15</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']"
                 priority="1003"
                 mode="M90">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']"/>

		    <!--REPORT error-->
<xsl:if test="($action = 'O' or $action = 'R') and ($incidentDate castable as xs:date and xs:date($incidentDate) &lt; xs:date('1950-01-01'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($action = 'O' or $action = 'R') and ($incidentDate castable as xs:date and xs:date($incidentDate) &lt; xs:date('1950-01-01'))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>111: INCIDENT DATE CANNOT BE PRIOR TO AGENCY START DATE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($incidentDate castable as xs:date and xs:date($incidentDate) &gt; current-date())">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($incidentDate castable as xs:date and xs:date($incidentDate) &gt; current-date())">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>124: INCIDENT DATE CANNOT BE A FUTURE DATE</svrl:text> 
            <svrl:diagnostic-reference diagnostic="nodeValue">
</svrl:diagnostic-reference>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="occRepDate"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()] | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/nc:Activity/nc:ActivityDate/*[text() and not(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Incident']/lexsdigest:Metadata/nc:ReportedDate/*[text()])]"/>

		    <!--REPORT warning-->
<xsl:if test="((not($action = 'W')) and not(number($incidentNumber) = 0) and (string-length($occRepDate) &lt;= 10))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((not($action = 'W')) and not(number($incidentNumber) = 0) and (string-length($occRepDate) &lt;= 10))">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: Please verify that the Hour Occurred is Unknown.  If an approximate time is known, please resubmit the incident to MICR with the correct HOUR OCC.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident"
                 priority="1002"
                 mode="M90">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident"/>
      <xsl:variable name="exClearCode"
                    select="./j:IncidentAugmentation/j:IncidentExceptionalClearanceCode"/>
      <xsl:variable name="exClearDate"
                    select="./j:IncidentAugmentation/j:IncidentExceptionalClearanceDate/nc:Date"/>
      <xsl:variable name="isFileC9004"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 9004])"/>
      <xsl:variable name="isFileC9005"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 9005])"/>
      <xsl:variable name="isFileC9006"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 9006])"/>

		    <!--REPORT error-->
<xsl:if test="exists($exClearCode/text()) and empty($exClearDate/text())">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($exClearCode/text()) and empty($exClearDate/text())">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>149: CLEAR DATE MUST BE ENTERED WHEN EXCEPTION CLEARANCE IS ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($exClearCode/text()) and exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject/nc:RoleOfPersonReference)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($exClearCode/text()) and exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject/nc:RoleOfPersonReference)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>150: ARREST INFORMATION CANNOT BE ENTERED IF EXCEPTIONAL CLEARANCE IS NOT BLANK</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($exClearCode/text()) and not($offenderExists) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '151']/../COLUMN[@NAME = 'CODE' and text() = $action])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($exClearCode/text()) and not($offenderExists) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '151']/../COLUMN[@NAME = 'CODE' and text() = $action])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>151: OFFENDER MUST BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($exClearCode/text()) and ($isFileC9004 or $isFileC9005 or $isFileC9006)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($exClearCode/text()) and ($isFileC9004 or $isFileC9005 or $isFileC9006)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>152: EXCEPTIONAL CLEAR MUST NOT BE ENTERED FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($exClearDate/text()) and empty($exClearCode/text())">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($exClearDate/text()) and empty($exClearCode/text())">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>153: EXCEPTIONAL CLEAR MUST BE ENTERED WHEN CLEAR DATE IS ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty($exClearDate/text()) or xs:date($exClearDate) &gt;= xs:date($incidentDate)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($exClearDate/text()) or xs:date($exClearDate) &gt;= xs:date($incidentDate)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>113: CLEAR DATE CANNOT BE PRIOR TO INCIDENT DATE</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization[./ndexia:OrganizationAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$assistOriId]]"
                 priority="1001"
                 mode="M90">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization[./ndexia:OrganizationAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$assistOriId]]"/>
      <xsl:variable name="assistOri"
                    select="./j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID/text()"/>
      <xsl:variable name="isVictimAssist"
                    select="exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/nc:PersonOrganizationAssociation[nc:PersonReference/@s:ref = ../../lexsdigest:EntityPerson/j:Victim/nc:RoleOfPersonReference/@s:ref][nc:OrganizationReference/@s:ref = $assistOriId])"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$assistOri != $ori or $isVictimAssist"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="$assistOri != $ori or $isVictimAssist">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>111: ASSIST ORI CANNOT BE SAME AS ORI</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="exists($assistOriId) and not($isVictimAssist) and not($isOffenseFCOnly)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($assistOriId) and not($isVictimAssist) and not($isOffenseFCOnly)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>111: FIELDS (SITE THROUGH PREMIS) MUST NOT BE ENTERED FOR ASSISTS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($assistOriId) and not($isVictimAssist) and not($isOffenseFCOnlyForAssist)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($assistOriId) and not($isVictimAssist) and not($isOffenseFCOnlyForAssist)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>111: FIELDS (SITE THROUGH PREMIS) MUST NOT BE ENTERED FOR ASSISTS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($assistOriId) and not($isVictimAssist) and $victimExists">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($assistOriId) and not($isVictimAssist) and $victimExists">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>111: VICTIM INFORMATION MUST NOT BE ENTERED FOR ASSISTS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($assistOriId) and not($isVictimAssist) and $offenderExists">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($assistOriId) and not($isVictimAssist) and $offenderExists">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>111: OFFENDER INFORMATION MUST NOT BE ENTERED FOR ASSISTS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($assistOriId) and not($isVictimAssist) and $arrestExists">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($assistOriId) and not($isVictimAssist) and $arrestExists">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>111: ARREST INFORMATION MUST NOT BE ENTERED FOR ASSISTS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($assistOriId) and not($isVictimAssist) and $propertyExists">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($assistOriId) and not($isVictimAssist) and $propertyExists">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>111: PROPERTY INFORMATION MUST NOT BE ENTERED FOR ASSISTS</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident"
                 priority="1000"
                 mode="M90">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists(./msp:IncidentCompleteIndicator) and boolean(./msp:IncidentCompleteIndicator) = (true(),false())"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="exists(./msp:IncidentCompleteIndicator) and boolean(./msp:IncidentCompleteIndicator) = (true(),false())">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>106: INCIDENT COMPLETE MUST BE Y OR N</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M90"/>
   <xsl:template match="@*|node()" priority="-2" mode="M90">
      <xsl:apply-templates select="*" mode="M90"/>
   </xsl:template>

   <!--PATTERN offense-micr-edits-->
<xsl:variable name="offenseFileClass"
                 select="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"/>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport"
                 priority="1004"
                 mode="M91">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport"/>
      <xsl:variable name="cityTownship"
                    select="./msp:StructuredAddress/msp:LocationCityTownshipCode/text()"/>
      <xsl:variable name="county"
                    select="./msp:StructuredAddress/msp:LocationCountyCode/text()"/>
      <xsl:variable name="site" select="./msp:Offense/msp:LocationCategoryCode/text()"/>

		    <!--REPORT error-->
<xsl:if test="some $x in $site satisfies ($orict_lookup//ROW[COLUMN[@NAME = 'ORICT_COUNTY' and text() = $county] and COLUMN[@NAME='ORICT_CITY_TWP' and text() = $cityTownship]]/COLUMN[@NAME = 'ORICT_TYPE']/text()='R' and $site != '15')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="some $x in $site satisfies ($orict_lookup//ROW[COLUMN[@NAME = 'ORICT_COUNTY' and text() = $county] and COLUMN[@NAME='ORICT_CITY_TWP' and text() = $cityTownship]]/COLUMN[@NAME = 'ORICT_TYPE']/text()='R' and $site != '15')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>123: CITY/TWP IS PRISON, OFFENSE SITE MUST BE 15</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(exists(./msp:Offense/msp:OffenseCategoryCode/text())) and $isActionOR and not($isZeroRec)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(exists(./msp:Offense/msp:OffenseCategoryCode/text())) and $isActionOR and not($isZeroRec)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>144: FILE CLASS IS REQUIRED FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="count(./msp:Offense/msp:OffenseCategoryCode/text()) = count(distinct-values(./msp:Offense/msp:OffenseCategoryCode/text()))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(./msp:Offense/msp:OffenseCategoryCode/text()) = count(distinct-values(./msp:Offense/msp:OffenseCategoryCode/text()))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>156: CANNOT HAVE DUPLICATE FILE CLASSES</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="some $x in ./msp:Offense/msp:OffenseCategoryCode satisfies(exists($x/../msp:CriminalActivityCategoryCode/text()) and not($x/text() = (24002,25000,28000,35001,35002,37000,39000,39003,52001 to 52003,09001,09002,10001,10002,11001 to 11008,12000,13001 to 13003, 72000)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="some $x in ./msp:Offense/msp:OffenseCategoryCode satisfies(exists($x/../msp:CriminalActivityCategoryCode/text()) and not($x/text() = (24002,25000,28000,35001,35002,37000,39000,39003,52001 to 52003,09001,09002,10001,10002,11001 to 11008,12000,13001 to 13003, 72000)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>208: ACTIVITY TYPE CANNOT BE ENTERED FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="some $x in ./msp:Offense/msp:OffenseCategoryCode satisfies(not (exists(//ndexia:IncidentReport/ndexia:Offense[ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref=$x/../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/ndexia:OffenseCargoTheftIndicator/text())) and ($x/text() = (12000,21000,22001,22002,23003,23005,23007,24001,24003,26001 to 26003,26005,26007,26008,27000,30001,30003,51000)) and not(exists($assistOriId)) and not($action = 'W'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="some $x in ./msp:Offense/msp:OffenseCategoryCode satisfies(not (exists(//ndexia:IncidentReport/ndexia:Offense[ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref=$x/../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/ndexia:OffenseCargoTheftIndicator/text())) and ($x/text() = (12000,21000,22001,22002,23003,23005,23007,24001,24003,26001 to 26003,26005,26007,26008,27000,30001,30003,51000)) and not(exists($assistOriId)) and not($action = 'W'))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>224: CARGO THEFT MUST BE Y OR N</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:OffenseCargoTheftIndicator/text()) and not($offenseFileClasses = (12000,21000,22001,22002,23003,23005,23007,24001,24003,26001 to 26003,26005,26007,26008,27000,30001,30003,51000))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:OffenseCargoTheftIndicator/text()) and not($offenseFileClasses = (12000,21000,22001,22002,23003,23005,23007,24001,24003,26001 to 26003,26005,26007,26008,27000,30001,30003,51000))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>226: CARGO THEFT CANNOT BE ENTERED FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense"
                 priority="1003"
                 mode="M91">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense"/>

		    <!--REPORT error-->
<xsl:if test="empty(./msp:OffenseCategoryCode/text())">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty(./msp:OffenseCategoryCode/text())">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>155: FILE CLASS 1 REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty(./msp:CriminalActivityCategoryCode/text()[exists(index-of(current()/msp:CriminalActivityCategoryCode/text(), .)[2])])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty(./msp:CriminalActivityCategoryCode/text()[exists(index-of(current()/msp:CriminalActivityCategoryCode/text(), .)[2])])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>173: ACTIVITY TYPE CANNOT BE DUPLICATED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="empty(./msp:LocationCategoryCode/text()) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '200']/../COLUMN[@NAME = 'CODE' and text() = $action]) and not(exists($assistOriId))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty(./msp:LocationCategoryCode/text()) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '200']/../COLUMN[@NAME = 'CODE' and text() = $action]) and not(exists($assistOriId))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>200: SITE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"
                 priority="1002"
                 mode="M91">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"/>
      <xsl:variable name="offenseFileClass" select="./text()"/>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '140']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and $isActionOR and not($victimExist) and not(exists($assistOriId))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '140']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and $isActionOR and not($victimExist) and not(exists($assistOriId))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>140: VICTIM INFORMATION IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean(every $x in (../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref) satisfies $x = (//lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref))) and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '1001']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and $isActionOR and not(exists($assistOriId))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean(every $x in (../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref) satisfies $x = (//lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref))) and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '1001']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and $isActionOR and not(exists($assistOriId))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>140: VICTIM INFORMATION IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '157']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and $isActionOR and ($offenseCount &gt; 1) and not($offenseFileClass = '09004' and $offenses = (09005,09006))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '157']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and $isActionOR and ($offenseCount &gt; 1) and not($offenseFileClass = '09004' and $offenses = (09005,09006))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>157: FILE CLASS 09004/75000/77000 SHOULD OCCUR ALONE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '158']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and $isActionOR and ($offenseCount &gt; 1) and ($offenseFileClass = '09005' or $offenseFileClass = '09006') and not($offenses = (09001,09004))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '158']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and $isActionOR and ($offenseCount &gt; 1) and ($offenseFileClass = '09005' or $offenseFileClass = '09006') and not($offenses = (09001,09004))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>158:FILE CLASS 09005 AND 09006 MAY OCCUR WITH A SECONDARY FILE CLASS IF IT IS EITHER IS 09001 OR 09004</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '312']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and not($offenderExist) and not(exists($assistOriId))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '312']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass]) and not($offenderExist) and not(exists($assistOriId))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>312: OFFENDER Number, AGE, RACE, AND SEX REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:OffenseCompletedIndicator"
                 priority="1001"
                 mode="M91">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:OffenseCompletedIndicator"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="./text() or not($isActionOR)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="./text() or not($isActionOR)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>202: ATTEMPT IS REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Offense'][@s:id  = ../../../lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]"
                 priority="1000"
                 mode="M91">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Offense'][@s:id  = ../../../lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]"/>
      <xsl:variable name="offenseId" select="@s:id"/>
      <xsl:variable name="fileClass"
                    select="//lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>
      <xsl:variable name="locationId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseLocationAssociation/nc:LocationReference/@s:ref[../../nc:ActivityReference/@s:ref=$offenseId]"/>
      <xsl:variable name="locationSite"
                    select="//lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:LocationCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>
      <xsl:variable name="offenseAttempted"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenseId]/../../ndexia:OffenseCompletedIndicator"/>
      <xsl:variable name="offenderUsed"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenseId]/../../j:IncidentFactor/j:IncidentFactorCode"/>
      <xsl:variable name="suspectedBias"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenseId]/../../msp:OffenseBiasMotivationCode"/>
      <xsl:variable name="weaponType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenseId]/../../j:IncidentForce/j:ForceCategoryCode"/>
      <xsl:variable name="activityType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenseId]/../../msp:CriminalActivityCategoryCode"/>
      <xsl:variable name="premisesEntered"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenseId]/../../j:IncidentStructuresEnteredQuantity"/>
      <xsl:variable name="cargoTheftIndicator"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenseId]/../../ndexia:OffenseCargoTheftIndicator"/>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '141']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $isActionOR and $offenseAttempted = true() and not($propertyExist)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '141']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $isActionOR and $offenseAttempted = true() and not($propertyExist)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>141: PROPERTY INFORMATION IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(some $x in $fileClass satisfies $x = (22001,22002)) and not($premisesEntered = '00') and not(some $x in $locationSite satisfies $x = (14,19)) and exists($premisesEntered)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(some $x in $fileClass satisfies $x = (22001,22002)) and not($premisesEntered = '00') and not(some $x in $locationSite satisfies $x = (14,19)) and exists($premisesEntered)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>159: SITE MUST BE 14 OR 19 WHEN PREMISE 1 IS GREATER THAN 0</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_ATTEMPTED_COMPLETED']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '161']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $offenseAttempted = false()">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_ATTEMPTED_COMPLETED']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '161']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $offenseAttempted = false()">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>161: ATTEMPT FOR OFFENSE MUST BE TRUE(C)</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '162']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $offenseAttempted = false() and not((some $x in $propertyLoss satisfies $x = 0,9))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '162']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $offenseAttempted = false() and not((some $x in $propertyLoss satisfies $x = 0,9))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>162: PROPERTY LOSS TYPE OF 0 OR 9 MUST BE ENTERED FOR ATTEMPTS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="empty($offenderUsed[index-of($offenderUsed,.)[2]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="empty($offenderUsed[index-of($offenderUsed,.)[2]])">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>163: USED CANNOT BE DUPLICATED IN OFFENSE</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="count($offenderUsed) &gt; 1 and count(index-of($offenderUsed, 'N')) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count($offenderUsed) &gt; 1 and count(index-of($offenderUsed, 'N')) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>164: USED = N MUST OCCUR ALONE FOR AN OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'WEAPON_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '167']/../COLUMN[@NAME = 'CODE' and text() = $weaponType])) and ($fileClass = '13001' and $isActionOR and not(exists($assistOriId)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'WEAPON_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '167']/../COLUMN[@NAME = 'CODE' and text() = $weaponType])) and ($fileClass = '13001' and $isActionOR and not(exists($assistOriId)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>167: WEAPON MUST BE 00/40/88/99 FOR 13001</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($fileClass = '13002') and ($weaponType = '99') and not(exists($assistOriId))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($fileClass = '13002') and ($weaponType = '99') and not(exists($assistOriId))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>167: WEAPON MUST NOT BE 00 FOR 13002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'WEAPON_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '168']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and ($weaponType = '99')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'WEAPON_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '168']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and ($weaponType = '99')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>168: WEAPON = 00 IS NOT VALID FOR 09001, 09002, 09004, 09005 OR 09006</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="string-length(normalize-space($weaponType)) &gt; 2 and not(substring($weaponType,3,1) = 'A')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="string-length(normalize-space($weaponType)) &gt; 2 and not(substring($weaponType,3,1) = 'A')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>169: 3RD CHARACTER OF WEAPON MUST BE A OR BLANK</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(($isActionOR and not(exists($assistOriId)) and not(every $x in $activityType satisfies $x = ('B','C','D','E','O','P','T','U'))    and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER'    and text() = '170']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]))    or (boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '170']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and not(boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '170']/../COLUMN[@NAME = 'CODE' and text() = $activityType])) and $isActionOR and not(exists($assistOriId))))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(($isActionOR and not(exists($assistOriId)) and not(every $x in $activityType satisfies $x = ('B','C','D','E','O','P','T','U')) and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '170']/../COLUMN[@NAME = 'CODE' and text() = $fileClass])) or (boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '170']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and not(boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '170']/../COLUMN[@NAME = 'CODE' and text() = $activityType])) and $isActionOR and not(exists($assistOriId))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>170: ACTIVITY Must Be B/C/D/E/O/P/T/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($activityType) and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '171']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and not(boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '171']/../COLUMN[@NAME = 'CODE' and text() = $activityType])) and not(exists($assistOriId)) and $isActionOR">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($activityType) and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '171']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and not(boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTIVITY_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '171']/../COLUMN[@NAME = 'CODE' and text() = $activityType])) and not(exists($assistOriId)) and $isActionOR">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>171: ACTIVITY Must Be J/G/N</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$activityType = 'N' and count($activityType) &gt; 1">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$activityType = 'N' and count($activityType) &gt; 1">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>172: IF ACTIVITY TYPE 'N' ENTERED, NO OTHER ACTIVITY TYPE CAN BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'PREMISES_ENTERED']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '174']/../COLUMN[@NAME = 'CODE' and text() = $locationSite]) and (some $x in $locationSite satisfies $x = (14,19)) and not(empty($premisesEntered)) and ($premisesEntered = '00')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'PREMISES_ENTERED']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '174']/../COLUMN[@NAME = 'CODE' and text() = $locationSite]) and (some $x in $locationSite satisfies $x = (14,19)) and not(empty($premisesEntered)) and ($premisesEntered = '00')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>174: SITE CANNOT BE 14 OR 19 WHEN PREMISE IS BLANK OR 0</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'PREMISES_ENTERED']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '174']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'PREMISES_ENTERED']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '174']/../COLUMN[@NAME = 'CODE' and text() = $locationSite]) and $isActionOR and empty($premisesEntered)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'PREMISES_ENTERED']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '174']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'PREMISES_ENTERED']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '174']/../COLUMN[@NAME = 'CODE' and text() = $locationSite]) and $isActionOR and empty($premisesEntered)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>174: PREMISE REQUIRED IF SITE IS 14 OR 19</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($fileClass = '72000' and not(exists($activityType)) and $isActionOR and not(exists($assistOriId))) or ($fileClass = '72000' and not(every $x in $activityType satisfies $x = ('A','I','F','S')) and $isActionOR and not(exists($assistOriId)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($fileClass = '72000' and not(exists($activityType)) and $isActionOR and not(exists($assistOriId))) or ($fileClass = '72000' and not(every $x in $activityType satisfies $x = ('A','I','F','S')) and $isActionOR and not(exists($assistOriId)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>176: Activity Must be A/I/F/S</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '203']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $offenseAttempted = true()">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '203']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $offenseAttempted = true()">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>203: ATTEMPT MUST BE A(FALSE) FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'SUSPECTED_BIAS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '205']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $isActionOR and empty($suspectedBias) and not(exists($assistOriId))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'SUSPECTED_BIAS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '205']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $isActionOR and empty($suspectedBias) and not(exists($assistOriId))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>205: BIAS IS REQUIRED FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'WEAPON_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '206']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $isActionOR and empty($weaponType) and not(exists($assistOriId))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'WEAPON_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '206']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $isActionOR and empty($weaponType) and not(exists($assistOriId))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>145: WEAPON IS REQUIRED FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(not(empty($premisesEntered)) and not(some $x in $fileClass satisfies $x = (22001,22002) and (some $x in $locationSite satisfies $x = (14,19)))) and not(some $x in $fileClass satisfies $x = (22001,22002) and not(some $x in $locationSite satisfies $x = (14,19)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(not(empty($premisesEntered)) and not(some $x in $fileClass satisfies $x = (22001,22002) and (some $x in $locationSite satisfies $x = (14,19)))) and not(some $x in $fileClass satisfies $x = (22001,22002) and not(some $x in $locationSite satisfies $x = (14,19)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>210: PREMISE IS NOT REQUIRED FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'WEAPON_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '206']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $isActionOR and exists($weaponType)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'WEAPON_TYPE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '206']/../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and $isActionOR and exists($weaponType)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>223: WEAPON CANNOT BE ENTERED FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'CYBERSPACE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '230']/../COLUMN[@NAME = 'CODE' and text() = $fileClass])) and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'CYBERSPACE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '230']/../COLUMN[@NAME = 'CODE' and text() = $locationSite])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'CYBERSPACE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '230']/../COLUMN[@NAME = 'CODE' and text() = $fileClass])) and boolean($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'CYBERSPACE']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '230']/../COLUMN[@NAME = 'CODE' and text() = $locationSite])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>230: LOCATION 58 CANNOT BE USED WITH THIS OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="$suspectedBias = '88'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$suspectedBias = '88'">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: Please verify an actual bias/hate crime was involved. If, so please attempt to code the bias in a more appropriate bias category rather than OTHER</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="$weaponType = '90'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$weaponType = '90'">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: The listed incident has a weapon type of 88(other).  Please attempt to classify the weapon more specifically</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M91"/>
   <xsl:template match="@*|node()" priority="-2" mode="M91">
      <xsl:apply-templates select="*" mode="M91"/>
   </xsl:template>

   <!--PATTERN offender-micr-edits-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference"
                 priority="1002"
                 mode="M92">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/j:Subject/nc:RoleOfOrganizationReference"/>
      <xsl:variable name="subjectId" select="../@s:id"/>
      <xsl:variable name="offenderId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject[@s:id = $subjectId]/nc:RoleOfPersonReference/@s:ref"/>
      <xsl:variable name="offenderNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $subjectId]/ndexia:SubjectSequenceNumberText/text()"/>
      <xsl:variable name="offenderAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonAgeMeasure/nc:MeasurePointValue[../../@s:id = $offenderId]/text()"/>
      <xsl:variable name="offenderSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = $offenderId]/nc:PersonSexCode/text()"/>
      <xsl:variable name="offenderRace"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/ndexia:PersonRaceCode[../lexslib:SameAsDigestReference/@lexslib:ref = $offenderId]"/>
      <xsl:variable name="isAgeSexRaceComplete"
                    select="exists($offenderAge) and exists($offenderRace) and exists($offenderSex)"/>
      <xsl:variable name="isFileC9004"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 9004])"/>
      <xsl:variable name="isFileC9005"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 9005])"/>
      <xsl:variable name="isVor01"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation[./msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:SubjectPersonReference/@s:ref = $offenderId]/@s:id]/msp:VictimToSubjectRelationshipCode[text() = '01'])"/>
      <xsl:variable name="isVor27"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation[./msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:SubjectPersonReference/@s:ref = $offenderId]/@s:id]/msp:VictimToSubjectRelationshipCode[text() = '27'])"/>
      <xsl:variable name="relatedVictims"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:SubjectPersonReference/@s:ref = $offenderId]/lexsdigest:VictimPersonReference/@s:ref]/j:Victim/@s:id"/>
      <xsl:variable name="allOffenderAges"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonAgeMeasure[nc:MeasurePointValue and ../@s:id = ../../j:Subject/nc:RoleOfPersonReference/@s:ref]/nc:MeasurePointValue/text()"/>
      <xsl:variable name="allOffenderSexCodes"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonSexCode[../@s:id = ../../j:Subject/nc:RoleOfPersonReference/@s:ref]/text()"/>
      <xsl:variable name="allOffenderRaceCodes"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/ndexia:PersonRaceCode[../lexslib:SameAsDigestReference/@lexslib:ref = ../../../../../lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference/@s:ref]/text()"/>

		    <!--REPORT error-->
<xsl:if test="number($offenderNumber) = 0 and ((exists($offenderAge) and not(number($offenderAge) = 0)) or exists($offenderRace) or exists($offenderSex))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($offenderNumber) = 0 and ((exists($offenderAge) and not(number($offenderAge) = 0)) or exists($offenderRace) or exists($offenderSex))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>300: OFFENDER AGE, SEX, AND RACE MUST NOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(($isFileC9004 or $isFileC9005) and not(exists($assistOriId)) and (not($isAgeSexRaceComplete) or not($offenderExist)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(($isFileC9004 or $isFileC9005) and not(exists($assistOriId)) and (not($isAgeSexRaceComplete) or not($offenderExist)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>312: OFFENDER AGE, RACE, AND SEX REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($isFileC9004) and number($offenderNumber) = 0 and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '151']/../COLUMN[@NAME = 'CODE' and text() = $action])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($isFileC9004) and number($offenderNumber) = 0 and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '151']/../COLUMN[@NAME = 'CODE' and text() = $action])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>151: OFFENDER NUMBER CANNOT BE 0</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($isExClear) and ((every $x in $allOffenderAges satisfies number($x) = 0) or (every $x in $allOffenderSexCodes satisfies $x = 'U') or (every $x in $allOffenderRaceCodes satisfies $x = 'U')) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '151']/../COLUMN[@NAME = 'CODE' and text() = $action])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($isExClear) and ((every $x in $allOffenderAges satisfies number($x) = 0) or (every $x in $allOffenderSexCodes satisfies $x = 'U') or (every $x in $allOffenderRaceCodes satisfies $x = 'U')) and not($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'ACTION']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '151']/../COLUMN[@NAME = 'CODE' and text() = $action])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>301: OFFENDER NUMBER, AGE, SEX AND RACE REQUIRED FOR EXCEPT CLEAR</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="exists($offenderNumber)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists($offenderNumber)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>305: OFFENDER MUST BE  0 to 99</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(empty($offenderAge) and number($offenderNumber) = 0) or exists($offenderAge)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(empty($offenderAge) and number($offenderNumber) = 0) or exists($offenderAge)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>306: OFFENDER AGE IS REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT error-->
<xsl:if test="($isVor01 or $isVor27) and exists($offenderAge) and number($offenderAge) &lt; 13">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($isVor01 or $isVor27) and exists($offenderAge) and number($offenderAge) &lt; 13">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>302: OFFENDER AGE CANNOT BE LESS THAN 13</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$offenderAge &gt; 16 and (some $victim in $relatedVictims satisfies //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victim]/j:VictimAggravatedAssaultHomicideFactorCode = '30')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenderAge &gt; 16 and (some $victim in $relatedVictims satisfies //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victim]/j:VictimAggravatedAssaultHomicideFactorCode = '30')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>307: OFFENDER AGE MUST BE &lt;17 FOR ASSAULT CIRCUMSTANCE 30</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(empty($offenderRace) and number($offenderNumber) = 0) or exists($offenderRace)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(empty($offenderRace) and number($offenderNumber) = 0) or exists($offenderRace)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>308: OFFENDER RACE IS REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(empty($offenderSex) and number($offenderNumber) = 0) or exists($offenderSex)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(empty($offenderSex) and number($offenderNumber) = 0) or exists($offenderSex)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>309: OFFENDER SEX IS REQUIRED</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
<xsl:if test="number($offenderAge) = (1 to 6,99)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($offenderAge) = (1 to 6,99)">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: Please verify the age of the offender(s) is 01-06 or 99 years or older.  Unknown offender(s) age should be reported as 00.  If changes are required, please submit with the next MICR submission.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Person"
                 priority="1001"
                 mode="M92">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Person"/>
      <xsl:variable name="offenderEthnic" select="./msp:PersonEthnicityCode"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = current()/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offender]"/>

		    <!--REPORT error-->
<xsl:if test="boolean($offender) and boolean($offenderEthnic) and not ($offenderEthnic = $ethinicity_lookup//ROW/COLUMN[@NAME='ETHINICITY_CODE']/text()) and             count($offenderArrestSubject) = 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($offender) and boolean($offenderEthnic) and not ($offenderEthnic = $ethinicity_lookup//ROW/COLUMN[@NAME='ETHINICITY_CODE']/text()) and count($offenderArrestSubject) = 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>310: OFFENDER ETHNICITY MUST EQUAL A, H, O, OR U</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"
                 priority="1000"
                 mode="M92">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage"/>

		    <!--REPORT error-->
<xsl:if test="mspfx:error-315()">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="mspfx:error-315()">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="mspfx:error-message('315')"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M92"/>
   <xsl:template match="@*|node()" priority="-2" mode="M92">
      <xsl:apply-templates select="*" mode="M92"/>
   </xsl:template>

   <!--PATTERN victim-micr-edits-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim"
                 priority="1018"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim"/>
      <xsl:variable name="victimNumber"
                    select="./ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText"/>
      <xsl:variable name="victimOffenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim/@s:id = current()/ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:VictimPersonReference/@s:ref = $victimOffenseId]/lexsdigest:SubjectPersonReference/@s:ref]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenderSexList"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:VictimPersonReference/@s:ref = $victimOffenseId]/lexsdigest:SubjectPersonReference/@s:ref]/lexsdigest:Person/nc:PersonSexCode"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$victimOffenseId]"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>
      <xsl:variable name="victimRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim[@s:id = current()/ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="victimType" select="./j:VictimCategoryCode"/>
      <xsl:variable name="offenseBias"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $offenseId]/msp:OffenseBiasMotivationCode"/>
      <xsl:variable name="subject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject[$offender = nc:RoleOfPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="offenderNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $subject]/ndexia:SubjectSequenceNumberText"/>
      <xsl:variable name="victimJustifiedHomicide"
                    select="./j:VictimJustifiableHomicideFactorCode"/>
      <xsl:variable name="victim"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim/@s:id = current()/ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref and j:Victim/nc:RoleOfPersonReference/@s:ref = lexsdigest:Person/@s:id]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="victimCircumstance"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimAggravatedAssaultHomicideFactorCode"/>
      <xsl:variable name="victimSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim/@s:id = current()/ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref and j:Victim/nc:RoleOfPersonReference/@s:ref = lexsdigest:Person/@s:id]/lexsdigest:Person/nc:PersonSexCode"/>
      <xsl:variable name="victimSubjectAssocId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:VictimPersonReference[@s:ref=$victim]/..//@s:id"/>
      <xsl:variable name="offenderId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id =$victimSubjectAssocId]/lexsdigest:SubjectPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="subjectId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject[$offenderId = nc:RoleOfPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="offenderNumberForVOR"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $subjectId]/ndexia:SubjectSequenceNumberText"/>
      <xsl:variable name="vor"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:VictimToSubjectRelationshipCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$victimSubjectAssocId]"/>
      <xsl:variable name="isVor31" select="$vor/text()= '31'"/>
      <xsl:variable name="isVor01" select="$vor/text()= '01'"/>
      <xsl:variable name="offenderNumbers"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText"/>

		    <!--REPORT error-->
<xsl:if test="$isVor31 and (count(distinct-values($offenderNumberForVOR)) != count($offenderNumberForVOR))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isVor31 and (count(distinct-values($offenderNumberForVOR)) != count($offenderNumberForVOR))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>583: VICTIM RECORD CANNOT HAVE DUPLICATE OFFENDER NUMBER</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$isVor01 and (count(distinct-values($vor)) != count($vor))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isVor01 and (count(distinct-values($vor)) != count($vor))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>564: ONLY ONE VOR CAN HAVE THE VALUE 01</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($victimNumber)) and not ($victimNumber = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='JUSTIFIABLE_HOMICIDE_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='147']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($victimNumber)) and not ($victimNumber = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='JUSTIFIABLE_HOMICIDE_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='147']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>147: VICTIM NUMBER IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimNumber) and not(boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:PersonReference/@s:ref = $victimOffenseId])) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimNumber) and not(boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:PersonReference/@s:ref = $victimOffenseId])) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>500: VICTIM OFFENSE 1 IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" not(boolean($victimType)) and boolean(./ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($victimType)) and boolean(./ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>501: VICTIM TYPE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='514']]/COLUMN[@NAME='CODE']) and             ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='514']]/COLUMN[@NAME='CODE'] = $offenseCode) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='514']]/COLUMN[@NAME='CODE']) and ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='514']]/COLUMN[@NAME='CODE'] = $offenseCode) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>514: VICTIM TYPE MUST BE I/P FOR CRIME AGAINST PERSON</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='515']]/COLUMN[@NAME='CODE']) and             ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='515']]/COLUMN[@NAME='CODE'] = $offenseCode) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='515']]/COLUMN[@NAME='CODE']) and ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='515']]/COLUMN[@NAME='CODE'] = $offenseCode) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>515: VICTIM TYPE MUST BE I/P/S</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='517']]/COLUMN[@NAME='CODE']) and             ( $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='517']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='517']]/COLUMN[@NAME='CODE']) and ( $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='517']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>517: VICTIM TYPE MUST BE S</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='516']]/COLUMN[@NAME='CODE']) and             ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='516']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='516']]/COLUMN[@NAME='CODE']) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='516']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>516: VICTIM TYPE CANNOT BE S</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='597']]/COLUMN[@NAME='CODE']) and             ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='597']]/COLUMN[@NAME='CODE'] = $offenseCode) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='597']]/COLUMN[@NAME='CODE']) and ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='597']]/COLUMN[@NAME='CODE'] = $offenseCode) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>597:  VICTIM TYPE MUST BE S (SOCIETY) FOR THIS OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='572']]/COLUMN[@NAME='CODE']) and             ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='572']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='572']]/COLUMN[@NAME='CODE']) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='572']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>572: VICTIM TYPE MUST BE I FOR 10002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='597A']]/COLUMN[@NAME='CODE']) and             ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='597A']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='597A']]/COLUMN[@NAME='CODE']) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='597A']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>598:  VICTIM TYPE MUST BE I</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='518']]/COLUMN[@NAME='CODE']) and             ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='518']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='518']]/COLUMN[@NAME='CODE']) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='518']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>518: VICTIM TYPE MUST BE G/I/P</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='519']]/COLUMN[@NAME='CODE']) and             ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='519']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='519']]/COLUMN[@NAME='CODE']) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='519']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>519: VICTIM TYPE MUST BE G/I/P/S</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='554']]/COLUMN[@NAME='CODE']) and             count($offenderNumber) &gt; 0 and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='554']]/COLUMN[@NAME='CODE']) and count($offenderNumber) &gt; 0 and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>554: VICTIM TYPE MUST BE I/P IF OFFENDER IS ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimJustifiedHomicide) and not((for $I in $offenseCode  return number($I))= $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='577']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimJustifiedHomicide) and not((for $I in $offenseCode return number($I))= $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='577']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>577: JUSTIFY MUST BE BLANK</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($victimJustifiedHomicide)) and ((for $I in $offenseCode return number($I)) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='551']]/COLUMN[@NAME='CODE'] )">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($victimJustifiedHomicide)) and ((for $I in $offenseCode return number($I)) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='551']]/COLUMN[@NAME='CODE'] )">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>551: JUSTIFY IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimJustifiedHomicide) and ((for $I in $offenseCode return $I) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='550']]/COLUMN[@NAME='CODE'] ) and             not ($victimJustifiedHomicide =  ($fbi_codes//xsd:simpleType[@name='JustifiableHomicideFactorsCodeSimpleType']//xsd:enumeration/@value))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimJustifiedHomicide) and ((for $I in $offenseCode return $I) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='550']]/COLUMN[@NAME='CODE'] ) and not ($victimJustifiedHomicide = ($fbi_codes//xsd:simpleType[@name='JustifiableHomicideFactorsCodeSimpleType']//xsd:enumeration/@value))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>550: JUSTIFY MUST BE 1 to 6, 9</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimJustifiedHomicide) and ((for $I in $offenseCode return $I)  = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='576']]/COLUMN[@NAME='CODE'] ) and             ($victimJustifiedHomicide = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='JUSTIFIABLE_HOMICIDE_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='576']]/COLUMN[@NAME='CODE']) and             ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='576']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimJustifiedHomicide) and ((for $I in $offenseCode return $I) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='576']]/COLUMN[@NAME='CODE'] ) and ($victimJustifiedHomicide = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='JUSTIFIABLE_HOMICIDE_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='576']]/COLUMN[@NAME='CODE']) and ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='576']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>576: JUSTIFY CANNOT BE 1 OR 2 WHEN CIRCUMSTANCE IS 20</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(($offenderNumberForVOR = 0) or (not(every $vor in //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:VictimPersonReference/@s:ref = $victimOffenseId] satisfies exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = $vor/lexsdigest:SubjectPersonReference/@s:ref]))))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(($offenderNumberForVOR = 0) or (not(every $vor in //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:VictimPersonReference/@s:ref = $victimOffenseId] satisfies exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = $vor/lexsdigest:SubjectPersonReference/@s:ref]))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>580: OFFENDER RECORD DOES NOT EXIST FOR OFFENDER IN VOR</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:VictimPersonReference/@s:ref = $victimOffenseId]/lexsdigest:SubjectPersonReference/@s:ref) &gt; count(distinct-values(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:VictimPersonReference/@s:ref = $victimOffenseId]/lexsdigest:SubjectPersonReference/@s:ref))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:VictimPersonReference/@s:ref = $victimOffenseId]/lexsdigest:SubjectPersonReference/@s:ref) &gt; count(distinct-values(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:VictimPersonReference/@s:ref = $victimOffenseId]/lexsdigest:SubjectPersonReference/@s:ref))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>555: OFFENDER MUST NOT BE DUPLICATED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(boolean($vor) and (every $x in $offenderSexList satisfies ($x = ($victimSex)) or ($victimSex='U' and $offenderSexList=('M','F'))) and $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS']     and COLUMN[@NAME='ERROR_NUMBER' and .='560']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(boolean($vor) and (every $x in $offenderSexList satisfies ($x = ($victimSex)) or ($victimSex='U' and $offenderSexList=('M','F'))) and $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='560']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>560: VICTIM/OFFENDER MUST BE OPPOSITE SEX</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($vor)) and $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='599']]/COLUMN[@NAME='CODE'] and $victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='599']]/COLUMN[@NAME='CODE'] and (some $n in $offenderNumbers satisfies (number($n) &gt; 0))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($vor)) and $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='599']]/COLUMN[@NAME='CODE'] and $victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='599']]/COLUMN[@NAME='CODE'] and (some $n in $offenderNumbers satisfies (number($n) &gt; 0))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>599: VICTIM TO OFFENDER RELATIONSHIP (VOR) IS REQUIRED WITH THIS OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport"
                 priority="1017"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport"/>

		    <!--REPORT error-->
<xsl:if test="count(distinct-values(data(for $I in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText/text() return replace($I,'^0','')))) !=             count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText/text())">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count(distinct-values(data(for $I in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText/text() return replace($I,'^0','')))) != count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation/ndexia:VictimSequenceNumberText/text())">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>584: VICTIM CAN NOT BE DUPLICATED</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest"
                 priority="1016"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest"/>
      <xsl:variable name="victimDigest"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim]/../lexsdigest:EntityPerson[j:Victim]/lexsdigest:Person[@s:id = ../j:Victim/nc:RoleOfPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="victimAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id=$victimDigest]/nc:PersonAgeMeasure"/>
      <xsl:variable name="victimSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id=$victimDigest]/nc:PersonSexCode"/>
      <xsl:variable name="victimRace"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $victimDigest]/ndexia:PersonRaceCode"/>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim]"
                 priority="1015"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim]"/>
      <xsl:variable name="victimAge"
                    select="./lexsdigest:Person[../j:Victim]/nc:PersonAgeMeasure"/>
      <xsl:variable name="victim"
                    select="./lexsdigest:Person[@s:id = ../j:Victim/nc:RoleOfPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="victimRole"
                    select="./j:Victim[nc:RoleOfPersonReference/@s:ref = current()/lexsdigest:Person/@s:id]/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$victim]"/>
      <xsl:variable name="victimOffense"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$victim]"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>
      <xsl:variable name="victimSex"
                    select="./lexsdigest:Person[@s:id = current()/j:Victim/nc:RoleOfPersonReference/@s:ref]/nc:PersonSexCode"/>
      <xsl:variable name="victimRace"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $victim]/ndexia:PersonRaceCode"/>
      <xsl:variable name="enforcementOfficialRole"
                    select="current()[lexsdigest:Person/@s:id = j:EnforcementOfficial/nc:RoleOfPersonReference/@s:ref and lexsdigest:Person/@s:id=j:Victim/nc:RoleOfPersonReference/@s:ref]/j:EnforcementOfficial/@s:id"/>
      <xsl:variable name="victimNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/ndexia:VictimSequenceNumberText"/>
      <xsl:variable name="victimInjury"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$victimRole]/msp:VictimInjuryCode"/>
      <xsl:variable name="elderAbuse"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$victimRole]/msp:VictimElderAbuse"/>
      <xsl:variable name="victimOffenseCodes"
                    select="for $I in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = (for $J in //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$victim] return $J)]/msp:OffenseCategoryCode   return $I"/>
      <xsl:variable name="actionCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ActionCode"/>
      <xsl:variable name="offender"
                    select="../lexsdigest:EntityPerson[j:Subject]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="victims_01_Vors"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:SubjectPersonReference/@s:ref = $offender and             ./@s:id = //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation[msp:VictimToSubjectRelationshipCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TO_OFFENDER_RELATIONSHIP'] and COLUMN[@NAME='ERROR_NUMBER' and .='564']]/COLUMN[@NAME='CODE']]/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]"/>

		    <!--REPORT error-->
<xsl:if test="(number($victimAge/nc:MeasurePointValue) &gt; 59 and $victimAge/nc:TimeUnitCode = 'ANN' and $victimType = 'I') and not(exists($elderAbuse/text()))  ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(number($victimAge/nc:MeasurePointValue) &gt; 59 and $victimAge/nc:TimeUnitCode = 'ANN' and $victimType = 'I') and not(exists($elderAbuse/text()))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>532: ELDER ABUSE INDICATOR MUST BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$elderAbuse/text() = 'true' and not($victimType = 'I')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$elderAbuse/text() = 'true' and not($victimType = 'I')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>535: ELDER ABUSE INDICATOR CANNOT EQUAL Y</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="number($victimAge/nc:MeasurePointValue) &lt; 60 and $victimAge/nc:TimeUnitCode = 'ANN' and $elderAbuse/text() = 'true'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($victimAge/nc:MeasurePointValue) &lt; 60 and $victimAge/nc:TimeUnitCode = 'ANN' and $elderAbuse/text() = 'true'">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>535: ELDER ABUSE INDICATOR CANNOT EQUAL Y</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($victimAge)) and boolean($victimType) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='502']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($victimAge)) and boolean($victimType) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='502']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>502: VICTIM AGE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimType) and boolean($victimAge) and boolean($victimAge/nc:MeasurePointValue) and boolean($victimAge/nc:TimeUnitCode) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='521']]/COLUMN[@NAME='CODE']) and             (((number($victimAge/nc:MeasurePointValue) &gt; 99 or number($victimAge/nc:MeasurePointValue) &lt; 0) and $victimAge/nc:TimeUnitCode = 'ANN') or             ((number($victimAge/nc:MeasurePointValue) &gt; 364 or number($victimAge/nc:MeasurePointValue) &lt; 1) and $victimAge/nc:TimeUnitCode = 'DAY') or             ((number($victimAge/nc:MeasurePointValue) &gt; 23  or number($victimAge/nc:MeasurePointValue) &lt; 0) and $victimAge/nc:TimeUnitCode = 'HUR')) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and boolean($victimAge) and boolean($victimAge/nc:MeasurePointValue) and boolean($victimAge/nc:TimeUnitCode) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='521']]/COLUMN[@NAME='CODE']) and (((number($victimAge/nc:MeasurePointValue) &gt; 99 or number($victimAge/nc:MeasurePointValue) &lt; 0) and $victimAge/nc:TimeUnitCode = 'ANN') or ((number($victimAge/nc:MeasurePointValue) &gt; 364 or number($victimAge/nc:MeasurePointValue) &lt; 1) and $victimAge/nc:TimeUnitCode = 'DAY') or ((number($victimAge/nc:MeasurePointValue) &gt; 23 or number($victimAge/nc:MeasurePointValue) &lt; 0) and $victimAge/nc:TimeUnitCode = 'HUR')) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>521: INVALID VICTIM AGE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimType) and boolean($victimAge) and             not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='522']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and boolean($victimAge) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='522']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>522: VICTIM AGE MUST BE BLANK IF TYPE NOT I/P</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimType) and boolean($victimAge) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='523']]/COLUMN[@NAME='CODE' and text()= $victimType]) and             exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and text()='523']]/COLUMN[@NAME='CODE' and text() = $offenseCode]) and             ((number($victimAge/nc:MeasurePointValue) &gt; 17 or number($victimAge/nc:MeasurePointValue) &lt; 0) and $victimAge/nc:TimeUnitCode = 'ANN') and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and boolean($victimAge) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='523']]/COLUMN[@NAME='CODE' and text()= $victimType]) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and text()='523']]/COLUMN[@NAME='CODE' and text() = $offenseCode]) and ((number($victimAge/nc:MeasurePointValue) &gt; 17 or number($victimAge/nc:MeasurePointValue) &lt; 0) and $victimAge/nc:TimeUnitCode = 'ANN') and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>523: VICTIM AGE MUST BE NN, NB, BB OR 00 TO 17 IF OFFENSE = 10002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimType) and boolean($victimAge) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='524']]/COLUMN[@NAME='CODE' and text() = $victimType]) and             exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and text()='524']]/COLUMN[@NAME='CODE' and text() = $offenseCode]) and             not(number($victimAge/nc:MeasurePointValue) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='AGE'] and COLUMN[@NAME='ERROR_NUMBER' and .='524']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and boolean($victimAge) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='524']]/COLUMN[@NAME='CODE' and text() = $victimType]) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and text()='524']]/COLUMN[@NAME='CODE' and text() = $offenseCode]) and not(number($victimAge/nc:MeasurePointValue) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='AGE'] and COLUMN[@NAME='ERROR_NUMBER' and .='524']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>524: VICTIM AGE MUST BE 13, 14, OR 15 IF OFFENSE = 36001 OR 36002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimType) and boolean($victimAge) and ($victimType = 'L') and boolean($victimAge/nc:MeasurePointValue) and boolean($victimAge/nc:TimeUnitCode) and             (((number($victimAge/nc:MeasurePointValue) &gt; 70 or number($victimAge/nc:MeasurePointValue) &lt; 18) and $victimAge/nc:TimeUnitCode = 'ANN') or not($victimAge/nc:TimeUnitCode = 'ANN'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and boolean($victimAge) and ($victimType = 'L') and boolean($victimAge/nc:MeasurePointValue) and boolean($victimAge/nc:TimeUnitCode) and (((number($victimAge/nc:MeasurePointValue) &gt; 70 or number($victimAge/nc:MeasurePointValue) &lt; 18) and $victimAge/nc:TimeUnitCode = 'ANN') or not($victimAge/nc:TimeUnitCode = 'ANN'))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>525: VICTIM TYPE P CANNOT HAVE VICTIM AGE LESS THAN 18, GREATER THAN 70</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimSex) and boolean($victimType) and ($victimSex = $fbi_codes//xsd:simpleType[@name='SEXCodeSimpleType']/xsd:restriction/xsd:enumeration/@value) and             not ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='529']]/COLUMN[@NAME='CODE' and text() = $victimType])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimSex) and boolean($victimType) and ($victimSex = $fbi_codes//xsd:simpleType[@name='SEXCodeSimpleType']/xsd:restriction/xsd:enumeration/@value) and not ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='529']]/COLUMN[@NAME='CODE' and text() = $victimType])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>529: VICTIM SEX MUST BE BLANK IF TYPE NOT I/P</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimSex) and boolean($victimType) and not ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_SEX'] and COLUMN[@NAME='ERROR_NUMBER' and text()='530']]/COLUMN[@NAME='CODE' and text() = $victimSex]) and             ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='530']]/COLUMN[@NAME='CODE' and . = $victimType]) and             ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and text()='530']]/COLUMN[@NAME='CODE' and text() = $offenseCode])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimSex) and boolean($victimType) and not ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_SEX'] and COLUMN[@NAME='ERROR_NUMBER' and text()='530']]/COLUMN[@NAME='CODE' and text() = $victimSex]) and ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='530']]/COLUMN[@NAME='CODE' and . = $victimType]) and ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and text()='530']]/COLUMN[@NAME='CODE' and text() = $offenseCode])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>530: VICTIM SEX MUST BE M/F</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean(j:Victim) and not(boolean($victimSex)) and $victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='528']]/COLUMN[@NAME='CODE']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean(j:Victim) and not(boolean($victimSex)) and $victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='528']]/COLUMN[@NAME='CODE']">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>528: VICTIM SEX MUST BE M/F/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($victimSex)) and boolean($victimType) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='502']]/COLUMN[@NAME='CODE']) and             count($victimRole) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($victimSex)) and boolean($victimType) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='502']]/COLUMN[@NAME='CODE']) and count($victimRole) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>502: VICTIM SEX IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="boolean($victimAge) and number($victimAge/nc:MeasurePointValue) = 99 and $victimAge/nc:TimeUnitCode='ANN'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimAge) and number($victimAge/nc:MeasurePointValue) = 99 and $victimAge/nc:TimeUnitCode='ANN'">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: Please verify the age of the victim is 99 years or older. Unknown victim age should be reported as 00. If changes are required, please submit with the next MICR submission</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimType) and             boolean($victimRole) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='590']]/COLUMN[@NAME='CODE']) and             (some $x in $offenseCode satisfies (number($x) = (9001,13001 to 13003))) and             boolean(current()[lexsdigest:Person/@s:id = j:EnforcementOfficial/nc:RoleOfPersonReference/@s:ref and lexsdigest:Person/@s:id=j:Victim/nc:RoleOfPersonReference/@s:ref]) and             (not(boolean(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:EnforcementOfficial[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:EnforcementOfficialActivityCategoryCode)) or             not(boolean(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial[ndexia:EnforcementOfficialAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:EnforcementOfficialAssignmentCategoryCode))) and             (not(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:EnforcementOfficial[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:EnforcementOfficialActivityCategoryCode = '') or             not(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial[ndexia:EnforcementOfficialAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:EnforcementOfficialAssignmentCategoryCode = '')) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimType) and boolean($victimRole) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='590']]/COLUMN[@NAME='CODE']) and (some $x in $offenseCode satisfies (number($x) = (9001,13001 to 13003))) and boolean(current()[lexsdigest:Person/@s:id = j:EnforcementOfficial/nc:RoleOfPersonReference/@s:ref and lexsdigest:Person/@s:id=j:Victim/nc:RoleOfPersonReference/@s:ref]) and (not(boolean(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:EnforcementOfficial[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:EnforcementOfficialActivityCategoryCode)) or not(boolean(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial[ndexia:EnforcementOfficialAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:EnforcementOfficialAssignmentCategoryCode))) and (not(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:EnforcementOfficial[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:EnforcementOfficialActivityCategoryCode = '') or not(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial[ndexia:EnforcementOfficialAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:EnforcementOfficialAssignmentCategoryCode = ''))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>590: VICTIM TYPE OF P REQUIRES ACTIVITY TYPE AND ASSIGNMENT TYPE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists(current()/j:Victim) and not (every $x in $victimOffenseCodes satisfies $x= $filec_lookup//ROW/COLUMN[@NAME='FILEC_OFFENSE_CO'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(current()/j:Victim) and not (every $x in $victimOffenseCodes satisfies $x= $filec_lookup//ROW/COLUMN[@NAME='FILEC_OFFENSE_CO'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>VICTIM <xsl:text/>
               <xsl:value-of select="$victimNumber"/>
               <xsl:text/> 505: VICTIM OFFENSE MUST BE VALID OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="count(distinct-values(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:PersonReference/@s:ref=$victim]/nc:ActivityReference/@s:ref)) !=             count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:PersonReference/@s:ref=$victim]/nc:ActivityReference/@s:ref)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count(distinct-values(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:PersonReference/@s:ref=$victim]/nc:ActivityReference/@s:ref)) != count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:PersonReference/@s:ref=$victim]/nc:ActivityReference/@s:ref)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>VICTIM <xsl:text/>
               <xsl:value-of select="$victimNumber"/>
               <xsl:text/> 558: VICTIM OFFENSES CANNOT BE DUPLICATED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($offenseId) and boolean($victimInjury) and             empty($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and text()='574']]/COLUMN[@NAME='CODE' and text() = (for $K in $victimOffenseCodes return $K)]) and             exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='574']]/COLUMN[@NAME='CODE' and text() = $victimType])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($offenseId) and boolean($victimInjury) and empty($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and text()='574']]/COLUMN[@NAME='CODE' and text() = (for $K in $victimOffenseCodes return $K)]) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='574']]/COLUMN[@NAME='CODE' and text() = $victimType])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>574: VICTIM INJURY CANNOT BE ENTERED FOR THIS OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($victimInjury))  and boolean($victimType) and             ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='537']]/COLUMN[@NAME='CODE']) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='537']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($victimInjury)) and boolean($victimType) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='537']]/COLUMN[@NAME='CODE']) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='537']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>537: VICTIM INJURY REQUIRED FOR OFFENSE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($victimInjury)) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='538']]/COLUMN[@NAME='CODE']) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='538']]/COLUMN[@NAME='CODE']) and             boolean($victimType)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($victimInjury)) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='538']]/COLUMN[@NAME='CODE']) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='538']]/COLUMN[@NAME='CODE']) and boolean($victimType)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>538 VICTIM INJURY REQUIRED FOR OFFENSES 12000/21000</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimInjury) and ($victimOffenseCodes = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='595']]/COLUMN[@NAME='CODE']) and             not($victimInjury = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_INJURY'] and COLUMN[@NAME='ERROR_NUMBER' and .='595']]/COLUMN[@NAME='CODE']) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='595']]/COLUMN[@NAME='CODE']) and             boolean($victimType) and not(some $x in $victimOffenseCodes satisfies($x = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='FATAL_OFFENSE'] and COLUMN[@NAME='ERROR_NUMBER' and .='595']]/COLUMN[@NAME='CODE']))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimInjury) and ($victimOffenseCodes = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='595']]/COLUMN[@NAME='CODE']) and not($victimInjury = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_INJURY'] and COLUMN[@NAME='ERROR_NUMBER' and .='595']]/COLUMN[@NAME='CODE']) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='595']]/COLUMN[@NAME='CODE']) and boolean($victimType) and not(some $x in $victimOffenseCodes satisfies($x = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='FATAL_OFFENSE'] and COLUMN[@NAME='ERROR_NUMBER' and .='595']]/COLUMN[@NAME='CODE']))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>595: VICTIM INJURY MUST BE N/B/I/L/M/O/T/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person"
                 priority="1014"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person"/>
      <xsl:variable name="victimRace"
                    select="./ndexia:PersonAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Victim/nc:RoleOfPersonReference/@s:ref]/@s:id]/ndexia:PersonRaceCode"/>
      <xsl:variable name="victimRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim[../lexsdigest:Person/@s:id = current()/ndexia:PersonAugmentation/lexslib:SameAsDigestReference/@lexslib:ref and ../lexsdigest:Person/@s:id = ./nc:RoleOfPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>

		    <!--REPORT error-->
<xsl:if test="boolean($victimRace) and boolean($victimType) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='526']]/COLUMN[@NAME='CODE' and text() = $victimType]) and             not ($victimRace = ($ndexia_codes//xsd:simpleType[@name='RACCodeSimpleType']//xsd:enumeration/@value)) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimRace) and boolean($victimType) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='526']]/COLUMN[@NAME='CODE' and text() = $victimType]) and not ($victimRace = ($ndexia_codes//xsd:simpleType[@name='RACCodeSimpleType']//xsd:enumeration/@value))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>526: VICTIM RACE MUST BE A/B/I/P/U/W</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($victimRace)) and boolean($victimType) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='502']]/COLUMN[@NAME='CODE' and text() = $victimType])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($victimRace)) and boolean($victimType) and exists($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='502']]/COLUMN[@NAME='CODE' and text() = $victimType])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>502: VICTIM RACE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimRace) and boolean($victimType) and empty($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='527']]/COLUMN[@NAME='CODE' and text() = $victimType])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimRace) and boolean($victimType) and empty($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and text()='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and text()='527']]/COLUMN[@NAME='CODE' and text() = $victimType])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>527: VICTIM RACE MUST BE BLANK IF TYPE NOT I/P</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Person/msp:PersonEthnicityCode"
                 priority="1013"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Person/msp:PersonEthnicityCode"/>
      <xsl:variable name="victimRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = current()/../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/j:Victim/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>

		    <!--REPORT error-->
<xsl:if test="boolean(.) and boolean($victimType) and not (. = distinct-values($ethinicity_lookup//ROW/COLUMN[@NAME='ETHINICITY_CODE']/text())) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='531']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean(.) and boolean($victimType) and not (. = distinct-values($ethinicity_lookup//ROW/COLUMN[@NAME='ETHINICITY_CODE']/text())) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='531']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>531: VICTIM ETHNICITY MUST BE A/H/O/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean(.) and boolean($victimType) and             not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='503']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean(.) and boolean($victimType) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='503']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>503: VICTIM ETHNICITY MUST BE BLANK IF TYPE NOT I/P</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ResidenceAssociation/msp:ResidenceCategoryCode"
                 priority="1012"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ResidenceAssociation/msp:ResidenceCategoryCode"/>
      <xsl:variable name="victimForResidence"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/nc:ResidenceAssociation[@s:id = current()/../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/nc:PersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="victimRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim[nc:RoleOfPersonReference/@s:ref = $victimForResidence]/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>
      <xsl:variable name="residenceCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ResidenceAssociation/msp:ResidenceCategoryCode"/>

		    <!--REPORT error-->
<xsl:if test="boolean(.) and not ($residenceCode = $residence_lookup//ROW/COLUMN[@NAME='CODE']/text()) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='533']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean(.) and not ($residenceCode = $residence_lookup//ROW/COLUMN[@NAME='CODE']/text()) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='533']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>533: VICTIM RESIDENCE MUST BE R/C/S/O/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean(.) and              not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='534']]/COLUMN[@NAME='CODE']) and             string-length($victimType) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean(.) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='534']]/COLUMN[@NAME='CODE']) and string-length($victimType) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>534: VICTIM RESIDENCE MUST BE BLANK IF TYPE NOT I/P</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim"
                 priority="1011"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim"/>
      <xsl:variable name="victimInjury" select="./msp:VictimInjuryCode"/>
      <xsl:variable name="victimRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim[@s:id = current()/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>
      <xsl:variable name="victimForInjury"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim/@s:id = $victimRole]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$victimForInjury]"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>
      <xsl:variable name="victimNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim/ndexia:VictimAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/ndexia:VictimSequenceNumberText"/>
      <xsl:variable name="offenses"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode"/>

		    <!--REPORT error-->
<xsl:if test="boolean($victimInjury)  and             not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='536']]/COLUMN[@NAME='CODE']) and             string-length($victimType) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimInjury) and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='536']]/COLUMN[@NAME='CODE']) and string-length($victimType) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>536: VICTIM INJURY MUST BE BLANK IF TYPE NOT I/P</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimInjury)  and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='539']]/COLUMN[@NAME='CODE']) and             not($victimInjury = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_INJURY'] and COLUMN[@NAME='ERROR_NUMBER' and .='539']]/COLUMN[@NAME='CODE']) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='539']]/COLUMN[@NAME='CODE']) and             boolean($victimType)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimInjury) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='539']]/COLUMN[@NAME='CODE']) and not($victimInjury = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_INJURY'] and COLUMN[@NAME='ERROR_NUMBER' and .='539']]/COLUMN[@NAME='CODE']) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='539']]/COLUMN[@NAME='CODE']) and boolean($victimType)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>539: VICTIM INJURY MUST BE F FOR OFFENSES 09001 to 09006</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((for $I in $offenseCode return $I) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='541']]/COLUMN[@NAME='CODE']) and             not($victimInjury = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_INJURY'] and COLUMN[@NAME='ERROR_NUMBER' and .='541']]/COLUMN[@NAME='CODE']) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='541']]/COLUMN[@NAME='CODE']) and             boolean($victimType)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((for $I in $offenseCode return $I) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='541']]/COLUMN[@NAME='CODE']) and not($victimInjury = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_INJURY'] and COLUMN[@NAME='ERROR_NUMBER' and .='541']]/COLUMN[@NAME='CODE']) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='541']]/COLUMN[@NAME='CODE']) and boolean($victimType)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>541: NON AGGRAVATED ASSAULTS CANNOT HAVE MAJOR INJURIES</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="victimCircumstance"
                    select="./j:VictimAggravatedAssaultHomicideFactorCode"/>
      <xsl:variable name="victimForCircum"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim/@s:id = current()/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref and j:Victim/nc:RoleOfPersonReference/@s:ref = lexsdigest:Person/@s:id]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenseIdForCircum"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$victimForCircum]"/>
      <xsl:variable name="offenseCodeForCircum"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseIdForCircum]"/>

		    <!--REPORT error-->
<xsl:if test="boolean($victimCircumstance) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='545']]/COLUMN[@NAME='CODE']) and             not ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='545']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimCircumstance) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='545']]/COLUMN[@NAME='CODE']) and not ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='545']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>545: CIRCUMSTANCE MUST BE 01 to 10 FOR OFFENSE 09001</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not(boolean($victimCircumstance)) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='543']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($victimCircumstance)) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='543']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>VICTIM <xsl:text/>
               <xsl:value-of select="$victimNumber"/>
               <xsl:text/> 543: VICTIM CIRCUMSTANCE IS REQUIRED IF OFFENSE IS 09001, 09002, 09004, 09005, 13002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimCircumstance) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='547']]/COLUMN[@NAME='CODE']) and             not ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='547']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimCircumstance) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='547']]/COLUMN[@NAME='CODE']) and not ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='547']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>547: CIRCUMSTANCE MUST BE 30 to 34 FOR OFFENSE 09002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimCircumstance) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='548']]/COLUMN[@NAME='CODE']) and             not ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='548']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimCircumstance) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='548']]/COLUMN[@NAME='CODE']) and not ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='548']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>548: CIRCUMSTANCE MUST BE 20/21 FOR OFFENSE 09004</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimCircumstance) and ($offenseCount=1) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='549']]/COLUMN[@NAME='CODE']) and             not ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='549']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimCircumstance) and ($offenseCount=1) and ($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='549']]/COLUMN[@NAME='CODE']) and not ($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='549']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>549: CIRCUMSTANCE MUST BE 21 FOR OFFENSE 09005</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='546']]/COLUMN[@NAME='CODE']) and             not($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='546']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='546']]/COLUMN[@NAME='CODE']) and not($victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='546']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>VICTIM <xsl:text/>
               <xsl:value-of select="$victimNumber"/>
               <xsl:text/> 546: CIRCUMSTANCE MUST BE 1 to 6/8 to 10 FOR 13002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimCircumstance) and not ((for $I in $offenseCodeForCircum return number($I)) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='544']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimCircumstance) and not ((for $I in $offenseCodeForCircum return number($I)) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='544']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>544: VICTIM CIRCUMSTANCE MUST BE BLANK OR 0 IF OFFENSE IS NOT 09001, 09002, 09004, 09005, 13002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($victimCircumstance) and             $offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09001']]/COLUMN[@NAME='CODE'] and             $victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09001']]/COLUMN[@NAME='CODE'] and             $offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09002']]/COLUMN[@NAME='CODE'] and             $victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09002']]/COLUMN[@NAME='CODE'] and             $offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09004']]/COLUMN[@NAME='CODE'] and             $victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09004']]/COLUMN[@NAME='CODE'] and             $offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_13002']]/COLUMN[@NAME='CODE'] and             $victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_13002']]/COLUMN[@NAME='CODE'] ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimCircumstance) and $offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09001']]/COLUMN[@NAME='CODE'] and $victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09001']]/COLUMN[@NAME='CODE'] and $offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09002']]/COLUMN[@NAME='CODE'] and $victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09002']]/COLUMN[@NAME='CODE'] and $offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09004']]/COLUMN[@NAME='CODE'] and $victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_09004']]/COLUMN[@NAME='CODE'] and $offenseCodeForCircum = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_13002']]/COLUMN[@NAME='CODE'] and $victimCircumstance = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_CIRCUMSTANCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='575_13002']]/COLUMN[@NAME='CODE']">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>575: INVALID VICTIM CIRCUMSTANCE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$victimCircumstance='08' and count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[text() = ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='549_1']]/COLUMN[@NAME='CODE'])]) &lt; 2">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$victimCircumstance='08' and count(/lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[text() = ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='549_1']]/COLUMN[@NAME='CODE'])]) &lt; 2">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>549: AT LEAST TWO GROUP A OFFENSES MUST BE ENTERED WHEN CIRCUMSTANCE - 8 </svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense"
                 priority="1010"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense"/>
      <xsl:variable name="victimOffense" select="./msp:OffenseCategoryCode"/>
      <xsl:variable name="OffenseCodeId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[@s:id = current()/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="victimOffenseCodes"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $OffenseCodeId]/msp:OffenseCategoryCode"/>
      <xsl:variable name="victimForOffense"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:ActivityReference/@s:ref = $OffenseCodeId]/nc:PersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="victimRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim[nc:RoleOfPersonReference/@s:ref = $victimForOffense]/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>
      <xsl:variable name="victimInjury"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$victimRole]/msp:VictimInjuryCode"/>
      <xsl:variable name="offenseWeapon"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $OffenseCodeId]/j:IncidentForce/j:ForceCategoryCode"/>

		    <!--REPORT warning-->
<xsl:if test="boolean($victimOffense) and not($victimType = 'I') and ($victimOffense = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='W17']]/COLUMN[@NAME='CODE']) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='W17']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimOffense) and not($victimType = 'I') and ($victimOffense = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='W17']]/COLUMN[@NAME='CODE']) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='W17']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: A Victim Type of Individual must also be present.  The victim(s) of a robbery include not only persons and other entities from whom property was taken, but also those persons toward whom the robber(s) directed force or threat of force in perpetrating the offense.  If changes or additions are required, please submit with the next data submission.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="boolean($victimOffense)  and ($victimOffense = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='W23']]/COLUMN[@NAME='CODE']) and             ($victimInjury = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_INJURY'] and COLUMN[@NAME='ERROR_NUMBER' and .='W23']]/COLUMN[@NAME='CODE']) and             ($offenseWeapon = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_WEAPON'] and COLUMN[@NAME='ERROR_NUMBER' and .='W23']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($victimOffense) and ($victimOffense = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='W23']]/COLUMN[@NAME='CODE']) and ($victimInjury = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_INJURY'] and COLUMN[@NAME='ERROR_NUMBER' and .='W23']]/COLUMN[@NAME='CODE']) and ($offenseWeapon = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_WEAPON'] and COLUMN[@NAME='ERROR_NUMBER' and .='W23']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: This incident appears to have no serious or aggravated injury. Please review this incident to ensure that the offense of 13002 is correct, rather than a Simple Assault of 13001.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation"
                 priority="1009"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation"/>
      <xsl:variable name="victimForAssoc" select="current()/nc:PersonReference/@s:ref"/>
      <xsl:variable name="currOffenseCodeId" select="current()/nc:ActivityReference/@s:ref"/>
      <xsl:variable name="offenseCodeId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[@s:id = current()/nc:ActivityReference/@s:ref]/@s:id"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[$offenseCodeId = msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/msp:OffenseCategoryCode"/>
      <xsl:variable name="activity_f"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:PersonReference/@s:ref=$victimForAssoc]/following-sibling::node()[nc:PersonReference/@s:ref=$victimForAssoc]/nc:ActivityReference"/>
      <xsl:variable name="activity_p"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:PersonReference/@s:ref=$victimForAssoc]/preceding-sibling::node()[nc:PersonReference/@s:ref=$victimForAssoc]/nc:ActivityReference"/>
      <xsl:variable name="fc"
                    select="$activity_f[//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode = ('13001','9004')]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_506A_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='506A']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_506B_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='506B']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_506_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='506']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_506_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='506']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_507_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='507']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_507_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='507']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_508_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='508']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_508_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='508']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_509_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='509']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_509_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='509']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_510_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='510']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_510_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='510']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_510_1_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='510_1']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_510_1_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='510_1']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_510_2_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='510_2']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_510_2_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='510_2']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_511_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='511']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_511_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='511']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_512_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='512']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_512_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='512']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_504A_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='504A']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_504A_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='504A']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_504B_f"
                    select="$activity_f             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_f/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='504B']]/COLUMN[@NAME='CODE']]/@s:ref"/>
      <xsl:variable name="otherOffenseWithVictimCodes_504B_p"
                    select="$activity_p             [//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $activity_p/@s:ref]/msp:OffenseCategoryCode =             $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='504B']]/COLUMN[@NAME='CODE']]/@s:ref"/>

		    <!--REPORT error-->
<xsl:if test=" $offenseCode = '09005' and count($otherOffenseWithVictimCodes_506A_f) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = '09005' and count($otherOffenseWithVictimCodes_506A_f) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>506: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 09005, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 09006</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" $offenseCode = '09006' and count($otherOffenseWithVictimCodes_506B_f) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = '09006' and count($otherOffenseWithVictimCodes_506B_f) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>506: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 09006, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 09005</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" $offenseCode = '13001' and (count($otherOffenseWithVictimCodes_506_f) &gt; 0 or count($otherOffenseWithVictimCodes_506_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = '13001' and (count($otherOffenseWithVictimCodes_506_f) &gt; 0 or count($otherOffenseWithVictimCodes_506_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>506: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 13001, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 09001 to 09002, 11001 to 11008, 12000 OR 13002 to 13003</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" $offenseCode = '13002' and (count($otherOffenseWithVictimCodes_507_f) &gt; 0 or count($otherOffenseWithVictimCodes_507_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = '13002' and (count($otherOffenseWithVictimCodes_507_f) &gt; 0 or count($otherOffenseWithVictimCodes_507_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>507: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 13002, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 09001 to 09002, 11001 to 11006, 12000, 13001 OR 13003</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test=" $offenseCode = '13003' and (count($otherOffenseWithVictimCodes_508_f) &gt; 0 or count($otherOffenseWithVictimCodes_508_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = '13003' and (count($otherOffenseWithVictimCodes_508_f) &gt; 0 or count($otherOffenseWithVictimCodes_508_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>508: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 13003, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 09001 to 09002, 11001 to 11008, OR 12000</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($offenseCode = '11007' or $offenseCode = '11008') and (count($otherOffenseWithVictimCodes_509_f) &gt; 0 or count($otherOffenseWithVictimCodes_509_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($offenseCode = '11007' or $offenseCode = '11008') and (count($otherOffenseWithVictimCodes_509_f) &gt; 0 or count($otherOffenseWithVictimCodes_509_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>509: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 11007 OR 11008, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 11001 to 11006, OR 36001 to 36002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($offenseCode = '36001' or $offenseCode = '36002') and (count($otherOffenseWithVictimCodes_510_f) &gt; 0 or count($otherOffenseWithVictimCodes_510_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($offenseCode = '36001' or $offenseCode = '36002') and (count($otherOffenseWithVictimCodes_510_f) &gt; 0 or count($otherOffenseWithVictimCodes_510_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>510: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
    IF VICTIM CONNECTED FILE CLASS IS 36001 OR 36002, THEN ALL OTHER VICTIM CONNECTED
    FILE CLASSES CANNOT BE EQUAL TO 11001 to 11008 or 13001 to 13003</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($offenseCode = '11001' or $offenseCode = '11002') and (count($otherOffenseWithVictimCodes_510_1_f) &gt; 0 or count($otherOffenseWithVictimCodes_510_1_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($offenseCode = '11001' or $offenseCode = '11002') and (count($otherOffenseWithVictimCodes_510_1_f) &gt; 0 or count($otherOffenseWithVictimCodes_510_1_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>510: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 11001 OR 11002 , THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 11007 to 11008 or 13001 to 13003 or 36001, 36002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="($offenseCode = '11003' or $offenseCode = '11004') and (count($otherOffenseWithVictimCodes_510_2_f) &gt; 0 or count($otherOffenseWithVictimCodes_510_2_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="($offenseCode = '11003' or $offenseCode = '11004') and (count($otherOffenseWithVictimCodes_510_2_f) &gt; 0 or count($otherOffenseWithVictimCodes_510_2_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>510: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 11003 OR 11004 , THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 11007 to 11008 or 13001 to 13003 or 36001, 36002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$offenseCode = '12000' and (count($otherOffenseWithVictimCodes_511_f) &gt; 0 or count($otherOffenseWithVictimCodes_511_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = '12000' and (count($otherOffenseWithVictimCodes_511_f) &gt; 0 or count($otherOffenseWithVictimCodes_511_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>511: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 12000, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 13001 to 13003, 23001 to 23007, 24001, 30002 OR 30004</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$offenseCode = '09001' and (count($otherOffenseWithVictimCodes_512_f) &gt; 0 or count($otherOffenseWithVictimCodes_512_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = '09001' and (count($otherOffenseWithVictimCodes_512_f) &gt; 0 or count($otherOffenseWithVictimCodes_512_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>512: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 09001, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 09002, 13001,13002 and 13003</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$offenseCode = '30002' and (count($otherOffenseWithVictimCodes_504B_f) &gt; 0 or count($otherOffenseWithVictimCodes_504B_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = '30002' and (count($otherOffenseWithVictimCodes_504B_f) &gt; 0 or count($otherOffenseWithVictimCodes_504B_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>504: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 30002, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 30004</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$offenseCode = '30004' and (count($otherOffenseWithVictimCodes_504A_f) &gt; 0 or count($otherOffenseWithVictimCodes_504A_p) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = '30004' and (count($otherOffenseWithVictimCodes_504A_f) &gt; 0 or count($otherOffenseWithVictimCodes_504A_p) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>504: VICTIM CONNECTED TO AN INVALID COMBINATION OF OFFENSES.
     IF VICTIM CONNECTED FILE CLASS IS 30004, THEN ALL OTHER VICTIM CONNECTED
     FILE CLASSES CANNOT BE EQUAL TO 30002</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation"
                 priority="1008"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation"/>
      <xsl:variable name="subjectVictimVOR" select="./msp:VictimToSubjectRelationshipCode"/>
      <xsl:variable name="subjectVictimAssociation"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id = current()/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]"/>
      <xsl:variable name="victimSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id =$subjectVictimAssociation/@s:id]/lexsdigest:VictimPersonReference/@s:ref]/lexsdigest:Person/nc:PersonSexCode"/>
      <xsl:variable name="victimAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id =$subjectVictimAssociation/@s:id]/lexsdigest:VictimPersonReference/@s:ref]/lexsdigest:Person/nc:PersonAgeMeasure"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id =$subjectVictimAssociation/@s:id]/lexsdigest:SubjectPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="offenderSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id =$subjectVictimAssociation/@s:id]/lexsdigest:SubjectPersonReference/@s:ref]/lexsdigest:Person/nc:PersonSexCode"/>
      <xsl:variable name="offenderAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id =$subjectVictimAssociation/@s:id]/lexsdigest:SubjectPersonReference/@s:ref]/lexsdigest:Person/nc:PersonAgeMeasure"/>
      <xsl:variable name="offenderAgeValue"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id =$subjectVictimAssociation/@s:id]/lexsdigest:SubjectPersonReference/@s:ref]/lexsdigest:Person/nc:PersonAgeMeasure/nc:MeasurePointValue"/>
      <xsl:variable name="offenderRace"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/ndexia:PersonRaceCode[../lexslib:SameAsDigestReference/@lexslib:ref = $offender]"/>
      <xsl:variable name="victimForVor"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id =$subjectVictimAssociation/@s:id]/lexsdigest:VictimPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="victimRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim[nc:RoleOfPersonReference/@s:ref = $victimForVor]/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$victimForVor]"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>

		    <!--REPORT error-->
<xsl:if test="boolean($subjectVictimVOR) and             not($msp_codes//xsd:simpleType[@name='VictimOffenderRelationshipCodeSimpleType']/xsd:restriction/xsd:enumeration/@value = $subjectVictimVOR)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($subjectVictimVOR) and not($msp_codes//xsd:simpleType[@name='VictimOffenderRelationshipCodeSimpleType']/xsd:restriction/xsd:enumeration/@value = $subjectVictimVOR)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>557: VOR MUST EQUAL 01 - 13, 20 - 25, 27 - 34, 98, OR 99</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($subjectVictimVOR) and             $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='556_3']]/COLUMN[@NAME='CODE']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($subjectVictimVOR) and $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='556_3']]/COLUMN[@NAME='CODE']">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>556: VOR CANNOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((boolean($subjectVictimVOR) and empty($subjectVictimAssociation)          and empty($offender))          or (boolean($subjectVictimVOR) and boolean($offender) and (boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation) and             boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:VictimPersonReference[@s:ref=$victimForVor]) and             not(boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:SubjectPersonReference[@s:ref=$offender])))))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((boolean($subjectVictimVOR) and empty($subjectVictimAssociation) and empty($offender)) or (boolean($subjectVictimVOR) and boolean($offender) and (boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation) and boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:VictimPersonReference[@s:ref=$victimForVor]) and not(boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:SubjectPersonReference[@s:ref=$offender])))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>581: VICTIM OFFENDER RELATED # MUST BE BLANK IF OFFENDER NUMBER IS BLANK IN VOR</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($subjectVictimVOR) and ($offenderSex = $val_lookup//ROW[COLUMN/@NAME='DATA_ELEMENT' and COLUMN='OFFENDER_SEX' and COLUMN/@NAME='ERROR_NUMBER' and COLUMN='559']/COLUMN[@NAME='CODE']) and             $offenderAgeValue = $val_lookup//ROW[COLUMN/@NAME='DATA_ELEMENT' and COLUMN='OFFENDER_AGE' and COLUMN/@NAME='ERROR_NUMBER' and COLUMN='559']/COLUMN[@NAME='CODE'] and             $offenderRace = $val_lookup//ROW[COLUMN/@NAME='DATA_ELEMENT' and COLUMN='OFFENDER_RACE' and COLUMN/@NAME='ERROR_NUMBER' and COLUMN='559']/COLUMN[@NAME='CODE'] and             $subjectVictimVOR != $val_lookup//ROW[COLUMN/@NAME='DATA_ELEMENT' and COLUMN='VICTIM_TO_OFFENDER_RELATIONSHIP' and COLUMN/@NAME='ERROR_NUMBER' and COLUMN='559']/COLUMN[@NAME='CODE']">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($subjectVictimVOR) and ($offenderSex = $val_lookup//ROW[COLUMN/@NAME='DATA_ELEMENT' and COLUMN='OFFENDER_SEX' and COLUMN/@NAME='ERROR_NUMBER' and COLUMN='559']/COLUMN[@NAME='CODE']) and $offenderAgeValue = $val_lookup//ROW[COLUMN/@NAME='DATA_ELEMENT' and COLUMN='OFFENDER_AGE' and COLUMN/@NAME='ERROR_NUMBER' and COLUMN='559']/COLUMN[@NAME='CODE'] and $offenderRace = $val_lookup//ROW[COLUMN/@NAME='DATA_ELEMENT' and COLUMN='OFFENDER_RACE' and COLUMN/@NAME='ERROR_NUMBER' and COLUMN='559']/COLUMN[@NAME='CODE'] and $subjectVictimVOR != $val_lookup//ROW[COLUMN/@NAME='DATA_ELEMENT' and COLUMN='VICTIM_TO_OFFENDER_RELATIONSHIP' and COLUMN/@NAME='ERROR_NUMBER' and COLUMN='559']/COLUMN[@NAME='CODE']">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>559: VOR MUST BE 99 FOR UNKNOWN OFFENDER</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($subjectVictimVOR) and (number($subjectVictimVOR) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TO_OFFENDER_RELATIONSHIP'] and COLUMN[@NAME='ERROR_NUMBER' and .='561']]/COLUMN[@NAME='CODE']) and             not($victimSex = $offenderSex)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($subjectVictimVOR) and (number($subjectVictimVOR) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TO_OFFENDER_RELATIONSHIP'] and COLUMN[@NAME='ERROR_NUMBER' and .='561']]/COLUMN[@NAME='CODE']) and not($victimSex = $offenderSex)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>561: VICTIM AND OFFENDER MUST BE SAME SEX</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($subjectVictimVOR) and (number($subjectVictimVOR) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TO_OFFENDER_RELATIONSHIP'] and COLUMN[@NAME='ERROR_NUMBER' and .='562']]/COLUMN[@NAME='CODE']) and             not(empty($victimAge/nc:MeasurePointValue)) and not(empty($offenderAge/nc:MeasurePointValue)) and (($victimAge/nc:MeasurePointValue &lt;= $offenderAge/nc:MeasurePointValue and $victimAge/nc:TimeUnitCode = ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='TIME_UNIT_CODE'] and COLUMN[@NAME='ERROR_NUMBER' and .='562']]/COLUMN[@NAME='CODE'])) or             not($victimAge/nc:TimeUnitCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='TIME_UNIT_CODE'] and COLUMN[@NAME='ERROR_NUMBER' and .='562']]/COLUMN[@NAME='CODE']))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($subjectVictimVOR) and (number($subjectVictimVOR) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TO_OFFENDER_RELATIONSHIP'] and COLUMN[@NAME='ERROR_NUMBER' and .='562']]/COLUMN[@NAME='CODE']) and not(empty($victimAge/nc:MeasurePointValue)) and not(empty($offenderAge/nc:MeasurePointValue)) and (($victimAge/nc:MeasurePointValue &lt;= $offenderAge/nc:MeasurePointValue and $victimAge/nc:TimeUnitCode = ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='TIME_UNIT_CODE'] and COLUMN[@NAME='ERROR_NUMBER' and .='562']]/COLUMN[@NAME='CODE'])) or not($victimAge/nc:TimeUnitCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='TIME_UNIT_CODE'] and COLUMN[@NAME='ERROR_NUMBER' and .='562']]/COLUMN[@NAME='CODE']))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>562: VICTIM AGE MUST BE GREATER THAN OFFENDER AGE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($subjectVictimVOR) and ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TO_OFFENDER_RELATIONSHIP'] and COLUMN[@NAME='ERROR_NUMBER' and .='563']]/COLUMN[@NAME='CODE'] = number($subjectVictimVOR)) and             ($victimAge/nc:MeasurePointValue &gt;= $offenderAge/nc:MeasurePointValue and $victimAge/nc:TimeUnitCode = 'ANN')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($subjectVictimVOR) and ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TO_OFFENDER_RELATIONSHIP'] and COLUMN[@NAME='ERROR_NUMBER' and .='563']]/COLUMN[@NAME='CODE'] = number($subjectVictimVOR)) and ($victimAge/nc:MeasurePointValue &gt;= $offenderAge/nc:MeasurePointValue and $victimAge/nc:TimeUnitCode = 'ANN')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>563: VICTIM AGE MUST BE LESS THAN OFFENDER AGE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($subjectVictimVOR) and ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TO_OFFENDER_RELATIONSHIP'] and COLUMN[@NAME='ERROR_NUMBER' and .='565']]/COLUMN[@NAME='CODE'] = number($subjectVictimVOR)) and             ((number($victimAge/nc:MeasurePointValue) &lt; 13 and $victimAge/nc:TimeUnitCode = 'ANN') or $victimAge/nc:TimeUnitCode = 'DAY' or $victimAge/nc:TimeUnitCode = 'HUR')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($subjectVictimVOR) and ($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TO_OFFENDER_RELATIONSHIP'] and COLUMN[@NAME='ERROR_NUMBER' and .='565']]/COLUMN[@NAME='CODE'] = number($subjectVictimVOR)) and ((number($victimAge/nc:MeasurePointValue) &lt; 13 and $victimAge/nc:TimeUnitCode = 'ANN') or $victimAge/nc:TimeUnitCode = 'DAY' or $victimAge/nc:TimeUnitCode = 'HUR')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>565: VICTIM AGE CANNOT BE LESS THAN 13</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="domecticViolence"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$victimRole]/msp:OffenseDomesticViolenceIndicator"/>

		    <!--REPORT error-->
<xsl:if test="exists($domecticViolence) and not($domecticViolence = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_DOMESTIC_VIOLENCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='596']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($domecticViolence) and not($domecticViolence = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_DOMESTIC_VIOLENCE'] and COLUMN[@NAME='ERROR_NUMBER' and .='596']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>596: DOMESTIC VIOLENCE MUST BE Y OR N</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation"
                 priority="1007"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation"/>
      <xsl:variable name="subjectVictimAssociation" select="./@s:id"/>

		    <!--REPORT error-->
<xsl:if test="boolean($subjectVictimAssociation) and not (boolean(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$subjectVictimAssociation))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($subjectVictimAssociation) and not (boolean(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$subjectVictimAssociation))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>568: ALL OFFENDERS MUST BE ENTERED IN VICTIM OFFENDER RELATIONSHIP</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText"
                 priority="1006"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText"/>
      <xsl:variable name="subject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject[@s:id = current()/../lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and ../j:Subject/@s:id = $subject]"/>
      <xsl:variable name="victimForOffender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:SubjectPersonReference/@s:ref = $offender]/lexsdigest:VictimPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="victimRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Victim[nc:RoleOfPersonReference/@s:ref = $victimForOffender]/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>

		    <!--REPORT error-->
<xsl:if test="number(.) = 0 and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='579']]/COLUMN[@NAME='CODE']) and             boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:VictimPersonReference[@s:ref=$victimForOffender]) and             boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:SubjectPersonReference[@s:ref=$offender])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number(.) = 0 and not ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='579']]/COLUMN[@NAME='CODE']) and boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:VictimPersonReference[@s:ref=$victimForOffender]) and boolean(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:SubjectPersonReference[@s:ref=$offender])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>579: VICTIM OFFENDER NUMBER IS INVALID WHEN OFFENDER NUMBER = 00</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:EnforcementOfficial/j:EnforcementOfficialActivityCategoryCode"
                 priority="1005"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:EnforcementOfficial/j:EnforcementOfficialActivityCategoryCode"/>
      <xsl:variable name="victimRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = j:EnforcementOfficial/nc:RoleOfPersonReference/@s:ref and             lexsdigest:Person/@s:id=j:Victim/nc:RoleOfPersonReference/@s:ref and current()/../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = j:EnforcementOfficial/@s:id]/j:Victim/@s:id"/>
      <xsl:variable name="enforcementOfficialRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[lexsdigest:Person/@s:id = j:EnforcementOfficial/nc:RoleOfPersonReference/@s:ref and             lexsdigest:Person/@s:id=j:Victim/nc:RoleOfPersonReference/@s:ref]/j:EnforcementOfficial/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $victimRole]/j:VictimCategoryCode"/>
      <xsl:variable name="enforcementOfficial"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:EnforcementOfficial/@s:id = current()/../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$enforcementOfficial]"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>
      <xsl:variable name="assignmentType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial[ndexia:EnforcementOfficialAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:EnforcementOfficialAssignmentCategoryCode"/>
      <xsl:variable name="assitORI"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization[ndexia:OrganizationAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/nc:PersonOrganizationAssociation[nc:PersonReference/@s:ref = $enforcementOfficial]/nc:OrganizationReference/@s:ref]/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"/>

		    <!--REPORT error-->
<xsl:if test="boolean(.)  and not(. = ($fbi_codes//xsd:simpleType[@name='LEOKAActivityCategoryCodeSimpleType']//xsd:enumeration/@value)) and             boolean($victimType) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='585']]/COLUMN[@NAME='CODE']) and             boolean($offenseCode) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='585']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean(.) and not(. = ($fbi_codes//xsd:simpleType[@name='LEOKAActivityCategoryCodeSimpleType']//xsd:enumeration/@value)) and boolean($victimType) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='585']]/COLUMN[@NAME='CODE']) and boolean($offenseCode) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='585']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>585: INVALID ACTIVITY TYPE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(boolean(.)  or  boolean($assignmentType) or boolean($assitORI) ) and             ((boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE']             and COLUMN[@NAME='ERROR_NUMBER' and .='591']]/COLUMN[@NAME='CODE'])) or             (boolean($victimType) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE']             and COLUMN[@NAME='ERROR_NUMBER' and .='591']]/COLUMN[@NAME='CODE']) and             boolean($offenseCode) and not($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='585']]/COLUMN[@NAME='CODE'])             ))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(boolean(.) or boolean($assignmentType) or boolean($assitORI) ) and ((boolean($victimType) and not($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='591']]/COLUMN[@NAME='CODE'])) or (boolean($victimType) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='591']]/COLUMN[@NAME='CODE']) and boolean($offenseCode) and not($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='585']]/COLUMN[@NAME='CODE']) ))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>591: ACTIVITY TYPE, ASSIGNMENT TYPE AND ORI OTHER JURISDICTION MUST BE BLANK</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial/j:EnforcementOfficialAssignmentCategoryCode"
                 priority="1004"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:EnforcementOfficial/j:EnforcementOfficialAssignmentCategoryCode"/>
      <xsl:variable name="enforcementOfficialRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:EnforcementOfficial/@s:id = current()/../ndexia:EnforcementOfficialAugmentation/lexslib:SameAsDigestReference/@lexslib:ref]/j:Victim/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:VictimCategoryCode"/>
      <xsl:variable name="enforcementOfficial"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:EnforcementOfficial/@s:id = current()/../ndexia:EnforcementOfficialAugmentation/lexslib:SameAsDigestReference/@lexslib:ref]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$enforcementOfficial]"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>

		    <!--REPORT error-->
<xsl:if test="boolean(.) and not(. = $fbi_codes//xsd:simpleType[@name='LEOKAOfficerAssignmentCategoryCodeSimpleType']//xsd:enumeration/@value) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='586']]/COLUMN[@NAME='CODE']) and             ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='586']]/COLUMN[@NAME='CODE']) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean(.) and not(. = $fbi_codes//xsd:simpleType[@name='LEOKAOfficerAssignmentCategoryCodeSimpleType']//xsd:enumeration/@value) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='586']]/COLUMN[@NAME='CODE']) and ($offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='586']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>586: INVALID ASSIGNMENT TYPE</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"
                 priority="1003"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"/>
      <xsl:variable name="organization"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityOrganization/nc:Organization[@s:id = current()/../../../ndexia:OrganizationAugmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="enforcementOfficial"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:EnforcementOfficial/nc:RoleOfPersonReference/@s:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/nc:PersonOrganizationAssociation[nc:OrganizationReference/@s:ref = $organization]/nc:PersonReference/@s:ref]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="enforcementOfficialRole"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:EnforcementOfficial/nc:RoleOfPersonReference/@s:ref = $enforcementOfficial]/j:Victim/@s:id"/>
      <xsl:variable name="victimType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[ndexia:VictimAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $enforcementOfficialRole]/j:VictimCategoryCode"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$enforcementOfficial]"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>
      <xsl:variable name="oriOtherJuris"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Organization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID[../../../ndexia:OrganizationAugmentation/lexslib:SameAsDigestReference/@lexslib:ref=$organization]"/>

		    <!--REPORT error-->
<xsl:if test="(. =//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='592']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(. =//lexs:DataItemPackage/lexs:PackageMetadata/lexs:DataOwnerMetadata/lexs:DataOwnerIdentifier/lexs:ORI) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='592']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>592: ORIG ORI AND ORI OTHER JURISDICTION MUST NOT BE SAME</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($oriOtherJuris = $ori_codes//xsd:simpleType[@name='ORICodeSimpleType']//xsd:enumeration/@value) and             ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='586']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($oriOtherJuris = $ori_codes//xsd:simpleType[@name='ORICodeSimpleType']//xsd:enumeration/@value) and ($victimType = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='VICTIM_TYPE'] and COLUMN[@NAME='ERROR_NUMBER' and .='586']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>587: INVALID ORI OTHER JURISDICTION</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage" priority="1002" mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage"/>
      <xsl:variable name="edit553FileClasses"
                    select="$val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '1000']/../COLUMN[@NAME = 'CODE']"/>
      <xsl:variable name="societyVictimCount"
                    select="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[j:VictimCategoryCode='S'])"/>

		    <!--REPORT error-->
<xsl:if test="//lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:OffenseCategoryCode=$edit553FileClasses] and $societyVictimCount &gt; 1">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="//lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[msp:OffenseCategoryCode=$edit553FileClasses] and $societyVictimCount &gt; 1">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>553: ONLY ONE VICTIM RECORD CAN EXIST WITH TYPE S(SOCIETY/PUBLIC)</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:VictimToSubjectRelationshipCode"
                 priority="1001"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:VictimToSubjectRelationshipCode"/>
      <xsl:variable name="subjectVictimAssocId"
                    select="../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref"/>
      <xsl:variable name="victimId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id=$subjectVictimAssocId]/lexsdigest:VictimPersonReference/@s:ref"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:PersonReference[@s:ref=$victimId]/../nc:ActivityReference/@s:ref"/>
      <xsl:variable name="isVor31" select="./text()= '31'"/>
      <xsl:variable name="victimAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id=$victimId]/nc:PersonAgeMeasure/nc:MeasurePointValue/text()"/>
      <xsl:variable name="victimRace"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$victimId]/../ndexia:PersonRaceCode/text()"/>
      <xsl:variable name="victimSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = $victimId]/nc:PersonSexCode/text()"/>
      <xsl:variable name="offenderId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id=$subjectVictimAssocId]/lexsdigest:SubjectPersonReference/@s:ref"/>
      <xsl:variable name="offenderAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id=$offenderId]/nc:PersonAgeMeasure/nc:MeasurePointValue/text()"/>
      <xsl:variable name="offenderRace"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenderId]/../ndexia:PersonRaceCode/text()"/>
      <xsl:variable name="offenderSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = $offenderId]/nc:PersonSexCode/text()"/>

		    <!--REPORT error-->
<xsl:if test="$isVor31 and (not($offenderAge = $victimAge) or not($offenderRace = $victimRace) or not($offenderSex = $victimSex))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isVor31 and (not($offenderAge = $victimAge) or not($offenderRace = $victimRace) or not($offenderSex = $victimSex))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>567: VICTIM AND OFFENDER MUST BE SAME AGE/RACE/SEX WITH VOR 31 </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$isVor31 and not((some $o in $offenseId satisfies (count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference[@s:ref=$o]) &gt; 1)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isVor31 and not((some $o in $offenseId satisfies (count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference[@s:ref=$o]) &gt; 1)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>582: AT LEAST TWO VICTIMS MUST EXIST WITH A COMMON FILE CLASS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$isVor31 and $offenderCount &lt; 2">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$isVor31 and $offenderCount &lt; 2">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>582: AT LEAST TWO OFFENDERS MUST EXIST</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference"
                 priority="1000"
                 mode="M93">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference"/>
      <xsl:variable name="subjectId" select="../@s:id"/>
      <xsl:variable name="offenderId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:Subject[@s:id = $subjectId]/nc:RoleOfPersonReference/@s:ref"/>
      <xsl:variable name="cntVor01"
                    select="count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation[./msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[lexsdigest:SubjectPersonReference/@s:ref = $offenderId]/@s:id]/msp:VictimToSubjectRelationshipCode[text() = '01'])"/>

		    <!--REPORT error-->
<xsl:if test="$cntVor01 &gt; 1">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$cntVor01 &gt; 1">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>564: ONLY ONE VOR CAN HAVE THE VALUE 01</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M93"/>
   <xsl:template match="@*|node()" priority="-2" mode="M93">
      <xsl:apply-templates select="*" mode="M93"/>
   </xsl:template>

   <!--PATTERN arrest-micr-edits-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject"
                 priority="1012"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject"/>
      <xsl:variable name="arrestNumber"
                    select="./ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID"/>
      <xsl:variable name="arrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject[@s:id = current()/ndexia:ArrestSubjectAugmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:ArrestSubject/@s:id = $arrestSubject]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenderAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonAgeMeasure/nc:MeasurePointValue[../../@s:id = $offender]/text()"/>

		    <!--REPORT error-->
<xsl:if test="not(boolean($arrestNumber)) and not(9004 = number(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode/text()))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($arrestNumber)) and not(9004 = number(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode/text()))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>700: ARREST NUMBER IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="arrest"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation[nc:PersonReference/@s:ref = $offender]/nc:ActivityReference/@s:ref"/>
      <xsl:variable name="arrestDispo"
                    select="./ndexia:ArrestSubjectAugmentation/ndexia:ArresteeJuvenileDispositionCode"/>
      <xsl:variable name="age"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person[ndexia:PersonAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $arrest]/nc:PersonAgeMeasure/nc:MeasurePointValue/text()"/>

		    <!--REPORT error-->
<xsl:if test="count($age) &lt;= 1 and boolean($age) and number($age) &gt; 17 and boolean($arrestDispo)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count($age) &lt;= 1 and boolean($age) and number($age) &gt; 17 and boolean($arrestDispo)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>720: ARREST DISPO MUST BE BLANK</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="count($age) &lt;= 1 and boolean($age) and number($age)&lt; 18 and number($age) &gt;= 7 and not(boolean($arrestDispo))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count($age) &lt;= 1 and boolean($age) and number($age)&lt; 18 and number($age) &gt;= 7 and not(boolean($arrestDispo))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>702: ARREST DISPO IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="count($age) &lt;= 1 and boolean($age) and number($age) &lt; 18 and number($age) &gt;= 7 and boolean($arrestDispo) and not ($arrestDispo = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='DISPOSITION_OF_ARREST_UNDER_18'] and COLUMN[@NAME='ERROR_NUMBER' and .='719']]/COLUMN[@NAME='CODE'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count($age) &lt;= 1 and boolean($age) and number($age) &lt; 18 and number($age) &gt;= 7 and boolean($arrestDispo) and not ($arrestDispo = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='DISPOSITION_OF_ARREST_UNDER_18'] and COLUMN[@NAME='ERROR_NUMBER' and .='719']]/COLUMN[@NAME='CODE'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>719: ARREST DISPO MUST BE H/R</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$age &lt; $offenderAge">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$age &lt; $offenderAge">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>703: ARREST AGE CANNOT BE LESS THAN OFFENDER AGE</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="arrestClearance"
                    select="./ndexia:ArrestSubjectAugmentation/ndexia:ArresteeClearanceIndicator"/>

		    <!--REPORT error-->
<xsl:if test="exists($arrestClearance)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="exists($arrestClearance)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>730: Clearance Indicator Is Not a Valid Field</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="arrestMultIndicator"
                    select="./ndexia:ArrestSubjectAugmentation/j:ArrestSubjectCountCode"/>
      <xsl:variable name="offenderForArrest"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:ArrestSubject/@s:id=current()/ndexia:ArrestSubjectAugmentation/lexslib:SameAsDigestReference/@lexslib:ref]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offenderForArrest]"/>

		    <!--REPORT error-->
<xsl:if test="not(boolean($arrestMultIndicator)) and                 count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($arrestMultIndicator)) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>701: MULTI ARR INDICATOR IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($arrestMultIndicator) and not($arrestMultIndicator = $fbi_codes//xsd:simpleType[@name='MultipleArresteeSegmentsCodeSimpleType']/xsd:restriction/xsd:enumeration/@value) and                 count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($arrestMultIndicator) and not($arrestMultIndicator = $fbi_codes//xsd:simpleType[@name='MultipleArresteeSegmentsCodeSimpleType']/xsd:restriction/xsd:enumeration/@value) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>718: MULTIPLE ARREST INDICATOR MUST BE M/C/N</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:variable name="offenderSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:ArrestSubject/@s:id=$arrestSubject]/j:Subject/@s:id"/>
      <xsl:variable name="offenderNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Subject[ndexia:SubjectAugmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenderSubject]/ndexia:SubjectAugmentation/ndexia:SubjectSequenceNumberText"/>

		    <!--REPORT error-->
<xsl:if test="mspfx:error-731($arrestNumber, $offenderNumber)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="mspfx:error-731($arrestNumber, $offenderNumber)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>
               <xsl:text/>
               <xsl:value-of select="mspfx:error-message('731')"/>
               <xsl:text/>
            </svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport"
                 priority="1011"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport"/>

		    <!--REPORT error-->
<xsl:if test="count(distinct-values(data(for $I in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID/text() return replace($I,'^0','')))) !=             count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID/text())">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count(distinct-values(data(for $I in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID/text() return replace($I,'^0','')))) != count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID/text())">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>220: ARREST NUMBER ALREADY EXISTS" </svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Arrest']"
                 priority="1010"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity[nc:Activity/nc:ActivityCategoryText='Arrest']"/>
      <xsl:variable name="arrestDate" select="./nc:Activity/nc:ActivityDate"/>
      <xsl:variable name="incDate" select="xs:date($incidentDate)"/>
      <xsl:variable name="currentDate" select="current-date()"/>
      <xsl:variable name="arrestID" select="./nc:Activity/@s:id"/>
      <xsl:variable name="arrestType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Arrest[ndexia:ArrestAugmentation/lexslib:SameAsDigestReference/@lexslib:ref=$arrestID]/j:ArrestCategoryCode/text()"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation[nc:ActivityReference/@s:ref=$arrestID]/nc:PersonReference/@s:ref"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offender]"/>

		    <!--REPORT error-->
<xsl:if test="empty($arrestType) and count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty($arrestType) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>701: ARREST TYPE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($arrestType) and not($arrestType = $fbi_codes//xsd:simpleType[@name='ArrestCategoryCodeSimpleType']//xsd:enumeration/@value) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($arrestType) and not($arrestType = $fbi_codes//xsd:simpleType[@name='ArrestCategoryCodeSimpleType']//xsd:enumeration/@value) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>705: ARREST TYPE MUST BE O/S/T</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty($arrestDate/nc:Date/text()) and count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty($arrestDate/nc:Date/text()) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>701: ARREST DATE IS REQUIRED.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($arrestDate) and $arrestDate/nc:Date castable as xs:date and  xs:date($arrestDate/nc:Date) &gt; $currentDate and count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($arrestDate) and $arrestDate/nc:Date castable as xs:date and xs:date($arrestDate/nc:Date) &gt; $currentDate and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>717: ARREST DATE CANNOT BE A FUTURE DATE </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($arrestDate) and string-length($incidentDate) &gt; 0 and ($arrestDate/nc:Date castable as xs:date) and ($incDate castable as xs:date) and xs:date($arrestDate/nc:Date) &lt; $incDate and count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($arrestDate) and string-length($incidentDate) &gt; 0 and ($arrestDate/nc:Date castable as xs:date) and ($incDate castable as xs:date) and xs:date($arrestDate/nc:Date) &lt; $incDate and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>717: ARREST DATE CANNOT BE PRIOR TO INCIDENT DATE</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense"
                 priority="1009"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense"/>
      <xsl:variable name="offenseCode" select="./msp:OffenseCategoryCode"/>
      <xsl:variable name="numberOfArrests"
                    select="count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject)"/>

		    <!--REPORT error-->
<xsl:if test="$offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='704']]/COLUMN[@NAME='CODE'] and $numberOfArrests &gt; 0 and not($offenses = (09001))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='704']]/COLUMN[@NAME='CODE'] and $numberOfArrests &gt; 0 and not($offenses = (09001))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>704: ARREST CANNOT BE ENTERED FOR OFFENSE 09004, 09005, and 09006</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation"
                 priority="1008"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = current()/lexsdigest:SubjectPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="victim"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = current()/lexsdigest:VictimPersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="offense"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$victim]"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offense]"/>
      <xsl:variable name="arrest"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[@s:id  = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation[lexsdigest:PersonReference/@s:ref=$offender]/lexsdigest:ActivityReference/@s:ref]/@s:id"/>
      <xsl:variable name="arrestCharge"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest/msp:ArrestChargeCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$arrest]"/>
      <xsl:variable name="arrestSubjectId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject[nc:RoleOfPersonReference/@s:ref=$offender]/@s:id"/>
      <xsl:variable name="arrestNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $arrestSubjectId]/j:ArrestSequenceID/nc:IdentificationID"/>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person[ndexia:PersonAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText/text() = 'Arrest']/@s:id]"
                 priority="1007"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person[ndexia:PersonAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText/text() = 'Arrest']/@s:id]"/>
      <xsl:variable name="arrest"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Arrest' and @s:id = current()/ndexia:PersonAugmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="arrestCharge"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest/msp:ArrestChargeCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$arrest]"/>
      <xsl:variable name="arrestRace"
                    select="./ndexia:PersonAugmentation/ndexia:PersonRaceCode[../lexslib:SameAsDigestReference/@lexslib:ref=$arrest]"/>
      <xsl:variable name="arrestAge"
                    select="./ndexia:PersonAugmentation[lexslib:SameAsDigestReference/@lexslib:ref=$arrest]/../nc:PersonAgeMeasure"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = //lexs:DataItemPackage//lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation[nc:ActivityReference/@s:ref = $arrest]/nc:PersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offender]"/>
      <xsl:variable name="arrestSubjectId"
                    select="$offenderArrestSubject/../j:ArrestSubject/@s:id"/>
      <xsl:variable name="arrestNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $arrestSubjectId]/j:ArrestSequenceID/nc:IdentificationID"/>
      <xsl:variable name="completeIndicator"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Incident/msp:IncidentCompleteIndicator"/>

		    <!--REPORT error-->
<xsl:if test="boolean($arrest) and not($duplicateOffender) and not(boolean($arrestRace))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($arrest) and not($duplicateOffender) and not(boolean($arrestRace))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>701: ARREST RACE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($arrestRace) and not ($arrestRace = ($ndexia_codes//xsd:simpleType[@name='RACCodeSimpleType']//xsd:enumeration/@value)) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($arrestRace) and not ($arrestRace = ($ndexia_codes//xsd:simpleType[@name='RACCodeSimpleType']//xsd:enumeration/@value)) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>708: ARREST RACE MUST BE A/B/I/P/U/W</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(empty($arrestAge) or empty($arrestAge/nc:TimeUnitCode) or empty($arrestAge/nc:MeasurePointValue))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(empty($arrestAge) or empty($arrestAge/nc:TimeUnitCode) or empty($arrestAge/nc:MeasurePointValue))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>701: ARREST AGE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($arrestAge) and number($arrestAge/nc:MeasurePointValue) &lt; 7">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($arrestAge) and number($arrestAge/nc:MeasurePointValue) &lt; 7">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>706: ARREST AGE MUST BE 7 OR GREATER</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="not(boolean($arrestAge/nc:PersonAgeMeasure)) and boolean($arrestAge/nc:TimeUnitCode) and $arrestAge/nc:TimeUnitCode = 'ANN' and boolean($arrestAge/nc:MeasurePointValue) and ((number($arrestAge/nc:MeasurePointValue) &gt;= 1 and number($arrestAge/nc:MeasurePointValue) &lt;= 6) or number($arrestAge/nc:MeasurePointValue) = 99)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($arrestAge/nc:PersonAgeMeasure)) and boolean($arrestAge/nc:TimeUnitCode) and $arrestAge/nc:TimeUnitCode = 'ANN' and boolean($arrestAge/nc:MeasurePointValue) and ((number($arrestAge/nc:MeasurePointValue) &gt;= 1 and number($arrestAge/nc:MeasurePointValue) &lt;= 6) or number($arrestAge/nc:MeasurePointValue) = 99)">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: Please verify the age of the arrestee(s) is 01-06 or 99 years or older.  Unknown arrestee(s) age should be reported as 00.  If changes are required, please submit with the next MICR submission.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(string-length(./nc:PersonAgeMeasure/nc:MeasurePointValue) &gt; 0 or string-length(./nc:PersonAgeMeasure/nc:TimeUnitCode) &gt; 0) and             number(some $x in $offenses  satisfies $x = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='707']]/COLUMN[@NAME='CODE'] or             number($arrestCharge) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARREST_CHARGE'] and COLUMN[@NAME='ERROR_NUMBER' and .='707']]/COLUMN[@NAME='CODE']) and             string-length($arrestNumber) &gt; 0 and             number(./nc:PersonAgeMeasure/nc:MeasurePointValue) &gt; 17 and ./nc:PersonAgeMeasure/nc:TimeUnitCode = 'ANN'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(string-length(./nc:PersonAgeMeasure/nc:MeasurePointValue) &gt; 0 or string-length(./nc:PersonAgeMeasure/nc:TimeUnitCode) &gt; 0) and number(some $x in $offenses satisfies $x = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='707']]/COLUMN[@NAME='CODE'] or number($arrestCharge) = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARREST_CHARGE'] and COLUMN[@NAME='ERROR_NUMBER' and .='707']]/COLUMN[@NAME='CODE']) and string-length($arrestNumber) &gt; 0 and number(./nc:PersonAgeMeasure/nc:MeasurePointValue) &gt; 17 and ./nc:PersonAgeMeasure/nc:TimeUnitCode = 'ANN'">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>707: ARREST AGE MUST BE LESS THAN 18</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson"
                 priority="1006"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson"/>
      <xsl:variable name="arrestSex"
                    select="./lexsdigest:Person[@s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref]/nc:PersonSexCode"/>
      <xsl:variable name="offender" select="./lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offender]"/>

		    <!--REPORT error-->
<xsl:if test="not($duplicateOffender) and not(boolean($arrestSex)) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($duplicateOffender) and not(boolean($arrestSex)) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>701: ARREST SEX IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($arrestSex) and not($arrestSex = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARREST_SEX'] and COLUMN[@NAME='ERROR_NUMBER' and .='709']]/COLUMN[@NAME='CODE']) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($arrestSex) and not($arrestSex = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARREST_SEX'] and COLUMN[@NAME='ERROR_NUMBER' and .='709']]/COLUMN[@NAME='CODE']) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>709: ARREST SEX MUST BE M/F</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists(./j:ArrestSubject) and not($action = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ACTION'] and COLUMN[@NAME='ERROR_NUMBER' and .='115']]/COLUMN[@NAME='CODE']) and             (exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceCode) or              exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceDate/nc:Date))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(./j:ArrestSubject) and not($action = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ACTION'] and COLUMN[@NAME='ERROR_NUMBER' and .='115']]/COLUMN[@NAME='CODE']) and (exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceCode) or exists(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Incident/j:IncidentAugmentation/j:IncidentExceptionalClearanceDate/nc:Date))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>115: ARREST RECORD EXISTS, CANNOT ENTER EXCEPTIONAL CLEARANCE</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/lexslib:SameAsDigestReference"
                 priority="1005"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/lexslib:SameAsDigestReference"/>
      <xsl:variable name="ArrestSubject" select="./@lexslib:ref"/>

		    <!--REPORT error-->
<xsl:if test="not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject[@s:id = $ArrestSubject]))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(exists(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/j:ArrestSubject[@s:id = $ArrestSubject]))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>727: ARREST INFORMATION MUST MATCH OFFENDER NUMBER, RACE AND SEX.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest"
                 priority="1004"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Arrest"/>
      <xsl:variable name="arrestCharge" select="./msp:ArrestChargeCode"/>
      <xsl:variable name="arrestSubjectAssocId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Arrest' and @s:id = current()/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation/nc:PersonReference/@s:ref and //lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:ArrestSubjectAssociation/nc:ActivityReference/@s:ref = $arrestSubjectAssocId]/@s:id"/>
      <xsl:variable name="vitimOffenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:VictimPersonReference/@s:ref[$offender=../../lexsdigest:SubjectPersonReference/@s:ref]"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[../../nc:PersonReference/@s:ref=$vitimOffenseId]"/>
      <xsl:variable name="offenseCode"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offender]"/>

		    <!--REPORT error-->
<xsl:if test="not(boolean($arrestCharge)) or (not(boolean($arrestCharge)) and  $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='701_5']]/COLUMN[@NAME='CODE'] and             count($offenderArrestSubject) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($arrestCharge)) or (not(boolean($arrestCharge)) and $offenseCode = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='701_5']]/COLUMN[@NAME='CODE'] and count($offenderArrestSubject) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>701: ARREST CHARGE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(every $x in $offenses  satisfies $x = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='712']]/COLUMN[@NAME='CODE']) and             ($arrestCharge = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARREST_CHARGE'] and COLUMN[@NAME='ERROR_NUMBER' and .='712']]/COLUMN[@NAME='CODE']) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(every $x in $offenses satisfies $x = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='712']]/COLUMN[@NAME='CODE']) and ($arrestCharge = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARREST_CHARGE'] and COLUMN[@NAME='ERROR_NUMBER' and .='712']]/COLUMN[@NAME='CODE']) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>712: ARREST CHARGE MUST BE TYPE B</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(every $x in $offenses  satisfies $x = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='712']]/COLUMN[@NAME='CODE']) and             ($arrestCharge = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARREST_CHARGE'] and COLUMN[@NAME='ERROR_NUMBER' and .='712']]/COLUMN[@NAME='CODE']) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(every $x in $offenses satisfies $x = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='OFFENSE_FILE_CLASS'] and COLUMN[@NAME='ERROR_NUMBER' and .='712']]/COLUMN[@NAME='CODE']) and ($arrestCharge = $val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARREST_CHARGE'] and COLUMN[@NAME='ERROR_NUMBER' and .='712']]/COLUMN[@NAME='CODE']) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>713: OFFENSE CODE NOT GROUP A BUT ARREST CODE IS GROUP A</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($arrestCharge) and not ($arrcd_lookup//ROW/COLUMN[@NAME='ARRCD_ARREST_CO'] = number($arrestCharge)) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($arrestCharge) and not ($arrcd_lookup//ROW/COLUMN[@NAME='ARRCD_ARREST_CO'] = number($arrestCharge)) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>712: ARREST CHARGE NOT A VALID ARREST CODE</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ArrestSubject"
                 priority="1003"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ArrestSubject"/>
      <xsl:variable name="armedCount" select="count(./msp:ArrestSubjectArmedWithCode)"/>
      <xsl:variable name="armedValues" select="./msp:ArrestSubjectArmedWithCode"/>
      <xsl:variable name="armedValue1" select="./msp:ArrestSubjectArmedWithCode[1]"/>
      <xsl:variable name="armedValue2" select="./msp:ArrestSubjectArmedWithCode[2]"/>
      <xsl:variable name="unarmedCount"
                    select="count(./msp:ArrestSubjectArmedWithCode[text()='01'])"/>
      <xsl:variable name="arrestSubject"
                    select="./msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:ArrestSubject/@s:id = $arrestSubject]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offender]"/>

		    <!--REPORT error-->
<xsl:if test="$armedCount =2 and                         count(distinct-values($armedValues)) = 1 and                         count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$armedCount =2 and count(distinct-values($armedValues)) = 1 and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>715: ARMED 1 AND ARMED 2 CANNOT BE THE SAME.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$unarmedCount &gt; 0 and                        $armedCount &gt; 1 and                       count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$unarmedCount &gt; 0 and $armedCount &gt; 1 and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>716: ARMED 2 MUST BE BLANK IF ARMED 1 IS 01  OR  ARMED 1 MUST BE BLANK IF ARMED 2 IS 01</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$armedCount = 0 or ($armedCount = 0 and                       count($offenderArrestSubject) &gt; 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$armedCount = 0 or ($armedCount = 0 and count($offenderArrestSubject) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>701: ARREST ARMED IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($armedValue1) and not(normalize-space($armedValue1) = distinct-values($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARMED'] and COLUMN[@NAME='ERROR_NUMBER' and .='714']]/COLUMN[@NAME='CODE'])) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($armedValue1) and not(normalize-space($armedValue1) = distinct-values($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARMED'] and COLUMN[@NAME='ERROR_NUMBER' and .='714']]/COLUMN[@NAME='CODE'])) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>714: INVALID ARMED 1.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($armedValue1) and string-length(normalize-space($armedValue1)) = 3 and (distinct-values($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARMED'] and COLUMN[@NAME='ERROR_NUMBER' and .='714']]/COLUMN[@NAME='CODE']) = substring($armedValue1,1,2)) and not(ends-with($armedValue1,'A') ) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($armedValue1) and string-length(normalize-space($armedValue1)) = 3 and (distinct-values($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARMED'] and COLUMN[@NAME='ERROR_NUMBER' and .='714']]/COLUMN[@NAME='CODE']) = substring($armedValue1,1,2)) and not(ends-with($armedValue1,'A') ) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>714: 3rd CHAR OF ARMED 1 MUST BE 'A' OR BLANK.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($armedValue2) and not(normalize-space($armedValue2) = distinct-values($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARMED'] and COLUMN[@NAME='ERROR_NUMBER' and .='714']]/COLUMN[@NAME='CODE'])) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($armedValue2) and not(normalize-space($armedValue2) = distinct-values($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARMED'] and COLUMN[@NAME='ERROR_NUMBER' and .='714']]/COLUMN[@NAME='CODE'])) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>714: INVALID ARMED 2.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($armedValue2) and string-length(normalize-space($armedValue2)) = 3 and (distinct-values($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARMED'] and COLUMN[@NAME='ERROR_NUMBER' and .='714']]/COLUMN[@NAME='CODE'])  = substring($armedValue2,1,2)) and not(ends-with($armedValue2,'A') ) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($armedValue2) and string-length(normalize-space($armedValue2)) = 3 and (distinct-values($val_lookup//ROW[COLUMN[@NAME='DATA_ELEMENT' and .='ARMED'] and COLUMN[@NAME='ERROR_NUMBER' and .='714']]/COLUMN[@NAME='CODE']) = substring($armedValue2,1,2)) and not(ends-with($armedValue2,'A') ) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>714: 3rd CHAR OF ARMED 2 MUST BE 'A' OR BLANK.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject"
                 priority="1002"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject"/>
      <xsl:variable name="arrestMultIndicator"
                    select="./ndexia:ArrestSubjectAugmentation/j:ArrestSubjectCountCode"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:ArrestSubject/@s:id=current()/ndexia:ArrestSubjectAugmentation/lexslib:SameAsDigestReference/@lexslib:ref]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offender]"/>

		    <!--REPORT error-->
<xsl:if test="not(boolean($arrestMultIndicator)) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not(boolean($arrestMultIndicator)) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>701: MULTI ARR INDICATOR IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="boolean($arrestMultIndicator) and not($arrestMultIndicator = $fbi_codes//xsd:simpleType[@name='MultipleArresteeSegmentsCodeSimpleType']/xsd:restriction/xsd:enumeration/@value) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($arrestMultIndicator) and not($arrestMultIndicator = $fbi_codes//xsd:simpleType[@name='MultipleArresteeSegmentsCodeSimpleType']/xsd:restriction/xsd:enumeration/@value) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>718: MULTIPLE ARREST INDICATOR MUST BE M/C/N</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Person"
                 priority="1001"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Person"/>
      <xsl:variable name="arrectEthnic" select="./msp:PersonEthnicityCode"/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = current()/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offender]"/>

		    <!--REPORT error-->
<xsl:if test="boolean($arrectEthnic) and not ($arrectEthnic = $ethinicity_lookup//ROW/COLUMN[@NAME='ETHINICITY_CODE']/text()) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($arrectEthnic) and not ($arrectEthnic = $ethinicity_lookup//ROW/COLUMN[@NAME='ETHINICITY_CODE']/text()) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>710: ARREST ETHNICITY MUST BE A/H/O/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ResidenceAssociation/msp:ResidenceCategoryCode"
                 priority="1000"
                 mode="M94">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:ResidenceAssociation/msp:ResidenceCategoryCode"/>
      <xsl:variable name="residenceAssociation"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/nc:ResidenceAssociation[ @s:id=current()/../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id "/>
      <xsl:variable name="offender"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = $residenceAssociation/../nc:PersonReference/@s:ref]/@s:id"/>
      <xsl:variable name="offenderArrestSubject"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = ../j:Subject/nc:RoleOfPersonReference/@s:ref and @s:id = ../j:ArrestSubject/nc:RoleOfPersonReference/@s:ref and @s:id=$offender]"/>

		    <!--REPORT error-->
<xsl:if test="boolean(.) and not(. = $residence_lookup//ROW/COLUMN[@NAME='CODE']/text()) and             count($offenderArrestSubject) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean(.) and not(. = $residence_lookup//ROW/COLUMN[@NAME='CODE']/text()) and count($offenderArrestSubject) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>711: ARREST RESIDENT MUST BE R/C/S/O/U</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M94"/>
   <xsl:template match="@*|node()" priority="-2" mode="M94">
      <xsl:apply-templates select="*" mode="M94"/>
   </xsl:template>

   <!--PATTERN property_global_micr_edits-->
<xsl:variable name="propertyClassList"
                 select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyCategoryCode/number(text())"/>
   <xsl:variable name="drugTypeList"
                 select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug/msp:SuspectedDrugCategoryCode/text()"/>
   <xsl:variable name="propertyValueList"
                 select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = (//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug/@s:id | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:TangibleItem/@s:id) or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = (//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug/@s:id | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:TangibleItem/@s:id)]/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount/text()"/>
   <xsl:variable name="propertyListCount"
                 select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = (//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug/@s:id | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:TangibleItem/@s:id) or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = (//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug/@s:id | //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:TangibleItem/@s:id)]/ndexia:ItemQuantityStatusValue/ndexia:ItemValue"/>
   <xsl:variable name="checkClass"
                 select="some $offense in $completeOffenses satisfies $offense = (28000,10001,10002,51000,22001,22002,35001,35002,24002)"/>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport"
                 priority="1000"
                 mode="M95">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport"/>

		    <!--REPORT error-->
<xsl:if test="$attemptReqProp and not(some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = (0,9))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$attemptReqProp and not(some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = (0,9))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>162: PROPERTY LOSS TYPE OF 0 OR 9 MUST BE ENTERED FOR ATTEMPTS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(every $offenseFileClass in $offenses satisfies ($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '212']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass])) and $isActionOR and $propertyExist">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(every $offenseFileClass in $offenses satisfies ($val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '212']/../COLUMN[@NAME = 'CODE' and text() = $offenseFileClass])) and $isActionOR and $propertyExist">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>212: NO FILE CLASS FOUND WHICH REQUIRES PROPERTY INFORMATION</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists(./msp:Property) and (every $prop in ./msp:Property satisfies     ($completeOffenses = (35001,35002,28000) and number($prop/msp:PropertyLossCode) = 0 and not(number($prop/msp:PropertySequenceNumberText) = 0))     or ($completeOffenses = (10001,10002,51000,22001,22002) and number($prop/msp:PropertyLossCode) = (0,9) and not(number($prop/msp:PropertySequenceNumberText) = 0))) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(./msp:Property) and (every $prop in ./msp:Property satisfies ($completeOffenses = (35001,35002,28000) and number($prop/msp:PropertyLossCode) = 0 and not(number($prop/msp:PropertySequenceNumberText) = 0)) or ($completeOffenses = (10001,10002,51000,22001,22002) and number($prop/msp:PropertyLossCode) = (0,9) and not(number($prop/msp:PropertySequenceNumberText) = 0)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>900: PROPERTY ITEM MUST BE 0</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="count(./msp:Property/msp:PropertySequenceNumberText[number(text()) = 0]) &gt; 1">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count(./msp:Property/msp:PropertySequenceNumberText[number(text()) = 0]) &gt; 1">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>902: PROPERTY ITEM 0 CANNOT BE DUPLICATED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(count(./msp:Property/msp:PropertyLossCode[number(text()) = 5]) &gt; count(distinct-values(./msp:Property[msp:PropertyLossCode/number(text()) = 5]/msp:PropertySequenceNumberText)))           or (count(./msp:Property/msp:PropertyLossCode[number(text()) = 7]) &gt; count(distinct-values(./msp:Property[msp:PropertyLossCode/number(text()) = 7]/msp:PropertySequenceNumberText)))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(count(./msp:Property/msp:PropertyLossCode[number(text()) = 5]) &gt; count(distinct-values(./msp:Property[msp:PropertyLossCode/number(text()) = 5]/msp:PropertySequenceNumberText))) or (count(./msp:Property/msp:PropertyLossCode[number(text()) = 7]) &gt; count(distinct-values(./msp:Property[msp:PropertyLossCode/number(text()) = 7]/msp:PropertySequenceNumberText)))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>902: PROPERTY ITEM CANNOT OCCUR MORE THAN TWICE FOR ITEM TO BE DUPLICATED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$attemptReqProp and not(some $prop in ./msp:Property satisfies $prop/msp:PropertySequenceNumberText/number(text()) = 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$attemptReqProp and not(some $prop in ./msp:Property satisfies $prop/msp:PropertySequenceNumberText/number(text()) = 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>903: ITEM NUMBER CANNOT BE GREATER THAN 0</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty($drugTypeList) and $attemptOffenses = 35001">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty($drugTypeList) and $attemptOffenses = 35001">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>907: DRUG TYPE REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists(./msp:Property) and (every $prop in ./msp:Property satisfies           (($completeOffenses = (22001,22002) and $prop/msp:PropertyLossCode/text() = (1,5,7) and ($prop/msp:PropertyCategoryCode/text() = (99,29 to 35)))           or ($completeOffenses = (23001,23002) and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (1,3 to 5,12,15,18,24,28 to 35,37,39,66,78)))           or ($completeOffenses = (23003 to 23006) and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (3,5,24,28 to 35,37)))           or ($completeOffenses = (21000,23007) and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (3,5,24,28,37)))           or ($completeOffenses = (30002,30004) and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (1,3,5,12,15,18,24,28 to 35,37,39,66)))           or ($completeOffenses = 24001 and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (29 to 35,77)))           or ($completeOffenses = 35001 and $prop/msp:PropertyLossCode/text() = 6 and empty($prop/msp:PropertyCategoryCode/text()))           or ($completeOffenses = 35002 and ($prop/msp:PropertyLossCode/text() = 6 and (empty($prop/msp:PropertyCategoryCode/text())) or $prop/msp:PropertyCategoryCode/text() = 10))           or ($completeOffenses = 23007 and prop/msp:PropertyCategoryCode/text() = (1,5,24,28,37))           or (not($completeOffenses = 23007) and $prop/msp:PropertyCategoryCode/text() = (29 to 35) and $prop/msp:PropertyLossCode/text() = (1,5,7))           or ($completeOffenses = 24002 and not($prop/msp:PropertyLossCode/text() = 0) and empty($prop/msp:PropertyCategoryCode/text()))))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(./msp:Property) and (every $prop in ./msp:Property satisfies (($completeOffenses = (22001,22002) and $prop/msp:PropertyLossCode/text() = (1,5,7) and ($prop/msp:PropertyCategoryCode/text() = (99,29 to 35))) or ($completeOffenses = (23001,23002) and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (1,3 to 5,12,15,18,24,28 to 35,37,39,66,78))) or ($completeOffenses = (23003 to 23006) and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (3,5,24,28 to 35,37))) or ($completeOffenses = (21000,23007) and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (3,5,24,28,37))) or ($completeOffenses = (30002,30004) and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (1,3,5,12,15,18,24,28 to 35,37,39,66))) or ($completeOffenses = 24001 and (empty($prop/msp:PropertyCategoryCode/text()) or $prop/msp:PropertyCategoryCode/text() = (29 to 35,77))) or ($completeOffenses = 35001 and $prop/msp:PropertyLossCode/text() = 6 and empty($prop/msp:PropertyCategoryCode/text())) or ($completeOffenses = 35002 and ($prop/msp:PropertyLossCode/text() = 6 and (empty($prop/msp:PropertyCategoryCode/text())) or $prop/msp:PropertyCategoryCode/text() = 10)) or ($completeOffenses = 23007 and prop/msp:PropertyCategoryCode/text() = (1,5,24,28,37)) or (not($completeOffenses = 23007) and $prop/msp:PropertyCategoryCode/text() = (29 to 35) and $prop/msp:PropertyLossCode/text() = (1,5,7)) or ($completeOffenses = 24002 and not($prop/msp:PropertyLossCode/text() = 0) and empty($prop/msp:PropertyCategoryCode/text()))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>909: ILLOGICAL PROPERTY DESCRIPTION FOR OFFENSE SUBMITTED IN PROP RECORD</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = 2))            or (count($offenses) &gt; 1 and not($lossTypeList = 2)) ) and $completeOffenses = 20000">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = 2)) or (count($offenses) &gt; 1 and not($lossTypeList = 2)) ) and $completeOffenses = 20000">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>910: PROPERTY TYPE MUST BE 2</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = 4))            or (count($offenses) &gt; 1 and not($lossTypeList = 4))) and $completeOffenses = 29000">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = 4)) or (count($offenses) &gt; 1 and not($lossTypeList = 4))) and $completeOffenses = 29000">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>911: PROPERTY TYPE MUST BE 4</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = 6))            or (count($offenses) &gt; 1 and not($lossTypeList = 6))) and $completeOffenses = (39000 to 39009)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = 6)) or (count($offenses) &gt; 1 and not($lossTypeList = 6))) and $completeOffenses = (39000 to 39009)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>912: PROPERTY TYPE MUST BE 6</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (0,6)))            or (count($offenses) &gt; 1 and not($lossTypeList = (0,6)))) and $completeOffenses = (35001 to 35002)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (0,6))) or (count($offenses) &gt; 1 and not($lossTypeList = (0,6)))) and $completeOffenses = (35001 to 35002)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>913: PROPERTY TYPE MUST BE 0 OR 6</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (0,5)))            or (count($offenses) &gt; 1 and not($lossTypeList = (0,5)))) and $completeOffenses = (24002,28000)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (0,5))) or (count($offenses) &gt; 1 and not($lossTypeList = (0,5)))) and $completeOffenses = (24002,28000)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>914: PROPERTY TYPE MUST BE 0 OR 5</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (3,5,6)))            or (count($offenses) &gt; 1 and not($lossTypeList = (3,5,6)))) and $completeOffenses = 25000">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (3,5,6))) or (count($offenses) &gt; 1 and not($lossTypeList = (3,5,6)))) and $completeOffenses = 25000">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>915: PROPERTY TYPE MUST BE 3, 5, or 6</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (1,5,7)))            or (count($offenses) &gt; 1 and not($lossTypeList = (1,5,7)))) and $completeOffenses = (12000,21000,23001 to 23007,24001,24003,26001 to 26005, 26007, 26008, 27000,30001 to 30003)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (1,5,7))) or (count($offenses) &gt; 1 and not($lossTypeList = (1,5,7)))) and $completeOffenses = (12000,21000,23001 to 23007,24001,24003,26001 to 26005, 26007, 26008, 27000,30001 to 30003)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>916: PROPERTY TYPE MUST BE 1, 5, or 7</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (0,1,5,7,9)))            or (count($offenses) &gt; 1 and not($lossTypeList = (0,1,5,7,9)))) and $completeOffenses = (10001,10002,22001,22002,51000)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((count($offenses) = 1 and not(every $lossType in (./msp:Property/msp:PropertyLossCode/text()) satisfies $lossType = (0,1,5,7,9))) or (count($offenses) &gt; 1 and not($lossTypeList = (0,1,5,7,9)))) and $completeOffenses = (10001,10002,22001,22002,51000)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>917: PROPERTY TYPE MUST BE 0/1/5/7/9</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$completeOffenses = 35001 and not($completeOffenses = 35002) and exists(./msp:Property) and (some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/text() = 6 and number($prop/msp:PropertyCategoryCode/text()) = 11)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$completeOffenses = 35001 and not($completeOffenses = 35002) and exists(./msp:Property) and (some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/text() = 6 and number($prop/msp:PropertyCategoryCode/text()) = 11)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>925: PROPERTY CLASS CANNOT BE 11</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($completeOffenses = 35001) and exists(./msp:Property) and (some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/text() = 6 and number($prop/msp:PropertyCategoryCode/text()) = 10)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($completeOffenses = 35001) and exists(./msp:Property) and (some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/text() = 6 and number($prop/msp:PropertyCategoryCode/text()) = 10)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>925: PROPERTY CLASS CANNOT BE 10</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$propertyClassList = 77 and count($propertyClassList) &gt; 1">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$propertyClassList = 77 and count($propertyClassList) &gt; 1">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>927: PROPERTY RECORD WITH CLASS 77 MUST EXIST ALONE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="count($completeOffenses) &gt; 1 and ($propertyValueList &gt; 0 and count($propertyValueList) = count(./msp:Property)) and ($attemptReqProp or $completeOffenses = (10001,10002,22001,22002,24002,28000,35001,35002,51000)           and not(some $prop in ./msp:Property satisfies            ($completeOffenses = 28000 and $prop/msp:PropertyLossCode/number(text()) = 5)            or ($completeOffenses = (10001,10002,51000,22001,22002) and $prop/msp:PropertyLossCode[number(text()) = (1,5,7)])            or ($completeOffenses = 35001 and ($prop/msp:PropertyLossCode/number(text()) = 6 and not($prop/msp:PropertyCategoryCode/text() = 10) or empty(//msp:Drug[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $prop/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref])))            or ($completeOffenses = 35002 and $prop/msp:PropertyLossCode/number(text()) = 6)            or ($completeOffenses = 24002 and not($prop/msp:PropertyLossCode/number(text()) = 0))))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count($completeOffenses) &gt; 1 and ($propertyValueList &gt; 0 and count($propertyValueList) = count(./msp:Property)) and ($attemptReqProp or $completeOffenses = (10001,10002,22001,22002,24002,28000,35001,35002,51000) and not(some $prop in ./msp:Property satisfies ($completeOffenses = 28000 and $prop/msp:PropertyLossCode/number(text()) = 5) or ($completeOffenses = (10001,10002,51000,22001,22002) and $prop/msp:PropertyLossCode[number(text()) = (1,5,7)]) or ($completeOffenses = 35001 and ($prop/msp:PropertyLossCode/number(text()) = 6 and not($prop/msp:PropertyCategoryCode/text() = 10) or empty(//msp:Drug[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $prop/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]))) or ($completeOffenses = 35002 and $prop/msp:PropertyLossCode/number(text()) = 6) or ($completeOffenses = 24002 and not($prop/msp:PropertyLossCode/number(text()) = 0))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>931: PROPERTY VALUE MUST BE ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="count($completeOffenses) = 1           and (exists($propertyValueList) and count($propertyValueList) = count(./msp:Property) and (every $propertyValue in ($propertyValueList) satisfies $propertyValue &gt; 0 ))           and ($attemptReqProp or $completeOffenses = (10001,10002,22001,22002,24002,28000,35001,35002,51000)            and not(every $prop in ./msp:Property satisfies             ($completeOffenses = 28000 and $prop/msp:PropertyLossCode/number(text()) = 5)             or ($completeOffenses = (10001,10002,51000,22001,22002) and $prop/msp:PropertyLossCode[number(text()) = (1,5,7)])             or ($completeOffenses = 35001 and $prop/msp:PropertyLossCode/number(text()) = 6 and not($prop/msp:PropertyCategoryCode/text() = 10))             or ($completeOffenses = 35002 and $prop/msp:PropertyLossCode/number(text()) = 6)             or ($completeOffenses = 24002 and not($prop/msp:PropertyLossCode/number(text()) = 0)))) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count($completeOffenses) = 1 and (exists($propertyValueList) and count($propertyValueList) = count(./msp:Property) and (every $propertyValue in ($propertyValueList) satisfies $propertyValue &gt; 0 )) and ($attemptReqProp or $completeOffenses = (10001,10002,22001,22002,24002,28000,35001,35002,51000) and not(every $prop in ./msp:Property satisfies ($completeOffenses = 28000 and $prop/msp:PropertyLossCode/number(text()) = 5) or ($completeOffenses = (10001,10002,51000,22001,22002) and $prop/msp:PropertyLossCode[number(text()) = (1,5,7)]) or ($completeOffenses = 35001 and $prop/msp:PropertyLossCode/number(text()) = 6 and not($prop/msp:PropertyCategoryCode/text() = 10)) or ($completeOffenses = 35002 and $prop/msp:PropertyLossCode/number(text()) = 6) or ($completeOffenses = 24002 and not($prop/msp:PropertyLossCode/number(text()) = 0))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>931: PROPERTY VALUE MUST BE ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$completeOffenses = 35002 and not((some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = 6 and number($prop/msp:PropertyCategoryCode/text()) = 11) or (some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = 0 and $prop/msp:PropertySequenceNumberText/number(text()) = 0))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$completeOffenses = 35002 and not((some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = 6 and number($prop/msp:PropertyCategoryCode/text()) = 11) or (some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = 0 and $prop/msp:PropertySequenceNumberText/number(text()) = 0))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>932: PROPERTY LOSS TYPE OF 6 AND PROPERTY CLASS OF 11 ARE REQUIRED WITH OFFENSE 35002</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$offenses = 28000 and $action != 'W' and not(exists($assistOriId)) and (every $propertyClass in ($propertyClassList) satisfies number($propertyClass) = (3,5,24,28,37)) and empty(./msp:Property/msp:PropertyLossCode[text() = '0'])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenses = 28000 and $action != 'W' and not(exists($assistOriId)) and (every $propertyClass in ($propertyClassList) satisfies number($propertyClass) = (3,5,24,28,37)) and empty(./msp:Property/msp:PropertyLossCode[text() = '0'])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>946: PROPERTY CLASS CANNOT BE 03/05/24/28/37</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$completeOffenses = (24001) and (not(some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = (1,5,7) and $prop/msp:PropertyCategoryCode/number(text()) = (3,5,24,28,37))) and (not(some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = (0) and $prop/msp:PropertySequenceNumberText/number(text()) = 0))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$completeOffenses = (24001) and (not(some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = (1,5,7) and $prop/msp:PropertyCategoryCode/number(text()) = (3,5,24,28,37))) and (not(some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = (0) and $prop/msp:PropertySequenceNumberText/number(text()) = 0))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>947: PROPERTY CLASS MUST BE 03/05/24/28/37 AND A LOSS TYPE OF 1/5/7</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists(./msp:Property) and $completeOffenses = 35001 and (not(some $prop in ./msp:Property satisfies $prop/msp:PropertyCategoryCode/number(text()) = 10)            and (some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = 6             and (exists(//msp:Drug[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $prop/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/msp:SuspectedDrugCategoryCode/text())            or empty(//msp:Drug/msp:SuspectedDrugCategoryCode/text()) ))) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(./msp:Property) and $completeOffenses = 35001 and (not(some $prop in ./msp:Property satisfies $prop/msp:PropertyCategoryCode/number(text()) = 10) and (some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = 6 and (exists(//msp:Drug[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $prop/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/msp:SuspectedDrugCategoryCode/text()) or empty(//msp:Drug/msp:SuspectedDrugCategoryCode/text()) )))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>953: PROPERTY CLASS OF 10 MUST EXIST</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$completeOffenses = 35002 and //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/@s:id]/msp:PropertyLossCode/number(text())=6  and            not(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=            //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/@s:id]/msp:PropertyCategoryCode/number(text())=11)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$completeOffenses = 35002 and //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/@s:id]/msp:PropertyLossCode/number(text())=6 and not(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref= //lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property/@s:id]/msp:PropertyCategoryCode/number(text())=11)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>954: PROPERTY RECORD MUST EXIS WITH CLASS 11 AND LOSS TYPE OF 6</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists(./msp:Drug/msp:SuspectedDrugCategoryCode[text() = '77']) and not(count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug) = 3)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists(./msp:Drug/msp:SuspectedDrugCategoryCode[text() = '77']) and not(count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug/nc:Drug) = 3)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>958: AT LEAST 3 DRUG TYPES MUST EXIST</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug[msp:SuspectedDrugCategoryCode='99']) &gt;1">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug[msp:SuspectedDrugCategoryCode='99']) &gt;1">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>977: ONLY ONE PROPERTY RECORD CAN EXIST WITH DRUG TYPE 99-UNKNOWN</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="count(//mspRoot:IncidentReport/msp:Drug/msp:SuspectedDrugCategoryCode) &gt; 3 and (some $drug in (//mspRoot:IncidentReport/msp:Drug/msp:SuspectedDrugCategoryCode/text()) satisfies $drug = '77')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="count(//mspRoot:IncidentReport/msp:Drug/msp:SuspectedDrugCategoryCode) &gt; 3 and (some $drug in (//mspRoot:IncidentReport/msp:Drug/msp:SuspectedDrugCategoryCode/text()) satisfies $drug = '77')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>978: IF DRUG TYPE 77 IS USED, ONLY TWO OTHER DRUG TYPES CAN BE LISTED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="(some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = 0 and $prop/msp:PropertySequenceNumberText/number(text()) = 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(some $prop in ./msp:Property satisfies $prop/msp:PropertyLossCode/number(text()) = 0 and $prop/msp:PropertySequenceNumberText/number(text()) = 0)">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: Please verify the zero property record is accurate</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M95"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M95"/>
   <xsl:template match="@*|node()" priority="-2" mode="M95">
      <xsl:apply-templates select="*" mode="M95"/>
   </xsl:template>

   <!--PATTERN property-drug-micr-edits-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug"
                 priority="1000"
                 mode="M96">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug"/>
      <xsl:variable name="propertyId" select="nc:Drug/@s:id"/>
      <xsl:variable name="itemId" select="nc:Drug/@s:id"/>
      <xsl:variable name="itemNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = $propertyId]]/msp:PropertySequenceNumberText/number(text())"/>
      <xsl:variable name="lossType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $propertyId]/msp:PropertyLossCode/number(text())"/>
      <xsl:variable name="propertyClass"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $propertyId]/msp:PropertyCategoryCode/number(text())"/>
      <xsl:variable name="propertyValue"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount/number(text())"/>
      <xsl:variable name="recoverDate"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId  or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/ndexia:ItemStatus/nc:StatusDate/nc:Date/text()"/>
      <xsl:variable name="stolenPropId"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[number(msp:PropertySequenceNumberText/text()) = $itemNumber and number(msp:PropertyLossCode/text()) = 7]/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref"/>
      <xsl:variable name="error905Ex"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 35001] and number($lossType = 0))"/>
      <xsl:variable name="error908Ex2"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[number(msp:OffenseCategoryCode/text()) = 24001]/msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref] and number($propertyClass) = 38 and exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[number(msp:PropertySequenceNumberText/text()) = $itemNumber and exists($val_lookup//ROW[COLUMN/@NAME = 'DATA_ELEMENT' and COLUMN/text() = 'PROPERTY_TYPE' and COLUMN/@NAME = 'ERROR_NUMBER' and COLUMN/text() = '908']/COLUMN[@NAME = 'CODE' and number(text()) = number(msp:PropertyCategoryCode/text())])]/msp:PropertyLossCode[number(text()) = 7]) )"/>
      <xsl:variable name="numStlRecVeh"
                    select="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem/ndexia:TangibleItemAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/ndexia:ItemQuantity/text()"/>
      <xsl:variable name="drugType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/msp:SuspectedDrugCategoryCode/text()"/>
      <xsl:variable name="quantity"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:MeasurePointValue/text()"/>
      <xsl:variable name="measure"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text()"/>
      <xsl:variable name="error908Ex1"
                    select="$propertyClass = 38 and ($completeOffenses = 24001) and //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyCategoryCode/number(text()) = (3,5,24,28,37)"/>

		    <!--REPORT error-->
<xsl:if test="number($itemNumber) = 0 and          ($action = 'W' or $completeOffenses = (20000,29000,12000,24003,26001,26002,26003,26004,26005,27000,30000,30001,23001,23002,23003,23004,23005,23006,21000,23007,30002,30004,24001,39001,39002,39003,39004,25000)          and not(some $offense in $completeOffenses satisfies           (not($lossType = 5) and $offense = 28000)           or ($lossType = (0,9) and $offense = (10001,10002,51000,22001,22002))           or ($lossType = 0 and $offense = 24002)))          and not(some $prop in //msp:Property satisfies $prop/msp:PropertySequenceNumberText/number(text()) &gt; 0) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($itemNumber) = 0 and ($action = 'W' or $completeOffenses = (20000,29000,12000,24003,26001,26002,26003,26004,26005,27000,30000,30001,23001,23002,23003,23004,23005,23006,21000,23007,30002,30004,24001,39001,39002,39003,39004,25000) and not(some $offense in $completeOffenses satisfies (not($lossType = 5) and $offense = 28000) or ($lossType = (0,9) and $offense = (10001,10002,51000,22001,22002)) or ($lossType = 0 and $offense = 24002))) and not(some $prop in //msp:Property satisfies $prop/msp:PropertySequenceNumberText/number(text()) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 901: PROPERTY ITEM MUST NOT BE ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($lossType = (5,7)) and count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertySequenceNumberText[text() = $itemNumber]) &gt; 1">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($lossType = (5,7)) and count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertySequenceNumberText[text() = $itemNumber]) &gt; 1">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 902: PROPERTY ITEM MAY NOT BE DUPLICATED UNLESS LOSS TYPE IS 5 AND 7</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 5 and (some $prop in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) satisfies $prop/msp:PropertyLossCode/number(text()) = 7 and not($prop/msp:PropertyCategoryCode/number(text()) = $propertyClass) and $prop/msp:PropertySequenceNumberText/number(text()) = $itemNumber) and not($error908Ex1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 5 and (some $prop in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) satisfies $prop/msp:PropertyLossCode/number(text()) = 7 and not($prop/msp:PropertyCategoryCode/number(text()) = $propertyClass) and $prop/msp:PropertySequenceNumberText/number(text()) = $itemNumber) and not($error908Ex1)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 908: ITEM TYPE 5 MUST EXIST WITH TYPE 7</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 1 and empty(index-of((for $a in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = true()]]),  $b in ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 918]/COLUMN[@NAME = 'CODE']/text()) return string($a = $b)), 'true'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 1 and empty(index-of((for $a in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = true()]]), $b in ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 918]/COLUMN[@NAME = 'CODE']/text()) return string($a = $b)), 'true'))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 918: IF PROPERTY TYPE = 1, ONE OF THE FOLLOWING FILE CLASSES MUST EXIST AND ATTEMPT MUST = C: 10001, 10002, 12000, 21000, 22001, 22002, 23001 TO 23007, 24001, 24003, 26001 TO 26005, 26007 TO 26008, 27000, 30001 TO 30003, 51000</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 2 and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 20000]/../msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 2 and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 20000]/../msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 919: IF PROPERTY TYPE = 2, FILE CLASS 20000 MUST EXIST AND ATTEMPT MUST = C</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 3 and not($completeOffenses = 25000)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 3 and not($completeOffenses = 25000)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 920: IF PROPERTY TYPE = 3, FILE CLASS 25000 MUST EXIST AND ATTEMPT MUST = C</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 4 and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 29000]/../msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 4 and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 29000]/../msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 921: IF PROPERTY TYPE = 4, FILE CLASS 29000 MUST EXIST AND ATTEMPT MUST = C</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 5           and not($completeOffenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 922]/COLUMN[@NAME = 'CODE']/text())           and not($action = 'W')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 5 and not($completeOffenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 922]/COLUMN[@NAME = 'CODE']/text()) and not($action = 'W')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 922: IF PROPERTY TYPE = 5, ONE OF THE FOLLOWING FILE CLASSES MUST EXIST AND ATTEMPT MUST = C: 10001, 10002, 12000, 21000, 22001, 22002, 23001 TO 23007, 24001 TO 24003, 25000, 26001 TO 26005, 26007 TO 26008, 27000, 28000, 30001 TO 30004, 51000</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 6 and not($completeOffenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 923]/COLUMN[@NAME = 'CODE']/text())">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 6 and not($completeOffenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 923]/COLUMN[@NAME = 'CODE']/text())">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 923: IF PROPERTY TYPE = 6, ONE OF THE FOLLOWING FILE CLASSES MUST EXIST AND ATTEMPT MUST = C: 25000, 35001, 35002, 39001 TO 39004</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 7 and not($itemNumber = 0) and not($completeOffenses = (10001, 10002, 12000, 21000, 22001, 22002, 23001 to 23007, 24001, 24003, 26001 to 26005, 26007, 26008, 27000, 30001 to 30004, 51000))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 7 and not($itemNumber = 0) and not($completeOffenses = (10001, 10002, 12000, 21000, 22001, 22002, 23001 to 23007, 24001, 24003, 26001 to 26005, 26007, 26008, 27000, 30001 to 30004, 51000))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 924: IF PROPERTY TYPE = 7, ONE OF THE FOLLOWING FILE CLASSES MUST EXIST AND ATTEMPT MUST = C: 10001, 10002, 12000, 21000, 22001, 22002, 23001 TO 23007, 24001, 24003, 26001 TO 26005, 26007 TO 26008, 27000, 30001 TO 30004, 51000</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$propertyClass = 77 and not(number($itemNumber) = 1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$propertyClass = 77 and not(number($itemNumber) = 1)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 928: IF PROPERTY CLASS IS 77, ITEM NUMBER MUST BE 001</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="number($propertyClass) = 77 and not(number($propertyValue) = 1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($propertyClass) = 77 and not(number($propertyValue) = 1)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 929: PROPERTY VALUE MUST BE 1</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($propertyClass) and empty($lossType)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($propertyClass) and empty($lossType)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 930: PROPERTY TYPE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($propertyValue) and number($propertyValue) &gt; 0 and (empty($lossType) or empty($propertyClass))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($propertyValue) and number($propertyValue) &gt; 0 and (empty($lossType) or empty($propertyClass))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 933: PROPERTY TYPE IS REQUIRED PROPERTY CLASS IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="number($propertyClass) = (9,22,48,65,66) and number($propertyValue) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($propertyClass) = (9,22,48,65,66) and number($propertyValue) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 934: PROPERTY VALUE MUST BE ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(number($propertyClass) = 88 or number($propertyClass) = 99) and $propertyValue &lt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(number($propertyClass) = 88 or number($propertyClass) = 99) and $propertyValue &lt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 935: PROPERTY VALUE MUST BE NUMERIC</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((exists($propertyValue) and not($propertyValue &gt; 0)) or not(exists($propertyValue)) or empty($propertyValue))            and ((not($propertyClass = (9,22,48,65,66,88)) and ($lossType = (1,2,3,4,5,6,7)))            and (not($lossType = 6 and $propertyClass = 10))            ) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((exists($propertyValue) and not($propertyValue &gt; 0)) or not(exists($propertyValue)) or empty($propertyValue)) and ((not($propertyClass = (9,22,48,65,66,88)) and ($lossType = (1,2,3,4,5,6,7))) and (not($lossType = 6 and $propertyClass = 10)) )">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>936: VALUE MUST BE GREATER THAN ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((exists(./msp:Property) and (exists($propertyValue) and number($propertyValue) &gt; 0)       or (exists($propertyClass) and number($propertyClass) &gt; 0)       or exists($recoverDate)      or (exists($numStlRecVeh) and number($numStlRecVeh) &gt; 0)      or (exists($quantity) and number($quantity) &gt; 0)      or exists($measure))            and $lossType = (0,9))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((exists(./msp:Property) and (exists($propertyValue) and number($propertyValue) &gt; 0) or (exists($propertyClass) and number($propertyClass) &gt; 0) or exists($recoverDate) or (exists($numStlRecVeh) and number($numStlRecVeh) &gt; 0) or (exists($quantity) and number($quantity) &gt; 0) or exists($measure)) and $lossType = (0,9))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>906: PROPERTY RECORD, CLASS, VALUE, DATE, VEHICLE, DRUG QTY, AND MEASURE MUST NOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 5 and number(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property[@s:id = $stolenPropId]/nc:RoleOfItemReference/@s:ref or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $stolenPropId]/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount/text()) &lt; $propertyValue">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 5 and number(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property[@s:id = $stolenPropId]/nc:RoleOfItemReference/@s:ref or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $stolenPropId]/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount/text()) &lt; $propertyValue">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 937: VALUE RECOVERED CANNOT BE GREATER THAN VALUE STOLEN</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$propertyClass = 10 and $lossType = 6 and $completeOffenses = 35001 and $propertyValue &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$propertyClass = 10 and $lossType = 6 and $completeOffenses = 35001 and $propertyValue &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 938: PROPERTY VALUE MUST BE ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty($recoverDate)           and (($action = 'W')           or ((count($completeOffenses) &gt; 0 and count($attemptOffenses) = 0)           and (every $offense in $completeOffenses satisfies ($offense = 24002 and not($lossType = 0))            or ($offense = (28000,25000) and $lossType = 5)            or ($offense = (10001,10002,12000,21000,22001,22002,23001 to 23007,24001,24003,26001 to 26005, 26007, 26008, 27000,30000 to 30002,51000) and $lossType = (1,5))))) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty($recoverDate) and (($action = 'W') or ((count($completeOffenses) &gt; 0 and count($attemptOffenses) = 0) and (every $offense in $completeOffenses satisfies ($offense = 24002 and not($lossType = 0)) or ($offense = (28000,25000) and $lossType = 5) or ($offense = (10001,10002,12000,21000,22001,22002,23001 to 23007,24001,24003,26001 to 26005, 26007, 26008, 27000,30000 to 30002,51000) and $lossType = (1,5)))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 940: RECOVERED DATE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($recoverDate) and not($action = 'W')           and not(some $attempt in $attemptOffenses satisfies $attempt = ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 162]/COLUMN[@NAME = 'CODE']/text(), 39000 to 39009))           and not(some $complete in $completeOffenses satisfies (($complete = (10001,10002,12000,24003,26001 to 26005,26007,26008,27000,51000,22001,22002,23001 to 23007,21000,30000 to 30004,24001) and $lossType = (5,1))           or ($complete = (28000,25000) and $lossType = 5)           or ($complete = 24002 and not($lossType = 0)))) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($recoverDate) and not($action = 'W') and not(some $attempt in $attemptOffenses satisfies $attempt = ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 162]/COLUMN[@NAME = 'CODE']/text(), 39000 to 39009)) and not(some $complete in $completeOffenses satisfies (($complete = (10001,10002,12000,24003,26001 to 26005,26007,26008,27000,51000,22001,22002,23001 to 23007,21000,30000 to 30004,24001) and $lossType = (5,1)) or ($complete = (28000,25000) and $lossType = 5) or ($complete = 24002 and not($lossType = 0))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 942: RECOVERED DATE MUST NOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($completeOffenses = 35001) and (not(empty($drugType)) and not($drugType = '99'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($completeOffenses = 35001) and (not(empty($drugType)) and not($drugType = '99'))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 949: DRUG TYPE CANNOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty($itemNumber)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty($itemNumber)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 961: ITEM NUMBER REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($action = 'W') and $lossType = 5           and not(some $prop in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) satisfies $prop/msp:PropertyLossCode/number(text()) = 7 and $prop/msp:PropertyCategoryCode/number(text()) = $propertyClass and $prop/msp:PropertySequenceNumberText/number(text()) = $itemNumber)           and not($completeOffenses = (24002,25000,28000))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($action = 'W') and $lossType = 5 and not(some $prop in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) satisfies $prop/msp:PropertyLossCode/number(text()) = 7 and $prop/msp:PropertyCategoryCode/number(text()) = $propertyClass and $prop/msp:PropertySequenceNumberText/number(text()) = $itemNumber) and not($completeOffenses = (24002,25000,28000))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 969: PROPERTY LOSS TYPE 5 REQUIRES A LOSS TYPE 7 ENTRY</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty($drugType) and (exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode/text() = '35001') and ($lossType = (6)) and number($propertyClass) = 10)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty($drugType) and (exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode/text() = '35001') and ($lossType = (6)) and number($propertyClass) = 10)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 971: DRUG TYPE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="xs:date($recoverDate) &gt; current-date() or ($incidentDate castable as xs:date and xs:date($recoverDate) &lt; xs:date($incidentDate))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="xs:date($recoverDate) &gt; current-date() or ($incidentDate castable as xs:date and xs:date($recoverDate) &lt; xs:date($incidentDate))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 972: RECOVER DATE CANNOT BE PRIOR TO INCIDENT DATE OR A FUTURE DATE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$completeOffenses = 35001 and $lossType = 0 and $itemNumber = 0 and not($drugType = 99) and not(some $prop in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property satisfies $prop/msp:PropertyCategoryCode/number(text()) = 10) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$completeOffenses = 35001 and $lossType = 0 and $itemNumber = 0 and not($drugType = 99) and not(some $prop in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property satisfies $prop/msp:PropertyCategoryCode/number(text()) = 10)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 977: DRUG TYPE MUST BE 99 WITH ITEM 000 AND LOSS TYPE 0</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test=" $offenses = 26002 and number($propertyClass) = 9">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenses = 26002 and number($propertyClass) = 9">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: Please verify this incident involved credit card fraud.  A transaction must have occurred in order to be considered credit card fraud.  If changes are required, please submit with the next MICR submission.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="number($lossType) = 7 and (for $a in number($propertyClass) return $a = (29,30,31,32,33,34,35)) and index-of(for $a in //lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode return $a = (23001,23002,23003,23004,23005,23006,23007), true()) &gt; 0 ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($lossType) = 7 and (for $a in number($propertyClass) return $a = (29,30,31,32,33,34,35)) and index-of(for $a in //lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode return $a = (23001,23002,23003,23004,23005,23006,23007), true()) &gt; 0">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING:  It is uncommon in an offense of larceny-theft to list a structure as the stolen property.  Please verify stolen property type.  If changes are required, please submit with your next MICR Submission.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M96"/>
   <xsl:template match="@*|node()" priority="-2" mode="M96">
      <xsl:apply-templates select="*" mode="M96"/>
   </xsl:template>

   <!--PATTERN property-tangible-micr-edits-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem"
                 priority="1000"
                 mode="M97">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem"/>
      <xsl:variable name="propertyId" select="nc:Property/@s:id"/>
      <xsl:variable name="itemId" select="nc:TangibleItem/@s:id"/>
      <xsl:variable name="itemNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = $propertyId]]/msp:PropertySequenceNumberText/number(text())"/>
      <xsl:variable name="lossType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $propertyId]/msp:PropertyLossCode/number(text())"/>
      <xsl:variable name="propertyClass"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $propertyId]/msp:PropertyCategoryCode/number(text())"/>
      <xsl:variable name="propertyValue"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount/number(text())"/>
      <xsl:variable name="recoverDate"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId  or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/ndexia:ItemStatus/nc:StatusDate/nc:Date/text()"/>
      <xsl:variable name="stolenPropId"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[number(msp:PropertySequenceNumberText/text()) = $itemNumber and number(msp:PropertyLossCode/text()) = 7]/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref"/>
      <xsl:variable name="error905Ex"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 35001] and number($lossType = 0))"/>
      <xsl:variable name="error908Ex2"
                    select="exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense[number(msp:OffenseCategoryCode/text()) = 24001]/msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref] and number($propertyClass) = 38 and exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[number(msp:PropertySequenceNumberText/text()) = $itemNumber and exists($val_lookup//ROW[COLUMN/@NAME = 'DATA_ELEMENT' and COLUMN/text() = 'PROPERTY_TYPE' and COLUMN/@NAME = 'ERROR_NUMBER' and COLUMN/text() = '908']/COLUMN[@NAME = 'CODE' and number(text()) = number(msp:PropertyCategoryCode/text())])]/msp:PropertyLossCode[number(text()) = 7]) )"/>
      <xsl:variable name="numStlRecVeh"
                    select="//lexspd:doPublish/lexs:PublishMessageContainer/lexs:PublishMessage/lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem/ndexia:TangibleItemAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/ndexia:ItemQuantity/text()"/>
      <xsl:variable name="drugType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/msp:SuspectedDrugCategoryCode/text()"/>
      <xsl:variable name="quantity"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:MeasurePointValue/text()"/>
      <xsl:variable name="measure"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $itemId]/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text()"/>
      <xsl:variable name="error908Ex1"
                    select="$propertyClass = 38 and ($completeOffenses = 24001) and //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyCategoryCode/number(text()) = (3,5,24,28,37)"/>

		    <!--REPORT error-->
<xsl:if test="number($itemNumber) = 0 and          ($action = 'W' or $completeOffenses = (20000,29000,12000,24003,26001,26002,26003,26004,26005,27000,30000,30001,23001,23002,23003,23004,23005,23006,21000,23007,30002,30004,24001,39001,39002,39003,39004,25000)          and not(some $offense in $completeOffenses satisfies           (not($lossType = 5) and $offense = 28000)           or ($lossType = (0,9) and $offense = (10001,10002,51000,22001,22002))           or ($lossType = 0 and $offense = 24002)))          and not(some $prop in //msp:Property satisfies $prop/msp:PropertySequenceNumberText/number(text()) &gt; 0) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($itemNumber) = 0 and ($action = 'W' or $completeOffenses = (20000,29000,12000,24003,26001,26002,26003,26004,26005,27000,30000,30001,23001,23002,23003,23004,23005,23006,21000,23007,30002,30004,24001,39001,39002,39003,39004,25000) and not(some $offense in $completeOffenses satisfies (not($lossType = 5) and $offense = 28000) or ($lossType = (0,9) and $offense = (10001,10002,51000,22001,22002)) or ($lossType = 0 and $offense = 24002))) and not(some $prop in //msp:Property satisfies $prop/msp:PropertySequenceNumberText/number(text()) &gt; 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 901: PROPERTY ITEM MUST NOT BE ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($lossType = (5,7)) and count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertySequenceNumberText[text() = $itemNumber]) &gt; 1">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($lossType = (5,7)) and count(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertySequenceNumberText[text() = $itemNumber]) &gt; 1">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 902: PROPERTY ITEM MAY NOT BE DUPLICATED UNLESS LOSS TYPE IS 5 AND 7</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 5 and (some $prop in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) satisfies $prop/msp:PropertyLossCode/number(text()) = 7 and not($prop/msp:PropertyCategoryCode/number(text()) = $propertyClass) and $prop/msp:PropertySequenceNumberText/number(text()) = $itemNumber) and not($error908Ex1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 5 and (some $prop in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) satisfies $prop/msp:PropertyLossCode/number(text()) = 7 and not($prop/msp:PropertyCategoryCode/number(text()) = $propertyClass) and $prop/msp:PropertySequenceNumberText/number(text()) = $itemNumber) and not($error908Ex1)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 908: ITEM TYPE 5 MUST EXIST WITH TYPE 7</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 1 and empty(index-of((for $a in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = true()]]),  $b in ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 918]/COLUMN[@NAME = 'CODE']/text()) return string($a = $b)), 'true'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 1 and empty(index-of((for $a in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref[../../../ndexia:OffenseCompletedIndicator = true()]]), $b in ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 918]/COLUMN[@NAME = 'CODE']/text()) return string($a = $b)), 'true'))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 918: IF PROPERTY TYPE = 1, ONE OF THE FOLLOWING FILE CLASSES MUST EXIST AND ATTEMPT MUST = C: 10001, 10002, 12000, 21000, 22001, 22002, 23001 TO 23007, 24001, 24003, 26001 TO 26005, 26007 TO 26008, 27000, 30001 TO 30003, 51000</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 2 and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 20000]/../msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 2 and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 20000]/../msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 919: IF PROPERTY TYPE = 2, FILE CLASS 20000 MUST EXIST AND ATTEMPT MUST = C</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 3 and not($completeOffenses = 25000)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 3 and not($completeOffenses = 25000)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 920: IF PROPERTY TYPE = 3, FILE CLASS 25000 MUST EXIST AND ATTEMPT MUST = C</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 4 and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 29000]/../msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref])">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 4 and empty(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[number(text()) = 29000]/../msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense[ndexia:OffenseCompletedIndicator/text() = true()]/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference/@lexslib:ref])">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 921: IF PROPERTY TYPE = 4, FILE CLASS 29000 MUST EXIST AND ATTEMPT MUST = C</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 5           and not($completeOffenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 922]/COLUMN[@NAME = 'CODE']/text())           and not($action = 'W')">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 5 and not($completeOffenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 922]/COLUMN[@NAME = 'CODE']/text()) and not($action = 'W')">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 922: IF PROPERTY TYPE = 5, ONE OF THE FOLLOWING FILE CLASSES MUST EXIST AND ATTEMPT MUST = C: 10001, 10002, 12000, 21000, 22001, 22002, 23001 TO 23007, 24001 TO 24003, 25000, 26001 TO 26005, 26007 TO 26008, 27000, 28000, 30001 TO 30004, 51000</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 6 and not($completeOffenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 923]/COLUMN[@NAME = 'CODE']/text())">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 6 and not($completeOffenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 923]/COLUMN[@NAME = 'CODE']/text())">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 923: IF PROPERTY TYPE = 6, ONE OF THE FOLLOWING FILE CLASSES MUST EXIST AND ATTEMPT MUST = C: 25000, 35001, 35002, 39001 TO 39004</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 7 and not($itemNumber = 0) and not($completeOffenses = (10001, 10002, 12000, 21000, 22001, 22002, 23001 to 23007, 24001, 24003, 26001 to 26005, 26007, 26008, 27000, 30001 to 30004, 51000))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 7 and not($itemNumber = 0) and not($completeOffenses = (10001, 10002, 12000, 21000, 22001, 22002, 23001 to 23007, 24001, 24003, 26001 to 26005, 26007, 26008, 27000, 30001 to 30004, 51000))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 924: IF PROPERTY TYPE = 7, ONE OF THE FOLLOWING FILE CLASSES MUST EXIST AND ATTEMPT MUST = C: 10001, 10002, 12000, 21000, 22001, 22002, 23001 TO 23007, 24001, 24003, 26001 TO 26005, 26007 TO 26008, 27000, 30001 TO 30004, 51000</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$propertyClass = 77 and not(number($itemNumber) = 1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$propertyClass = 77 and not(number($itemNumber) = 1)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 928: IF PROPERTY CLASS IS 77, ITEM NUMBER MUST BE 001</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="number($propertyClass) = 77 and not(number($propertyValue) = 1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($propertyClass) = 77 and not(number($propertyValue) = 1)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 929: PROPERTY VALUE MUST BE 1</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($propertyClass) and empty($lossType)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($propertyClass) and empty($lossType)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 930: PROPERTY TYPE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($propertyValue) and number($propertyValue) &gt; 0 and (empty($lossType) or empty($propertyClass))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($propertyValue) and number($propertyValue) &gt; 0 and (empty($lossType) or empty($propertyClass))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 933: PROPERTY TYPE IS REQUIRED PROPERTY CLASS IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="number($propertyClass) = (9,22,48,65,66) and number($propertyValue) &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($propertyClass) = (9,22,48,65,66) and number($propertyValue) &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 934: PROPERTY VALUE MUST BE ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(number($propertyClass) = 88 or number($propertyClass) = 99) and $propertyValue &lt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(number($propertyClass) = 88 or number($propertyClass) = 99) and $propertyValue &lt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 935: PROPERTY VALUE MUST BE NUMERIC</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((exists($propertyValue) and not($propertyValue &gt; 0)) or not(exists($propertyValue)) or empty($propertyValue))            and ((not($propertyClass = (9,22,48,65,66,88)) and ($lossType = (1,2,3,4,5,6,7)))            and (not($lossType = 6 and $propertyClass = 10))            ) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((exists($propertyValue) and not($propertyValue &gt; 0)) or not(exists($propertyValue)) or empty($propertyValue)) and ((not($propertyClass = (9,22,48,65,66,88)) and ($lossType = (1,2,3,4,5,6,7))) and (not($lossType = 6 and $propertyClass = 10)) )">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>936: VALUE MUST BE GREATER THAN ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="((exists(./msp:Property) and (exists($propertyValue) and number($propertyValue) &gt; 0)       or (exists($propertyClass) and number($propertyClass) &gt; 0)       or exists($recoverDate)      or (exists($numStlRecVeh) and number($numStlRecVeh) &gt; 0)      or (exists($quantity) and number($quantity) &gt; 0)      or exists($measure))            and $lossType = (0,9))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="((exists(./msp:Property) and (exists($propertyValue) and number($propertyValue) &gt; 0) or (exists($propertyClass) and number($propertyClass) &gt; 0) or exists($recoverDate) or (exists($numStlRecVeh) and number($numStlRecVeh) &gt; 0) or (exists($quantity) and number($quantity) &gt; 0) or exists($measure)) and $lossType = (0,9))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>906: PROPERTY RECORD, CLASS, VALUE, DATE, VEHICLE, DRUG QTY, AND MEASURE MUST NOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$lossType = 5 and number(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property[@s:id = $stolenPropId]/nc:RoleOfItemReference/@s:ref or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $stolenPropId]/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount/text()) &lt; $propertyValue">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$lossType = 5 and number(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/*[self::ndexia:TangibleItem or self::ndexia:Drug]/*[self::ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = //lexs:Digest/lexsdigest:EntityTangibleItem/nc:Property[@s:id = $stolenPropId]/nc:RoleOfItemReference/@s:ref or self::ndexia:DrugAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $stolenPropId]/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount/text()) &lt; $propertyValue">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 937: VALUE RECOVERED CANNOT BE GREATER THAN VALUE STOLEN</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$propertyClass = 10 and $lossType = 6 and $completeOffenses = 35001 and $propertyValue &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$propertyClass = 10 and $lossType = 6 and $completeOffenses = 35001 and $propertyValue &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 938: PROPERTY VALUE MUST BE ZERO</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty($recoverDate)           and (($action = 'W')           or ((count($completeOffenses) &gt; 0 and count($attemptOffenses) = 0)           and (every $offense in $completeOffenses satisfies ($offense = 24002 and not($lossType = 0))            or ($offense = (28000,25000) and $lossType = 5)            or ($offense = (10001,10002,12000,21000,22001,22002,23001 to 23007,24001,24003,26001 to 26005, 26007, 26008, 27000,30000 to 30002,51000) and $lossType = (1,5))))) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty($recoverDate) and (($action = 'W') or ((count($completeOffenses) &gt; 0 and count($attemptOffenses) = 0) and (every $offense in $completeOffenses satisfies ($offense = 24002 and not($lossType = 0)) or ($offense = (28000,25000) and $lossType = 5) or ($offense = (10001,10002,12000,21000,22001,22002,23001 to 23007,24001,24003,26001 to 26005, 26007, 26008, 27000,30000 to 30002,51000) and $lossType = (1,5)))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 940: RECOVERED DATE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="exists($recoverDate) and not($action = 'W')           and not(some $attempt in $attemptOffenses satisfies $attempt = ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 162]/COLUMN[@NAME = 'CODE']/text(), 39000 to 39009))           and not(some $complete in $completeOffenses satisfies (($complete = (10001,10002,12000,24003,26001 to 26005,26007,26008,27000,51000,22001,22002,23001 to 23007,21000,30000 to 30004,24001) and $lossType = (5,1))           or ($complete = (28000,25000) and $lossType = 5)           or ($complete = 24002 and not($lossType = 0)))) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($recoverDate) and not($action = 'W') and not(some $attempt in $attemptOffenses satisfies $attempt = ($val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'PROPERTY_TYPE' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = 162]/COLUMN[@NAME = 'CODE']/text(), 39000 to 39009)) and not(some $complete in $completeOffenses satisfies (($complete = (10001,10002,12000,24003,26001 to 26005,26007,26008,27000,51000,22001,22002,23001 to 23007,21000,30000 to 30004,24001) and $lossType = (5,1)) or ($complete = (28000,25000) and $lossType = 5) or ($complete = 24002 and not($lossType = 0))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 942: RECOVERED DATE MUST NOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($completeOffenses = 35001) and (not(empty($drugType)) and not($drugType = '99'))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($completeOffenses = 35001) and (not(empty($drugType)) and not($drugType = '99'))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 949: DRUG TYPE CANNOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty($itemNumber)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="empty($itemNumber)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 961: ITEM NUMBER REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="not($action = 'W') and $lossType = 5           and not(some $prop in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) satisfies $prop/msp:PropertyLossCode/number(text()) = 7 and $prop/msp:PropertyCategoryCode/number(text()) = $propertyClass and $prop/msp:PropertySequenceNumberText/number(text()) = $itemNumber)           and not($completeOffenses = (24002,25000,28000))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="not($action = 'W') and $lossType = 5 and not(some $prop in (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property) satisfies $prop/msp:PropertyLossCode/number(text()) = 7 and $prop/msp:PropertyCategoryCode/number(text()) = $propertyClass and $prop/msp:PropertySequenceNumberText/number(text()) = $itemNumber) and not($completeOffenses = (24002,25000,28000))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 969: PROPERTY LOSS TYPE 5 REQUIRES A LOSS TYPE 7 ENTRY</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty($drugType) and (exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode/text() = '35001') and ($lossType = (6)) and number($propertyClass) = 10)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty($drugType) and (exists(//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode/text() = '35001') and ($lossType = (6)) and number($propertyClass) = 10)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 971: DRUG TYPE IS REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="xs:date($recoverDate) &gt; current-date() or ($incidentDate castable as xs:date and xs:date($recoverDate) &lt; xs:date($incidentDate))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="xs:date($recoverDate) &gt; current-date() or ($incidentDate castable as xs:date and xs:date($recoverDate) &lt; xs:date($incidentDate))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 972: RECOVER DATE CANNOT BE PRIOR TO INCIDENT DATE OR A FUTURE DATE</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$completeOffenses = 35001 and $lossType = 0 and $itemNumber = 0 and not($drugType = 99) and not(some $prop in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property satisfies $prop/msp:PropertyCategoryCode/number(text()) = 10) ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$completeOffenses = 35001 and $lossType = 0 and $itemNumber = 0 and not($drugType = 99) and not(some $prop in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property satisfies $prop/msp:PropertyCategoryCode/number(text()) = 10)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 977: DRUG TYPE MUST BE 99 WITH ITEM 000 AND LOSS TYPE 0</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test=" $offenses = 26002 and number($propertyClass) = 9">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$offenses = 26002 and number($propertyClass) = 9">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING: Please verify this incident involved credit card fraud.  A transaction must have occurred in order to be considered credit card fraud.  If changes are required, please submit with the next MICR submission.</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="number($lossType) = 7 and (for $a in number($propertyClass) return $a = (29,30,31,32,33,34,35)) and index-of(for $a in //lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode return $a = (23001,23002,23003,23004,23005,23006,23007), true()) &gt; 0 ">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($lossType) = 7 and (for $a in number($propertyClass) return $a = (29,30,31,32,33,34,35)) and index-of(for $a in //lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode return $a = (23001,23002,23003,23004,23005,23006,23007), true()) &gt; 0">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING:  It is uncommon in an offense of larceny-theft to list a structure as the stolen property.  Please verify stolen property type.  If changes are required, please submit with your next MICR Submission.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M97"/>
   <xsl:template match="@*|node()" priority="-2" mode="M97">
      <xsl:apply-templates select="*" mode="M97"/>
   </xsl:template>

   <!--PATTERN property-drug-extended-micr-edits-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug"
                 priority="1000"
                 mode="M98">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityDrug"/>
      <xsl:variable name="drugId" select="nc:Drug/@s:id"/>
      <xsl:variable name="itemNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = $drugId]]/msp:PropertySequenceNumberText/text()"/>
      <xsl:variable name="propertyClass"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $drugId]/msp:PropertyCategoryCode/text()"/>
      <xsl:variable name="propertyValue"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $drugId]/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount/text()"/>
      <xsl:variable name="drugType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $drugId]/msp:SuspectedDrugCategoryCode/text()"/>
      <xsl:variable name="quantity"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $drugId]/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:MeasurePointValue/text()"/>
      <xsl:variable name="measure"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation[lexslib:SameAsDigestReference/@lexslib:ref = $drugId]/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text()"/>
      <xsl:variable name="lossType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $drugId]/msp:PropertyLossCode/number(text())"/>
      <xsl:variable name="weightMeasure" select="'GM','KG','OZ','LB'"/>
      <xsl:variable name="fluidMeasure" select="'ML','LT','FO','GL'"/>
      <xsl:variable name="unitMeasure" select="'DU','NP','XX'"/>

		    <!--REPORT error-->
<xsl:if test="number($drugType) = 77 and exists($measure)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($drugType) = 77 and exists($measure)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 950: MEASURE MUST NOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(some $drug in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation[lexslib:SameAsDigestReference/not(@lexslib:ref = $drugId)] satisfies        (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $drug/lexslib:SameAsDigestReference/@lexslib:ref]/msp:SuspectedDrugCategoryCode/text() =$drugType       and ($drug//ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text() = $measure       or ($measure = ($weightMeasure) and $drug/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text() = ($weightMeasure))       or ($measure = ($fluidMeasure) and $drug/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text() = ($fluidMeasure))       or ($measure = ($unitMeasure) and $drug/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text() = ($unitMeasure)))))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(some $drug in //lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Drug/ndexia:DrugAugmentation[lexslib:SameAsDigestReference/not(@lexslib:ref = $drugId)] satisfies (//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Drug[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $drug/lexslib:SameAsDigestReference/@lexslib:ref]/msp:SuspectedDrugCategoryCode/text() =$drugType and ($drug//ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text() = $measure or ($measure = ($weightMeasure) and $drug/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text() = ($weightMeasure)) or ($measure = ($fluidMeasure) and $drug/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text() = ($fluidMeasure)) or ($measure = ($unitMeasure) and $drug/ndexia:ItemQuantityStatusValue/nc:SubstanceQuantityMeasure/nc:SubstanceUnitCode/text() = ($unitMeasure)))))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="number($itemNumber)"/>
               <xsl:text/> 951: MEASURE 1 CANNOT BE SAME MEASURE CATEGORY AS MEASURE 2</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="number($drugType) != 77 and number($lossType) = 6 and $propertyClass = 10 and $completeOffenses = 35001 and (empty($quantity) or $quantity = 0)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($drugType) != 77 and number($lossType) = 6 and $propertyClass = 10 and $completeOffenses = 35001 and (empty($quantity) or $quantity = 0)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="number($itemNumber)"/>
               <xsl:text/> 952: DRUG QTY REQUIRED FOR SEIZED DRUGS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="number($drugType) != 77 and number($lossType) = 6 and $propertyClass = 10 and $completeOffenses = 35001 and empty($measure)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="number($drugType) != 77 and number($lossType) = 6 and $propertyClass = 10 and $completeOffenses = 35001 and empty($measure)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="number($itemNumber)"/>
               <xsl:text/> 952: MEASURE REQUIRED FOR SEIZED DRUGS</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="$measure = 'XX' and number($quantity) != 1000">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="$measure = 'XX' and number($quantity) != 1000">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="$itemNumber"/>
               <xsl:text/> 955: DRUG QTY MUST BE 1 FOLLOWED BY THREE ZEROS (1000 = 1.000)
     DRUG QUANTITY IS INVALID </svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="empty(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'DRUG_UOM' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = '957']/COLUMN[@NAME = 'CODE']/text() return $a = $drugType, true())) and $measure = 'NP'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="empty(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT']/text() = 'DRUG_UOM' and COLUMN[@NAME = 'ERROR_NUMBER']/text() = '957']/COLUMN[@NAME = 'CODE']/text() return $a = $drugType, true())) and $measure = 'NP'">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="number($itemNumber)"/>
               <xsl:text/> 957: MEASURE CANNOT BE NP</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(not($completeOffenses = 35001) or ($completeOffenses = 35001 and not($lossType = 6 and $propertyClass = 10))) and exists($measure)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(not($completeOffenses = 35001) or ($completeOffenses = 35001 and not($lossType = 6 and $propertyClass = 10))) and exists($measure)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="number($itemNumber)"/>
               <xsl:text/> 974: MEASURE CANNOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(not($completeOffenses = 35001) or ($completeOffenses = 35001 and not($lossType = 6 and $propertyClass = 10))) and $quantity &gt; 0">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(not($completeOffenses = 35001) or ($completeOffenses = 35001 and not($lossType = 6 and $propertyClass = 10))) and $quantity &gt; 0">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="number($itemNumber)"/>
               <xsl:text/> 975: DRUG QTY CANNOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT warning-->
<xsl:if test="(for $a in number($drugType) return $a = (1,2,5)) and $measure = 'DU'">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(for $a in number($drugType) return $a = (1,2,5)) and $measure = 'DU'">
            <xsl:attribute name="role">warning</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>WARNING:  Please verify the drug measurement of DU.  It is uncommon to use DU for these drug types.  If changes are required, please submit with your next data submission.</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M98"/>
   <xsl:template match="@*|node()" priority="-2" mode="M98">
      <xsl:apply-templates select="*" mode="M98"/>
   </xsl:template>

   <!--PATTERN property-tangible-extended-micr-edits-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem"
                 priority="1000"
                 mode="M99">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityTangibleItem"/>
      <xsl:variable name="tangibleItemId" select="nc:TangibleItem/@s:id"/>
      <xsl:variable name="propertyId"
                    select="nc:Property[nc:RoleOfItemReference/@s:ref = $tangibleItemId]/@s:id"/>
      <xsl:variable name="propertyClass"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $propertyId]/msp:PropertyCategoryCode/text()"/>
      <xsl:variable name="itemNumber"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference[@lexslib:ref = $propertyId]]/msp:PropertySequenceNumberText/text()"/>
      <xsl:variable name="propertyValue"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem[ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $tangibleItemId]/ndexia:TangibleItemAugmentation/ndexia:ItemQuantityStatusValue/ndexia:ItemValue/nc:ItemValueAmount"/>
      <xsl:variable name="stolenPropId"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[number(msp:PropertySequenceNumberText/text()) = $itemNumber and number(msp:PropertyLossCode/text()) = 7]/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref"/>
      <xsl:variable name="numStlRecVeh"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:TangibleItem[ndexia:TangibleItemAugmentation/lexslib:SameAsDigestReference/@lexslib:ref = $tangibleItemId]/ndexia:TangibleItemAugmentation/ndexia:ItemQuantityStatusValue/ndexia:ItemQuantity/text()"/>
      <xsl:variable name="lossType"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property[msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref = $propertyId]/msp:PropertyLossCode/text()"/>

		    <!--REPORT error-->
<xsl:if test="exists($numStlRecVeh) and number($numStlRecVeh) != 0 and (empty(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '943A']]/COLUMN[@NAME = 'CODE']/text() return $a = //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode, true())) or empty(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '943B']]/COLUMN[@NAME = 'CODE']/number(text()) return $a = $propertyClass, true())))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="exists($numStlRecVeh) and number($numStlRecVeh) != 0 and (empty(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '943A']]/COLUMN[@NAME = 'CODE']/text() return $a = //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode, true())) or empty(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '943B']]/COLUMN[@NAME = 'CODE']/number(text()) return $a = $propertyClass, true())))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="number($itemNumber)"/>
               <xsl:text/> 943: VEH STLN/REC CANNOT BE ENTERED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(empty($numStlRecVeh) or number($numStlRecVeh) = 0) and $propertyClass = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '944C']]/COLUMN[@NAME = 'CODE']/text() and $lossType = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '944B']]/COLUMN[@NAME = 'CODE']/text() and $offenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '944A']]/COLUMN[@NAME = 'CODE']/text()">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(empty($numStlRecVeh) or number($numStlRecVeh) = 0) and $propertyClass = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '944C']]/COLUMN[@NAME = 'CODE']/text() and $lossType = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '944B']]/COLUMN[@NAME = 'CODE']/text() and $offenses = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '944A']]/COLUMN[@NAME = 'CODE']/text()">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="number($itemNumber)"/>
               <xsl:text/> 944: PROP REC VEH STLN/REC REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>

		    <!--REPORT error-->
<xsl:if test="(empty($numStlRecVeh) or number($numStlRecVeh) = 0) and (exists(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '945C']]/COLUMN[@NAME = 'CODE']/text() return $a = $propertyClass, true())) and exists(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '945B']]/COLUMN[@NAME = 'CODE']/text() return $a = $lossType, true())) and exists(index-of(for $a in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode return $a = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '945A']]/COLUMN[@NAME = 'CODE']/text(), true())))">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="(empty($numStlRecVeh) or number($numStlRecVeh) = 0) and (exists(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '945C']]/COLUMN[@NAME = 'CODE']/text() return $a = $propertyClass, true())) and exists(index-of(for $a in $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '945B']]/COLUMN[@NAME = 'CODE']/text() return $a = $lossType, true())) and exists(index-of(for $a in //lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode return $a = $val_lookup//ROW[COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'NUM_STL_REC_VEH'] and COLUMN[@NAME = 'ERROR_NUMBER' and text() = '945A']]/COLUMN[@NAME = 'CODE']/text(), true())))">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>Property <xsl:text/>
               <xsl:value-of select="number($itemNumber)"/>
               <xsl:text/> 945: PROP REC VEH STLN/REC REQUIRED</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M99"/>
   <xsl:template match="@*|node()" priority="-2" mode="M99">
      <xsl:apply-templates select="*" mode="M99"/>
   </xsl:template>

   <!--PATTERN micr-final-edits-->


	<!--RULE -->
<xsl:template match="//lexs:DataItemPackage" priority="1003" mode="M100">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage"/>
      <xsl:variable name="offenseId"
                    select="//lexs:Digest/lexsdigest:EntityActivity/nc:Activity[nc:ActivityCategoryText='Offense'][@s:id  = ../../../lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref]/@s:id"/>
      <xsl:variable name="fileClass"
                    select="//lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense/msp:OffenseCategoryCode[../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref=$offenseId]"/>
      <xsl:variable name="offenseAttempted"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Offense/ndexia:ActivityAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenseId]/../../ndexia:OffenseCompletedIndicator"/>
      <xsl:variable name="offenseVictimIds"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference/@s:ref[$offenseId]/../../nc:PersonReference/@s:ref"/>
      <xsl:variable name="finalEdit1000FileClasses"
                    select="$val_lookup//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '1000']/../COLUMN[@NAME = 'CODE']"/>
      <xsl:variable name="propertyLoss"
                    select="./lexs:StructuredPayload/mspRoot:IncidentReport/msp:Property/msp:PropertyLossCode"/>
      <xsl:variable name="allVictimCircumstance"
                    select="./lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim/j:VictimAggravatedAssaultHomicideFactorCode"/>
      <xsl:variable name="societyVictimCount"
                    select="count(//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Victim[j:VictimCategoryCode='S'])"/>
      <xsl:variable name="arrests"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:ArrestSubject/ndexia:ArrestSubjectAugmentation/j:ArrestSequenceID/nc:IdentificationID"/>
      <xsl:variable name="allOffenderAges"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonAgeMeasure[nc:MeasurePointValue and ../@s:id = ../../j:Subject/nc:RoleOfPersonReference/@s:ref]/nc:MeasurePointValue/text()"/>
      <xsl:variable name="allOffenderSexCodes"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonSexCode[../@s:id = ../../j:Subject/nc:RoleOfPersonReference/@s:ref]/text()"/>
      <xsl:variable name="allOffenderRaceCodes"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/ndexia:PersonRaceCode[../lexslib:SameAsDigestReference/@lexslib:ref = ../../../../../lexs:Digest/lexsdigest:EntityPerson/j:Subject/nc:RoleOfPersonReference/@s:ref]/text()"/>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim[j:VictimAggravatedAssaultHomicideFactorCode=30]"
                 priority="1002"
                 mode="M100">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Victim[j:VictimAggravatedAssaultHomicideFactorCode=30]"/>
      <xsl:variable name="victimId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson[j:Victim/@s:id = current()/../msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref and j:Victim/nc:RoleOfPersonReference/@s:ref = lexsdigest:Person/@s:id]/lexsdigest:Person/@s:id"/>
      <xsl:variable name="offenderId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:SubjectPersonReference/@s:ref[../../lexsdigest:VictimPersonReference/@s:ref=$victimId]"/>
      <xsl:variable name="offenderAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person/nc:PersonAgeMeasure/nc:MeasurePointValue[../../@s:id = $offenderId]/text()"/>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:VictimToSubjectRelationshipCode"
                 priority="1001"
                 mode="M100">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:StructuredPayload/mspRoot:IncidentReport/msp:SubjectVictimAssociation/msp:VictimToSubjectRelationshipCode"/>
      <xsl:variable name="subjectVictimAssocId"
                    select="./msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref"/>
      <xsl:variable name="victimId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation[@s:id=$subjectVictimAssocId]/lexsdigest:VictimPersonReference/@s:ref"/>
      <xsl:variable name="offenseId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:PersonReference[@s:ref=$victimId]/../nc:ActivityReference/@s:ref"/>
      <xsl:variable name="isVor31"
                    select="./msp:VictimToSubjectRelationshipCode/text()= '31'"/>
      <xsl:variable name="victimAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id=$victimId]/nc:PersonAgeMeasure/nc:MeasurePointValue/text()"/>
      <xsl:variable name="victimRace"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$victimId]/../ndexia:PersonRaceCode/text()"/>
      <xsl:variable name="victimSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = $victimId]/nc:PersonSexCode/text()"/>
      <xsl:variable name="offenderId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:SubjectPersonReference/@s:ref[../../lexsdigest:VictimPersonReference/@s:ref=$victimId]"/>
      <xsl:variable name="offenderAge"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id=$offenderId]/nc:PersonAgeMeasure/nc:MeasurePointValue/text()"/>
      <xsl:variable name="offenderRace"
                    select="//lexs:DataItemPackage/lexs:StructuredPayload/ndexia:IncidentReport/ndexia:Person/ndexia:PersonAugmentation/lexslib:SameAsDigestReference[@lexslib:ref=$offenderId]/../ndexia:PersonRaceCode/text()"/>
      <xsl:variable name="offenderSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = $offenderId]/nc:PersonSexCode/text()"/>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>

	  <!--RULE -->
<xsl:template match="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense"
                 priority="1000"
                 mode="M100">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//lexs:DataItemPackage/lexs:StructuredPayload/mspRoot:IncidentReport/msp:Offense"/>
      <xsl:variable name="offenseId"
                    select="./msp:Augmentation/lexslib:SameAsDigestReference/@lexslib:ref"/>
      <xsl:variable name="fileClass" select="./msp:OffenseCategoryCode/text()"/>
      <xsl:variable name="victimId"
                    select="//lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation/nc:ActivityReference[@s:ref=$offenseId]/../nc:PersonReference/@s:ref"/>
      <xsl:variable name="victimSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id=$victimId]/nc:PersonSexCode/text()"/>
      <xsl:variable name="offenderId"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:SubjectVictimAssociation/lexsdigest:SubjectPersonReference/@s:ref[../../lexsdigest:VictimPersonReference/@s:ref=$victimId]"/>
      <xsl:variable name="offenderSex"
                    select="//lexs:DataItemPackage/lexs:Digest/lexsdigest:EntityPerson/lexsdigest:Person[@s:id = $offenderId]/nc:PersonSexCode/text()"/>

		    <!--REPORT error-->
<xsl:if test="boolean($incidentComplete) and boolean(//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '1001']/ ../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and (count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:ActivityReference[@s:ref=$offenseId]]) &lt; 1)">
         <svrl:successful-report xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                 test="boolean($incidentComplete) and boolean(//ROW/COLUMN[@NAME = 'DATA_ELEMENT' and text() = 'OFFENSE_FILE_CLASS']/../COLUMN[@NAME = 'ERROR_NUMBER' and text() = '1001']/ ../COLUMN[@NAME = 'CODE' and text() = $fileClass]) and (count(//lexs:DataItemPackage/lexs:Digest/lexsdigest:Associations/lexsdigest:OffenseVictimPersonAssociation[nc:ActivityReference[@s:ref=$offenseId]]) &lt; 1)">
            <xsl:attribute name="role">error</xsl:attribute>
            <xsl:attribute name="location">
               <xsl:apply-templates select="." mode="schematron-select-full-path"/>
            </xsl:attribute>
            <svrl:text>1001: FINAL EDIT ERROR: NO CORRESPONDING VICTIM RECORD FOR OFFENSE FILE CLASS</svrl:text>
         </svrl:successful-report>
      </xsl:if>
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M100"/>
   <xsl:template match="@*|node()" priority="-2" mode="M100">
      <xsl:apply-templates select="*" mode="M100"/>
   </xsl:template>
</xsl:stylesheet>
